(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    339061,       8731]
NotebookOptionsPosition[    271815,       7069]
NotebookOutlinePosition[    311157,       7946]
CellTagsIndexPosition[    311004,       7939]
WindowTitle->S20 Statistics & Data Analysis
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[TextData[{
 "Statistics & Data Analysis with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"]
}], "Title"],

Cell[TextData[{
 StyleBox["Wolfram",
  FontSlant->"Plain"],
 " ",
 StyleBox["Online Seminar Series",
  FontColor->RGBColor[0.811765, 0.117647, 0.145098]]
}], "Subtitle"],

Cell[TextData[{
 StyleBox["Presenter:",
  FontSlant->"Plain"],
 " Harry Calkins",
 "\n",
 "seminars@wolfram.com"
}], "Subsubtitle"],

Cell[TextData[{
 Cell[BoxData[
  DynamicBox[ToBoxes[
    Style[
     DateString[], FontFamily -> "Calibri"], StandardForm],
   ImageSizeCache->{225., {1., 14.}},
   UpdateInterval:>1]]],
 StyleBox["  (GMT ",
  StripOnInput->False,
  FontFamily->"Calibri"],
 Cell[BoxData[
  DynamicBox[ToBoxes[
    Style[$TimeZone, FontFamily -> "Calibri"], StandardForm],
   ImageSizeCache->{31., {0., 13.}}]]],
 ")"
}], "DateSection"],

Cell["", "Spacer"]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Overview", "Section"],

Cell[TextData[{
 "This seminar focuses on the state-of-the-art statistics functionality in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". Specifically, we will cover:"
}], "Text",
 CellChangeTimes->{{3.501263695535119*^9, 3.501263696241001*^9}, {
  3.531665972627991*^9, 3.5316659739789915`*^9}}],

Cell[BoxData[
 PaneSelectorBox[{False->
  FrameBox[
   StyleBox["\<\"\\!\\(\\*\\nStyleBox[\\\"Descriptive\\\",\\nFontWeight->\\\"\
Bold\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontWeight->\\\"Bold\\\"]\\)\\!\
\\(\\*\\nStyleBox[\\\"and\\\",\\nFontWeight->\\\"Bold\\\"]\\)\\!\\(\\*\\\
nStyleBox[\\\" \
\\\",\\nFontWeight->\\\"Bold\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"Exploratory\\\",\
\\nFontWeight->\\\"Bold\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontWeight->\
\\\"Bold\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"S\\\",\\nFontWeight->\\\"Bold\\\"]\\)\
\\!\\(\\*\\nStyleBox[\\\"tatistics\\\",\\nFontWeight->\\\"Bold\\\"]\\)\"\>", 
    "OverviewSection",
    StripOnInput->False],
   BoxFrame->2,
   FrameMargins->{{15, 15}, {5, 5}},
   FrameStyle->None,
   RoundingRadius->5,
   StripOnInput->False], True->
  TemplateBox[{FrameBox[
     StyleBox[
     "\"\\!\\(\\*\\nStyleBox[\\\"Descriptive\\\",\\nFontWeight->\\\"Bold\\\"]\
\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontWeight->\\\"Bold\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"and\\\",\\\
nFontWeight->\\\"Bold\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontWeight->\\\
\"Bold\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"Exploratory\\\",\\nFontWeight->\\\"\
Bold\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontWeight->\\\"Bold\\\"]\\)\\!\
\\(\\*\\nStyleBox[\\\"S\\\",\\nFontWeight->\\\"Bold\\\"]\\)\\!\\(\\*\\\
nStyleBox[\\\"tatistics\\\",\\nFontWeight->\\\"Bold\\\"]\\)\"", 
      "OverviewSection", StripOnInput -> False, LineColor -> GrayLevel[1], 
      FrontFaceColor -> GrayLevel[1], BackFaceColor -> GrayLevel[1], 
      GraphicsColor -> GrayLevel[1], FontColor -> GrayLevel[1]], Background -> 
     RGBColor[0.811765, 0.117647, 0.145098, 1], 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> None, RoundingRadius -> 
     5, StripOnInput -> False],"\" \[RightGuillemet] \"",FrameBox[
     StyleBox[
     "\"descriptive measures and charts, smoothing, transformations, \
clustering, visualization\"", "OverviewSection", StripOnInput -> False], 
     Background -> GrayLevel[1], BoxFrame -> 2, 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> 
     RGBColor[0.811765, 0.117647, 0.145098, 1], RoundingRadius -> 5, 
     StripOnInput -> False]},
   "Row",
   DisplayFunction->(
    RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
   InterpretationFunction->(RowBox[{"Row", "[", 
      RowBox[{"{", 
        RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )]}, Dynamic[
   CurrentValue["MouseOver"]],
  FrameMargins->0,
  ImageSize->Automatic]], "OverviewSection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[BoxData[
 PaneSelectorBox[{False->
  FrameBox[
   StyleBox["\<\"\\!\\(\\*\\nStyleBox[\\\"Statistical\\\",\\nFontWeight->\\\"\
Bold\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontWeight->\\\"Bold\\\"]\\)\\!\
\\(\\*\\nStyleBox[\\\"D\\\",\\nFontWeight->\\\"Bold\\\"]\\)\\!\\(\\*\\\
nStyleBox[\\\"istributions\\\",\\nFontWeight->\\\"Bold\\\"]\\)\"\>", 
    "OverviewSection",
    StripOnInput->False],
   BoxFrame->2,
   FrameMargins->{{15, 15}, {5, 5}},
   FrameStyle->None,
   RoundingRadius->5,
   StripOnInput->False], True->
  TemplateBox[{FrameBox[
     StyleBox[
     "\"\\!\\(\\*\\nStyleBox[\\\"Statistical\\\",\\nFontWeight->\\\"Bold\\\"]\
\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontWeight->\\\"Bold\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"D\\\",\\\
nFontWeight->\\\"Bold\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"istributions\\\",\\\
nFontWeight->\\\"Bold\\\"]\\)\"", "OverviewSection", 
      GrayLevel[1], StripOnInput -> False], 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> None, RoundingRadius -> 
     5, Background -> RGBColor[0.811765, 0.117647, 0.145098, 1], StripOnInput -> 
     False],"\" \[RightGuillemet] \"",FrameBox[
     StyleBox[
     "\"parametric and nonparametric distributions, properties of \
distributions, random numbers, parameter estimation, visualization\"", 
      "OverviewSection", StripOnInput -> False], 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> 
     RGBColor[0.811765, 0.117647, 0.145098, 1], BoxFrame -> 2, RoundingRadius -> 
     5, Background -> GrayLevel[1], StripOnInput -> False]},
   "Row",
   DisplayFunction->(
    RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
   InterpretationFunction->(RowBox[{"Row", "[", 
      RowBox[{"{", 
        RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )]}, Dynamic[
   CurrentValue["MouseOver"]],
  FrameMargins->0,
  ImageSize->Automatic]], "OverviewSection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[BoxData[
 PaneSelectorBox[{False->
  FrameBox[
   StyleBox["\<\"\\!\\(\\*\\nStyleBox[\\\"Hypothesis\\\",\\nFontWeight->\\\"\
Bold\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontWeight->\\\"Bold\\\"]\\)\\!\
\\(\\*\\nStyleBox[\\\"T\\\",\\nFontWeight->\\\"Bold\\\"]\\)\\!\\(\\*\\\
nStyleBox[\\\"esting\\\",\\nFontWeight->\\\"Bold\\\"]\\)\"\>", 
    "OverviewSection",
    StripOnInput->False],
   BoxFrame->2,
   FrameMargins->{{15, 15}, {5, 5}},
   FrameStyle->None,
   RoundingRadius->5,
   StripOnInput->False], True->
  TemplateBox[{FrameBox[
     StyleBox[
     "\"\\!\\(\\*\\nStyleBox[\\\"Hypothesis\\\",\\nFontWeight->\\\"Bold\\\"]\\\
)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontWeight->\\\"Bold\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"T\\\",\\\
nFontWeight->\\\"Bold\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"esting\\\",\\\
nFontWeight->\\\"Bold\\\"]\\)\"", "OverviewSection", 
      GrayLevel[1], StripOnInput -> False], 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> None, RoundingRadius -> 
     5, Background -> RGBColor[0.811765, 0.117647, 0.145098, 1], StripOnInput -> 
     False],"\" \[RightGuillemet] \"",FrameBox[
     StyleBox[
     "\"tests of distributional goodness of fit, tests of location and \
scale\"", "OverviewSection", StripOnInput -> False], 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> 
     RGBColor[0.811765, 0.117647, 0.145098, 1], BoxFrame -> 2, RoundingRadius -> 
     5, Background -> GrayLevel[1], StripOnInput -> False]},
   "Row",
   DisplayFunction->(
    RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
   InterpretationFunction->(RowBox[{"Row", "[", 
      RowBox[{"{", 
        RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )]}, Dynamic[
   CurrentValue["MouseOver"]],
  FrameMargins->0,
  ImageSize->Automatic]], "OverviewSection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[BoxData[
 PaneSelectorBox[{False->
  FrameBox[
   StyleBox["\<\"\\!\\(\\*\\nStyleBox[\\\"Model\\\",\\nFontWeight->\\\"Bold\\\
\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontWeight->\\\"Bold\\\"]\\)\\!\\(\\*\
\\nStyleBox[\\\"F\\\",\\nFontWeight->\\\"Bold\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"\
itting\\\",\\nFontWeight->\\\"Bold\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontWeight->\\\"Bold\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"and\\\",\\\
nFontWeight->\\\"Bold\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontWeight->\\\
\"Bold\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"A\\\",\\nFontWeight->\\\"Bold\\\"]\\)\\\
!\\(\\*\\nStyleBox[\\\"nalysis\\\",\\nFontWeight->\\\"Bold\\\"]\\)\"\>", 
    "OverviewSection",
    StripOnInput->False],
   BoxFrame->2,
   FrameMargins->{{15, 15}, {5, 5}},
   FrameStyle->None,
   RoundingRadius->5,
   StripOnInput->False], True->
  TemplateBox[{FrameBox[
     StyleBox[
     "\"\\!\\(\\*\\nStyleBox[\\\"Model\\\",\\nFontWeight->\\\"Bold\\\"]\\)\\!\
\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontWeight->\\\"Bold\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"F\\\",\\\
nFontWeight->\\\"Bold\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"itting\\\",\\\
nFontWeight->\\\"Bold\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontWeight->\\\
\"Bold\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"and\\\",\\nFontWeight->\\\"Bold\\\"]\\)\
\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontWeight->\\\"Bold\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"A\\\",\\\
nFontWeight->\\\"Bold\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"nalysis\\\",\\\
nFontWeight->\\\"Bold\\\"]\\)\"", "OverviewSection", StripOnInput -> False, 
      LineColor -> GrayLevel[1], FrontFaceColor -> GrayLevel[1], 
      BackFaceColor -> GrayLevel[1], GraphicsColor -> GrayLevel[1], FontColor -> 
      GrayLevel[1]], Background -> RGBColor[0.811765, 0.117647, 0.145098, 1], 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> None, RoundingRadius -> 
     5, StripOnInput -> False],"\" \[RightGuillemet] \"",FrameBox[
     StyleBox[
     "\"linear regression, nonlinear regression, generalized linear models \
including logit and probit, ANOVA\"", "OverviewSection", StripOnInput -> 
      False], Background -> GrayLevel[1], BoxFrame -> 2, 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> 
     RGBColor[0.811765, 0.117647, 0.145098, 1], RoundingRadius -> 5, 
     StripOnInput -> False]},
   "Row",
   DisplayFunction->(
    RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
   InterpretationFunction->(RowBox[{"Row", "[", 
      RowBox[{"{", 
        RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )]}, Dynamic[
   CurrentValue["MouseOver"]],
  FrameMargins->0,
  ImageSize->Automatic]], "OverviewSection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell["\<\
The number of included distributions, functionality for distributions, \
hypothesis tests, and statistical visualization capabilities have all been \
greatly extended in recent versions.\
\>", "Text",
 CellChangeTimes->{{3.4976273120493965`*^9, 3.4976273795046797`*^9}, {
  3.498218464535104*^9, 3.498218470707058*^9}, {3.531665994833991*^9, 
  3.5316659990809913`*^9}}],

Cell["\<\
Related graphics, data import, data operations, and general symbolic and \
numeric computation will be seen in the context of examples.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Overview: Data accessibility", "Section"],

Cell["\<\
Data that is to be analyzed often needs to be obtained from some external \
source.\
\>", "Text"],

Cell["", "Spacer"],

Cell[CellGroupData[{

Cell["File import/export", "Subsubsection"],

Cell[TextData[{
 "The ",
 Cell[BoxData[
  ButtonBox["Import",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Import"]], "InlineFormula"],
 " and ",
 Cell[BoxData[
  ButtonBox["Export",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Export"]], "InlineFormula"],
 " functions can import or export dozens of different file formats including \
numeric and tabular formats, plain or formatted text, and graphics formats."
}], "Text"],

Cell[TextData[{
 "A few formats of particular note for numeric data analysis include ",
 Cell[BoxData[
  ButtonBox["XLS",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/format/XLS"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  ButtonBox["XLSX",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/format/XLSX"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  ButtonBox["CSV",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/format/CSV"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  ButtonBox["TSV",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/format/TSV"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  ButtonBox["DBF",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/format/DBF"]], "InlineFormula"],
 ", and ",
 Cell[BoxData[
  ButtonBox["MDB",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/format/MDB"]], "InlineFormula"],
 ", but there are many others as well."
}], "Text",
 CellChangeTimes->{{3.435066632614512*^9, 3.4350666405364885`*^9}, {
   3.498291602483389*^9, 3.498291638536179*^9}, 3.498291721559744*^9}],

Cell[TextData[{
 "Available formats can be displayed by evaluating ",
 Cell[BoxData[
  ButtonBox["$ImportFormats",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/$ImportFormats"]], "InlineFormula"],
 " and ",
 Cell[BoxData[
  ButtonBox["$ExportFormats",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/$ExportFormats"]], "InlineFormula"],
 "."
}], "MathCaption"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"$ImportFormats", "//", "Length"}], ",", 
   RowBox[{"$ExportFormats", "//", "Length"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.4350665175976458`*^9, 3.43506652928522*^9}, {
  3.4350666503334885`*^9, 3.435066656302315*^9}}],

Cell["", "Spacer"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Databases", "Subsubsection"],

Cell[TextData[{
 ButtonBox["DatabaseLink",
  BaseStyle->"Link",
  ButtonData->"paclet:DatabaseLink/tutorial/Overview"],
 ", included in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", allows users to integrate ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " with database management systems.  ",
 StyleBox["DatabaseLink",
  FontSlant->"Italic"],
 " is JDBC-compliant and works with all known databases.  It contains both a \
SQL and a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " interface."
}], "Text",
 CellChangeTimes->{{3.498291847629306*^9, 3.498291894956132*^9}}],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Descriptive Statistics", "Section"],

Cell["\<\
Many descriptive statistics and charts are included for data and \
distributions. We will see a small sampling of them in examples.\
\>", "Text",
 CellChangeTimes->{{3.434109838362525*^9, 3.4341098763781495`*^9}, {
  3.4976272205464683`*^9, 3.4976272477348385`*^9}, {3.497704568278659*^9, 
  3.497704573263193*^9}, {3.4977053983950853`*^9, 3.4977054111928616`*^9}}],

Cell["\<\
The built\[Hyphen]in Old Faithful geyser data includes durations and waiting \
times for geyser eruptions.\
\>", "MathCaption"],

Cell[BoxData[
 RowBox[{"headers", "=", 
  RowBox[{"ExampleData", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\"\<Statistics\>\"", ",", "\"\<OldFaithful\>\""}], "}"}], ",", 
    "\"\<ColumnHeadings\>\""}], "]"}]}]], "Input"],

Cell[TextData[{
 "This gives descriptive measures based on the first 4 moments, as well as \
the median and ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "th"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["90", "th"], TraditionalForm]]],
 " percentiles for waiting durations."
}], "MathCaption",
 CellChangeTimes->{{3.497705549937003*^9, 3.4977055769857826`*^9}, {
   3.497706031889305*^9, 3.4977060477964363`*^9}, 3.4977093701475544`*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ofdata", "=", 
   RowBox[{"ExampleData", "[", 
    RowBox[{"{", 
     RowBox[{"\"\<Statistics\>\"", ",", "\"\<OldFaithful\>\""}], "}"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"ofdata", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "1"}], "]"}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{
      "Mean", ",", "Variance", ",", "Skewness", ",", "Kurtosis", ",", 
       "Median", ",", 
       RowBox[{
        RowBox[{"Quantile", "[", 
         RowBox[{"#", ",", ".1"}], "]"}], "&"}], ",", 
       RowBox[{
        RowBox[{"Quantile", "[", 
         RowBox[{"#", ",", ".9"}], "]"}], "&"}]}], "}"}]}], "}"}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.497705451758217*^9, 3.4977055348265643`*^9}, {
  3.4977059668543096`*^9, 3.4977060106380816`*^9}, {3.4977093769134393`*^9, 
  3.4977093830386744`*^9}}],

Cell["", "Spacer"],

Cell["\<\
Numerous visualization functions are included, allowing for various types of \
graphical interpretation of the data. \
\>", "Text",
 CellChangeTimes->{{3.497706305038204*^9, 3.497706345552533*^9}, 
   3.4979762551853647`*^9, {3.531666210611205*^9, 3.531666233340478*^9}}],

Cell["\<\
The following visualizes the distributions of the data as histograms, box\
\[Hyphen]whisker plots, and violin plots.\
\>", "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"ofdata", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "i"}], "]"}], "]"}], ",", 
      RowBox[{"PlotLabel", "\[Rule]", 
       RowBox[{"headers", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"f", ",", 
      RowBox[{"{", 
       RowBox[{
       "Histogram", ",", "BoxWhiskerChart", ",", "DistributionChart"}], 
       "}"}]}], "}"}]}], "]"}], "//", "Grid"}]], "Input",
 CellChangeTimes->{{3.4977049492022123`*^9, 3.4977049523898954`*^9}, {
   3.497705075211609*^9, 3.497705078868186*^9}, 3.4977057903746395`*^9, {
   3.49770595835382*^9, 3.4977059739015903`*^9}}],

Cell["", "Spacer"],

Cell[TextData[{
 "A gallery of statistical visualization functions with links to more \
detailed examples can be found on the",
 ButtonBox[" Statistical Visualization guide page",
  BaseStyle->"Link",
  ButtonData->"paclet:guide/StatisticalVisualization"],
 "."
}], "Text",
 CellDingbat->"\[LightBulb]"],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["\<\
Descriptive Statistics: Multivariate measures and visualization\
\>", "Section"],

Cell[TextData[{
 "This gives the marginal descriptive measures based on the first 4 moments, \
as well as the median and ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "th"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["90", "th"], TraditionalForm]]],
 " percentiles for waiting durations and waiting time."
}], "Text",
 CellChangeTimes->{{3.497705549937003*^9, 3.4977055769857826`*^9}, {
   3.497706031889305*^9, 3.4977060477964363`*^9}, 3.4977093701475544`*^9, {
   3.497709404586377*^9, 3.4977094315561624`*^9}}],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"N", "[", "ofdata", "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{
      "Mean", ",", "Variance", ",", "Skewness", ",", "Kurtosis", ",", 
       "Median", ",", 
       RowBox[{
        RowBox[{"Quantile", "[", 
         RowBox[{"#", ",", ".1"}], "]"}], "&"}], ",", 
       RowBox[{
        RowBox[{"Quantile", "[", 
         RowBox[{"#", ",", ".9"}], "]"}], "&"}]}], "}"}]}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.497705451758217*^9, 3.4977055348265643`*^9}, {
  3.4977059668543096`*^9, 3.4977060106380816`*^9}, {3.4977093769134393`*^9, 
  3.497709402492546*^9}, {3.4977094340406327`*^9, 3.4977094364782267`*^9}}],

Cell["\<\
We could also obtain the correlation between duration and waiting time.\
\>", "MathCaption",
 CellChangeTimes->{{3.497705549937003*^9, 3.4977055769857826`*^9}, {
  3.497706031889305*^9, 3.4977060477964363`*^9}, {3.4977088526304226`*^9, 
  3.497708871537036*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Correlation", "[", "ofdata", "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.4977077101400537`*^9, 3.497707759408201*^9}, {
   3.4977078357714853`*^9, 3.4977078750391207`*^9}, {3.497708546692758*^9, 
   3.497708585957629*^9}, {3.4977087833009667`*^9, 3.4977087850197496`*^9}, 
   3.4977088280674515`*^9}],

Cell["\<\
There are numerous ways to visualize the bivariate data including pointwise \
plots, density projections, and histograms based on binning or kernel density \
estimation.\
\>", "MathCaption",
 CellChangeTimes->{3.5316667938565235`*^9}],

Cell[BoxData[
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"ListPlot", "[", "ofdata", "]"}], ",", 
       RowBox[{"DensityHistogram", "[", 
        RowBox[{"ofdata", ",", "20", ",", "\"\<PDF\>\""}], "]"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Histogram3D", "[", 
        RowBox[{"ofdata", ",", "20", ",", "\"\<PDF\>\""}], "]"}], ",", 
       RowBox[{"SmoothHistogram3D", "[", "ofdata", "]"}]}], "}"}]}], 
    "\[IndentingNewLine]", "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "Large"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5316662700631495`*^9, 3.5316662717293158`*^9}}],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Descriptive Statistics: Categorical charts", "Section"],

Cell["\<\
We might want to decompose the data into categories, for instance based on \
specific ranges of duration.\
\>", "Text",
 CellChangeTimes->{{3.497707490738196*^9, 3.497707542131452*^9}}],

Cell[TextData[{
 Cell[BoxData[
  ButtonBox["BinCounts",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/BinCounts"]], "InlineFormula"],
 " is used here to count the times ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]]],
 " such that ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", "<", "2"}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{"2", "\[LessEqual]", "t", "<", "3"}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{"3", "\[LessEqual]", "t", "<", "4"}], TraditionalForm]]],
 ", and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", "\[GreaterEqual]", "4"}], TraditionalForm]]],
 ", respectively."
}], "MathCaption"],

Cell[BoxData[
 RowBox[{"bc", "=", 
  RowBox[{"BinCounts", "[", 
   RowBox[{
    RowBox[{"ofdata", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "1"}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"0", ",", "2", ",", "3", ",", "4", ",", "10"}], "}"}], "}"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.497707097312764*^9, 3.4977072550386286`*^9}, {
  3.4977100657710257`*^9, 3.4977100695524445`*^9}}],

Cell["\<\
The counts could then be visualized in a bar chart or a pie chart.\
\>", "MathCaption",
 CellChangeTimes->{{3.434987627934633*^9, 3.4349876422478657`*^9}, {
  3.4977076442773066`*^9, 3.497707664497092*^9}}],

Cell[BoxData[
 RowBox[{"GraphicsRow", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"bc", ",", 
       RowBox[{"ChartStyle", "\[Rule]", "\"\<DarkRainbow\>\""}], ",", 
       RowBox[{"ChartLabels", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<t<2\>\"", ",", "\"\<2\[LessEqual]t<3\>\"", ",", 
          "\"\<3\[LessEqual]t<4\>\"", ",", "\"\<t\[GreaterEqual]4\>\""}], 
         "}"}]}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"f", ",", 
       RowBox[{"{", 
        RowBox[{"BarChart", ",", "PieChart"}], "}"}]}], "}"}]}], "]"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", " ", "Large"}]}], "]"}]], "Input"],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Descriptive Statistics: Data transformation", "Section"],

Cell[TextData[{
 "Built\[Hyphen]in smoothers include ",
 Cell[BoxData[
  ButtonBox["MovingAverage",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/MovingAverage"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  ButtonBox["MovingMedian",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/MovingMedian"]], "InlineFormula"],
 ", and ",
 Cell[BoxData[
  ButtonBox["ExponentialMovingAverage",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/ExponentialMovingAverage"]], "InlineFormula"],
 ". Data can be shifted and scaled using ",
 Cell[BoxData[
  ButtonBox["Standardize",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Standardize"]], "InlineFormula"],
 ". Filters of particular interest for signals and image analysis are also \
included."
}], "Text"],

Cell["This gets and plots some historical Dow Jones data.", "MathCaption",
 CellChangeTimes->{{3.435077509556466*^9, 3.435077510322081*^9}, {
  3.4977113511411076`*^9, 3.4977113711420035`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dow", "=", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<^DJI\>\"", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "2010", "}"}], ",", 
       RowBox[{"{", "2011", "}"}]}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"DateListPlot", "[", "dow", "]"}]}], "Input",
 CellChangeTimes->{{3.497710118101495*^9, 3.4977102151839685`*^9}, {
   3.4977102768429813`*^9, 3.497710278811819*^9}, 3.497711390517872*^9, {
   3.5316666109242325`*^9, 3.5316666131974597`*^9}}],

Cell["\<\
Here 25\[Hyphen]term moving averages and moving medians are computed and \
visualized against the original data\
\>", "MathCaption",
 CellChangeTimes->{{3.4977113841894627`*^9, 3.4977114367699437`*^9}, {
  3.4977154507073517`*^9, 3.497715453066863*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"movavgdata", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"dow", "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"13", ";;", 
          RowBox[{"-", "13"}]}], ",", "1"}], "]"}], "]"}], ",", 
      RowBox[{"MovingAverage", "[", 
       RowBox[{
        RowBox[{"dow", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2"}], "]"}], "]"}], ",", "25"}], "]"}]}], 
     "}"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"movmeddata", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"dow", "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"13", ";;", 
          RowBox[{"-", "13"}]}], ",", "1"}], "]"}], "]"}], ",", 
      RowBox[{"MovingMedian", "[", 
       RowBox[{
        RowBox[{"dow", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2"}], "]"}], "]"}], ",", "25"}], "]"}]}], 
     "}"}], "]"}]}], ";"}], "\n", 
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"dow", "[", 
      RowBox[{"[", 
       RowBox[{"13", ";;", 
        RowBox[{"-", "13"}]}], "]"}], "]"}], ",", "movavgdata", ",", 
     "movmeddata"}], "}"}], ",", 
   RowBox[{"Joined", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"False", ",", "True", ",", "True"}], "}"}]}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Automatic", ",", "Thick", ",", "Thick"}], "}"}]}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.497710282593239*^9, 3.4977103227669134`*^9}, {
  3.4977107435826397`*^9, 3.497710777990432*^9}, {3.4977108143983126`*^9, 
  3.4977108285864477`*^9}, {3.4977113792673674`*^9, 3.4977113994088945`*^9}, {
  3.497715291649604*^9, 3.497715309682123*^9}, {3.4977153686081457`*^9, 
  3.4977154360346317`*^9}},
 CellTags->"Data Smoothing"],

Cell["", "Spacer"],

Cell["\<\
A complete set of financial visualization functions is also included, making \
it straightforward to built and work with financial charts.\
\>", "Text",
 CellChangeTimes->{{3.49771091401215*^9, 3.497710956654685*^9}, 
   3.4982347620415154`*^9, {3.5316666326794076`*^9, 3.5316666421103506`*^9}}],

Cell[TextData[{
 "Note that ",
 Cell[BoxData[
  ButtonBox["MovingAverage",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/MovingAverage"]], "InlineFormula"],
 " and ",
 Cell[BoxData[
  ButtonBox["MovingMedian",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/MovingMedian"]], "InlineFormula"],
 " reduce the length of the output list while ",
 ButtonBox["built\[Hyphen]in filter functions",
  BaseStyle->"Hyperlink",
  ButtonData->{"paclet:guide/LinearAndNonlinearFilters", None}],
 " operate in a manner that preserves data length."
}], "Text",
 CellChangeTimes->{{3.49771091401215*^9, 3.497710956654685*^9}, {
  3.4977154760994396`*^9, 3.497715560901199*^9}, {3.531668380568184*^9, 
  3.531668380572184*^9}}],

Cell[TextData[{
 "Other smoothers and transformations can be constructed using functions such \
as ",
 Cell[BoxData[
  ButtonBox["ListCorrelate",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/ListCorrelate"]], "InlineFormula"],
 " and ",
 Cell[BoxData[
  ButtonBox["ListConvolve",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/ListConvolve"]], "InlineFormula"],
 ", and arithmetic and linear algebra functions."
}], "Text",
 CellChangeTimes->{{3.434991101694541*^9, 3.4349911038355494`*^9}, {
  3.4350777351473284`*^9, 3.435077738694158*^9}}],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Descriptive Statistics: Clustering data", "Section"],

Cell["\<\
Clustering of data is often used to separate data into groups, or to try to \
identify subgroups within a data set.\
\>", "Text"],

Cell[TextData[{
 "The main clustering function is ",
 Cell[BoxData[
  ButtonBox["FindClusters",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/FindClusters"]], "InlineFormula"],
 ", which can be used on numeric, binary/Boolean, or string data; for a \
complete list of measures of distance, see the ",
 ButtonBox["Distance and Similarity Measures",
  BaseStyle->"Link",
  ButtonData->"paclet:guide/DistanceAndSimilarityMeasures"],
 " guide page. Used with ",
 Cell[BoxData[
  ButtonBox["FindClusters",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/FindClusters"]], "InlineFormula"],
 ", these define measures for separating data."
}], "Text",
 CellChangeTimes->{{3.4976312868456273`*^9, 3.497631291236449*^9}}],

Cell["\<\
As an example, we will start with samples from 10 bivariate normal \
distributions stored in an Excel spreadsheet.\
\>", "MathCaption",
 CellChangeTimes->{{3.5316669128683853`*^9, 3.5316669358993855`*^9}, {
  3.531666987096386*^9, 3.5316669934833856`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"origclusters", "=", 
   RowBox[{"Import", "[", "\"\<NormalClusters.xls\>\"", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Length", "[", "origclusters", "]"}]}], "Input",
 CellChangeTimes->{{3.5316669554503856`*^9, 3.5316669661373854`*^9}, {
  3.531667012388386*^9, 3.5316670135563855`*^9}, {3.5316670588423853`*^9, 
  3.531667059657386*^9}}],

Cell[TextData[{
 "Next we will mix up the elements of the original data so the data are not \
already grouped, and use ",
 Cell[BoxData[
  ButtonBox["FindClusters",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/FindClusters"]], "InlineFormula"],
 " to identify clusters in the data."
}], "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{"newclusters", "=", 
   RowBox[{"BlockRandom", "[", 
    RowBox[{
     RowBox[{"SeedRandom", "[", "1", "]"}], ";", 
     RowBox[{"RandomSample", "[", 
      RowBox[{"Flatten", "[", 
       RowBox[{"origclusters", ",", "1"}], "]"}], "]"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"clusters", "=", 
   RowBox[{"FindClusters", "[", "newclusters", "]"}]}], ";"}]], "Input"],

Cell[TextData[{
 Cell[BoxData[
  ButtonBox["FindClusters",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/FindClusters"]], "InlineFormula"],
 " identifies 3 distinct clusters, which looks quite reasonable given the \
scatter of the data."
}], "MathCaption"],

Cell[BoxData[
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ListPlot", "[", "origclusters", "]"}], ",", 
      RowBox[{"ListPlot", "[", "clusters", "]"}]}], "}"}], "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", " ", "All"}], ",", 
   RowBox[{"FrameStyle", "\[Rule]", " ", "Thick"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", " ", "Large"}]}], "]"}]], "Input"],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Descriptive Statistics: Cluster hierarchies", "Section"],

Cell[TextData[{
 "A cluster hierarchy can also be visualized using dendrogram plots. The ",
 ButtonBox["Hierarchical Clustering",
  BaseStyle->"Link",
  ButtonData->
   "paclet:HierarchicalClustering/guide/HierarchicalClusteringPackage"],
 " package is needed for this type of visualization."
}], "Text"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<HierarchicalClustering`\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.434993341731686*^9, 3.434993345669816*^9}}],

Cell["Here is some example text, split into string elements.", "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{"textdata", "=", 
   RowBox[{
   "StringSplit", "[", 
    "\"\<This seminar will give a broad overview of statistics in \
Mathematica. Statistics functions and other technologies, such as \
import/export capabilities and visualization functions, as they relate to \
statistical computation will be discussed.\>\"", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.442137335843274*^9, {3.4976312144986362`*^9, 3.4976312153893013`*^9}}],

Cell["\<\
The following generates a dendrogram labeling the leaves with the string \
elements they represent.\
\>", "MathCaption",
 CellChangeTimes->{3.437936802972034*^9}],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"DendrogramPlot", "[", 
    RowBox[{"textdata", ",", 
     RowBox[{"LeafLabels", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{"#", "&"}], ")"}]}], ",", 
     RowBox[{"Orientation", "\[Rule]", "Left"}]}], "]"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", " ", "Large"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.442050362811325*^9, 3.442050373857665*^9}, {
  3.442050452437312*^9, 3.442050468130804*^9}}],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Statistical Distributions", "Section"],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " contains extensive coverage for statistical distributions including:"
}], "Text",
 CellChangeTimes->{{3.531667396481785*^9, 3.5316673978669233`*^9}, {
  3.531667430446181*^9, 3.531667445661702*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 "More than 100 ",
 ButtonBox["named distributions",
  BaseStyle->"Link",
  ButtonData->"paclet:guide/ParametricStatisticalDistributions"]
}], "Item",
 CellChangeTimes->{{3.5316673531864557`*^9, 3.5316673576309*^9}}],

Cell[TextData[{
 "Functions for constructing or ",
 ButtonBox["deriving new distributions",
  BaseStyle->"Link",
  ButtonData->"paclet:guide/DerivedDistributions"]
}], "Item",
 CellChangeTimes->{{3.4976273936145062`*^9, 3.4976273952239327`*^9}, {
  3.497704577482078*^9, 3.497704579841529*^9}, {3.4977201030135636`*^9, 
  3.497720125545823*^9}, {3.4977201764543533`*^9, 3.497720187892366*^9}, {
  3.4982287319288335`*^9, 3.4982287471793213`*^9}}],

Cell[TextData[ButtonBox["Nonparametric distributions",
 BaseStyle->"Link",
 ButtonData->"paclet:guide/NonparametricStatisticalDistributions"]], "Item",
 CellChangeTimes->{{3.4976273936145062`*^9, 3.4976273952239327`*^9}, {
   3.497704577482078*^9, 3.497704579841529*^9}, {3.4977201030135636`*^9, 
   3.497720125545823*^9}, 3.4977201925488243`*^9, {3.4977202532234173`*^9, 
   3.4977202644895473`*^9}, 3.4977203591969147`*^9, {3.49822878979006*^9, 
   3.4982287996341248`*^9}}],

Cell[TextData[{
 "Automated ",
 ButtonBox["estimation",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/FindDistributionParameters"],
 " of distribution parameters"
}], "Item",
 CellChangeTimes->{{3.4976273936145062`*^9, 3.4976273952239327`*^9}, {
  3.497704577482078*^9, 3.497704579841529*^9}, {3.4977201030135636`*^9, 
  3.497720125545823*^9}, {3.4977201939082603`*^9, 3.4977202150810843`*^9}, {
  3.4982288584953833`*^9, 3.498228889402622*^9}, {3.4982289263413043`*^9, 
  3.4982289283413687`*^9}}],

Cell[TextData[{
 "Goodness of fit ",
 ButtonBox["testing",
  BaseStyle->"Link",
  ButtonData->"paclet:guide/HypothesisTests"],
 " for data against statistical distributions or other data sets"
}], "Item",
 CellChangeTimes->{{3.4976273936145062`*^9, 3.4976273952239327`*^9}, {
   3.497704577482078*^9, 3.497704579841529*^9}, {3.4977201030135636`*^9, 
   3.497720125545823*^9}, {3.4977202230189395`*^9, 3.4977202480513105`*^9}, 
   3.498228984934141*^9}],

Cell[TextData[{
 "Numerous additional ",
 ButtonBox["properties",
  BaseStyle->"Link",
  ButtonData->"paclet:guide/ProbabilityAndStatistics"],
 " for distributions"
}], "Item",
 CellChangeTimes->{{3.4976273936145062`*^9, 3.4976273952239327`*^9}, {
  3.497704577482078*^9, 3.497704579841529*^9}, {3.4977201030135636`*^9, 
  3.497720125545823*^9}, {3.4977202936627293`*^9, 3.497720313444865*^9}, {
  3.4982295239415503`*^9, 3.498229540457281*^9}}]
}, Open  ]],

Cell[TextData[{
 "It is important to note that distributions are objects in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " and are operated on by other functions. Whether a distribution is \
discrete, continuous, univariate, multivariate, named, derived, or defined by \
data, functions operate on them in the same way."
}], "Text"],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Statistical Distributions: Distributions and properties", "Section"],

Cell["\<\
Many properties of distributions such as PDF, CDF, mean, variance, and \
characteristic function are available. Built\[Hyphen]in functions for \
probabilities and expectations provide for direct computation of more general \
results.\
\>", "Text",
 CellChangeTimes->{{3.4982190625381966`*^9, 3.498219139025998*^9}, {
  3.531667519605096*^9, 3.5316675987690115`*^9}, {3.5320897925877533`*^9, 
  3.53208979355085*^9}}],

Cell["\<\
These are example PDF plots for univariate and multivariate, continuous, and \
discrete distributions.\
\>", "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Plot", "[", 
       RowBox[{
        RowBox[{"PDF", "[", 
         RowBox[{
          RowBox[{"SkewNormalDistribution", "[", 
           RowBox[{"3", ",", "8", ",", "4.5"}], "]"}], ",", "x"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", 
          RowBox[{"-", "10"}], ",", "30"}], "}"}], ",", 
        RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}], ",", 
      RowBox[{"DiscretePlot", "[", 
       RowBox[{
        RowBox[{"PDF", "[", 
         RowBox[{
          RowBox[{"BinomialDistribution", "[", 
           RowBox[{"50", ",", 
            RowBox[{"2", "/", "5"}]}], "]"}], ",", "x"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "0", ",", "50"}], "}"}]}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Plot3D", "[", 
       RowBox[{
        RowBox[{"PDF", "[", 
         RowBox[{
          RowBox[{"DirichletDistribution", "[", 
           RowBox[{"{", 
            RowBox[{"4", ",", "3.2", ",", "2"}], "}"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "y"}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", "0", ",", "1"}], "}"}], ",", 
        RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
        RowBox[{"Exclusions", "\[Rule]", "None"}], ",", 
        RowBox[{"MeshFunctions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"#3", "&"}], "}"}]}], ",", 
        RowBox[{"ColorFunction", "\[Rule]", "\"\<DeepSeaColors\>\""}]}], 
       "]"}], ",", 
      RowBox[{"DiscretePlot3D", "[", 
       RowBox[{
        RowBox[{"PDF", "[", 
         RowBox[{
          RowBox[{"MultivariatePoissonDistribution", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", 
             RowBox[{"10", ",", "15"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "y"}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "0", ",", "25"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", "0", ",", "25"}], "}"}], ",", 
        RowBox[{"ColorFunction", "\[Rule]", "\"\<DeepSeaColors\>\""}]}], 
       "]"}]}], "}"}]}], "}"}], "//", "GraphicsGrid"}]], "Input",
 CellChangeTimes->{{3.4979822536167765`*^9, 3.4979825489529257`*^9}, {
   3.4982391037007737`*^9, 3.4982391521707644`*^9}, {3.498239197874079*^9, 
   3.4982393118987613`*^9}, {3.498239351287117*^9, 3.49823940575273*^9}, 
   3.498239526591853*^9}],

Cell["This gives a small sampling of properties for distributions.", \
"MathCaption",
 CellChangeTimes->{{3.498219145291904*^9, 3.4982191980598927`*^9}, {
  3.498221056168762*^9, 3.498221077653137*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"dist", "=", 
      RowBox[{"NakagamiDistribution", "[", 
       RowBox[{"\[Mu]", ",", "\[Omega]"}], "]"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"TraditionalForm", "/@", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Mean", "[", "dist", "]"}], ",", 
       RowBox[{"MomentGeneratingFunction", "[", 
        RowBox[{"dist", ",", "t"}], "]"}], ",", 
       RowBox[{"Probability", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Log", "[", "x", "]"}], ">", 
          RowBox[{"1", "/", "2"}]}], ",", 
         RowBox[{"x", "\[Distributed]", "dist"}]}], "]"}], ",", 
       RowBox[{"Expectation", "[", 
        RowBox[{
         RowBox[{"Sqrt", "[", "x", "]"}], ",", 
         RowBox[{"x", "\[Distributed]", "dist"}]}], "]"}]}], "}"}]}]}], "]"}],
   "//", "Column"}]], "Input"],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Statistical Distributions: Probabilities and expectations", "Section"],

Cell[TextData[{
 Cell[BoxData[
  ButtonBox["Probability",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Probability"]], "InlineFormula"],
 " and ",
 Cell[BoxData[
  ButtonBox["Expectation",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Expectation"]], "InlineFormula"],
 " are general functions that rely on symbolic calculus. As with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "\[CloseCurlyQuote]s symbolic calculus functions, there are numeric analogs \
of ",
 Cell[BoxData[
  ButtonBox["Probability",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Probability"]], "InlineFormula"],
 " and ",
 Cell[BoxData[
  ButtonBox["Expectation",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Expectation"]], "InlineFormula"],
 " that use numeric methods to compute results. Numeric methods can often be \
much faster than symbolic methods."
}], "Text"],

Cell["\<\
This numerically computes the previous probability and expectation for \
specific \[Mu] and \[Omega] values.\
\>", "MathCaption",
 CellChangeTimes->{{3.498220864434387*^9, 3.498220898340637*^9}, {
   3.498220943246887*^9, 3.498220953262512*^9}, 3.498234782214036*^9}],

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"dist", "=", 
     RowBox[{"NakagamiDistribution", "[", 
      RowBox[{"1", ",", "5"}], "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"NProbability", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Log", "[", "x", "]"}], ">", 
        RowBox[{"1", "/", "2"}]}], ",", 
       RowBox[{"x", "\[Distributed]", "dist"}]}], "]"}], ",", 
     RowBox[{"NExpectation", "[", 
      RowBox[{
       RowBox[{"Sqrt", "[", "x", "]"}], ",", 
       RowBox[{"x", "\[Distributed]", "dist"}]}], "]"}]}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.4982206466680837`*^9, 3.4982207305904956`*^9}, {
  3.498220772465637*^9, 3.498220792575012*^9}, {3.4982221219196467`*^9, 
  3.4982221220915213`*^9}}],

Cell["\<\
This gives the result symbolically and then gets a numeric approximation for \
comparison.\
\>", "MathCaption"],

Cell[BoxData[{
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"dist", "=", 
     RowBox[{"NakagamiDistribution", "[", 
      RowBox[{"1", ",", "5"}], "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Probability", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Log", "[", "x", "]"}], ">", 
        RowBox[{"1", "/", "2"}]}], ",", 
       RowBox[{"x", "\[Distributed]", "dist"}]}], "]"}], ",", 
     RowBox[{"Expectation", "[", 
      RowBox[{
       RowBox[{"Sqrt", "[", "x", "]"}], ",", 
       RowBox[{"x", "\[Distributed]", "dist"}]}], "]"}]}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"N", "[", "%", "]"}]}], "Input",
 CellChangeTimes->{{3.498220800918762*^9, 3.498220851121887*^9}, {
  3.4982221172946467`*^9, 3.4982221174352713`*^9}}],

Cell["The probability can be visualized with a filled plot.", "MathCaption",
 CellChangeTimes->{{3.498220864434387*^9, 3.498220898340637*^9}, {
  3.498220956590637*^9, 3.498220976731262*^9}, {3.4982227766252403`*^9, 
  3.4982228051265774`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"curves", "=", 
   RowBox[{
    RowBox[{"PDF", "[", 
     RowBox[{
      RowBox[{"NakagamiDistribution", "[", 
       RowBox[{"1", ",", "5"}], "]"}], ",", "x"}], "]"}], " ", 
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{"Boole", "[", 
       RowBox[{
        RowBox[{"Log", "[", "x", "]"}], ">", 
        RowBox[{"1", "/", "2"}]}], "]"}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{"curves", ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "10"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"Filling", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"2", "\[Rule]", "Axis"}], "}"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5316677604241753`*^9, 3.531667776198753*^9}}],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Statistical Distributions: Simulation", "Section"],

Cell[TextData[{
 "It is often important to simulate data by generating random numbers. The ",
 Cell[BoxData[
  ButtonBox["RandomVariate",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/RandomVariate"]], "InlineFormula"],
 " function does this for any distribution in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.498221220543762*^9, 3.498221265637512*^9}}],

Cell["\<\
This generates 1000 random Weibull numbers and shows the histogram of the \
data.\
\>", "MathCaption",
 CellChangeTimes->{{3.498221125465637*^9, 3.498221144621887*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"wdata", "=", 
   RowBox[{"RandomVariate", "[", 
    RowBox[{
     RowBox[{"WeibullDistribution", "[", 
      RowBox[{"5", ",", "10"}], "]"}], ",", 
     SuperscriptBox["10", "3"]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"Histogram", "[", "wdata", "]"}]], "Input",
 CellChangeTimes->{{3.498221112371887*^9, 3.498221115950012*^9}}],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Statistical Distributions: Parameter estimation", "Section"],

Cell[TextData[{
 "In practice, we might have reason to believe that data comes from a \
particular type of distribution but need to estimate the parameters for that \
distribution. The ",
 Cell[BoxData[
  ButtonBox["EstimatedDistribution",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/EstimatedDistribution"]], "InlineFormula"],
 " and ",
 Cell[BoxData[
  ButtonBox["FindDistributionParameters",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/FindDistributionParameters"]], "InlineFormula"],
 " functions perform this type of estimation. ",
 Cell[BoxData[
  ButtonBox["EstimatedDistribution",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/EstimatedDistribution"]], "InlineFormula"],
 " returns a distribution object, while ",
 Cell[BoxData[
  ButtonBox["FindDistributionParameters",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/FindDistributionParameters"]], "InlineFormula"],
 " returns a list of rules of the parameters. The default estimator is \
maximum likelihood, but several moment\[Hyphen]based methods are also \
included."
}], "Text",
 CellChangeTimes->{3.5316678551726494`*^9}],

Cell["\<\
Here parameters are estimated from the previous data set using maximum \
likelihood.\
\>", "MathCaption",
 CellChangeTimes->{{3.498221125465637*^9, 3.498221183137512*^9}, {
  3.498221514201046*^9, 3.498221530638651*^9}}],

Cell[BoxData[
 RowBox[{"wparams", "=", 
  RowBox[{"FindDistributionParameters", "[", 
   RowBox[{"wdata", ",", 
    RowBox[{"WeibullDistribution", "[", 
     RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}]}], "]"}]}]], "Input"],

Cell["\<\
The optimal point can be visualized on a contour or 3D plot of the log\
\[Hyphen]likelihood function.\
\>", "MathCaption",
 CellChangeTimes->{{3.498221125465637*^9, 3.498221205450012*^9}, 
   3.4982347911049457`*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ll", "=", 
   RowBox[{"LogLikelihood", "[", 
    RowBox[{
     RowBox[{"WeibullDistribution", "[", 
      RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], ",", "wdata"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ab", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\[Alpha]", ",", "\[Beta]"}], "}"}], "/.", "wparams"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"GraphicsRow", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ContourPlot", "[", 
      RowBox[{"ll", ",", 
       RowBox[{"{", 
        RowBox[{"\[Alpha]", ",", "3", ",", "7"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Beta]", ",", "8", ",", "12"}], "}"}], ",", 
       RowBox[{"Epilog", "\[Rule]", 
        RowBox[{"Point", "[", "ab", "]"}]}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", "\"\<DeepSeaColors\>\""}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
       RowBox[{"Contours", "\[Rule]", "50"}]}], "]"}], ",", 
     RowBox[{"Show", "[", 
      RowBox[{
       RowBox[{"Plot3D", "[", 
        RowBox[{"ll", ",", 
         RowBox[{"{", 
          RowBox[{"\[Alpha]", ",", "3", ",", "7"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Beta]", ",", "8", ",", "12"}], "}"}], ",", 
         RowBox[{"MeshFunctions", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"#3", "&"}], "}"}]}], ",", 
         RowBox[{"ColorFunction", "\[Rule]", "\"\<DeepSeaColors\>\""}]}], 
        "]"}], ",", 
       RowBox[{"Graphics3D", "[", 
        RowBox[{"Point", "[", 
         RowBox[{"Join", "[", 
          RowBox[{"ab", ",", 
           RowBox[{"{", 
            RowBox[{"ll", "/.", "wparams"}], "}"}]}], "]"}], "]"}], "]"}]}], 
      "]"}]}], "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "Large"}]}], "]"}]}], "Input"],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Statistical Distributions: Derived and formula distributions", "Section"],

Cell["\<\
Derived and formula distributions allow for construction of new distributions \
based on relationships with other distributions or based on defining \
properties of a distribution (e.g., its PDF and support). While these are \
constructs, they are treated just like named distributions. Built\[Hyphen]in \
constructors include the following:\
\>", "Text"],

Cell[BoxData[
 PaneSelectorBox[{False->
  FrameBox[
   StyleBox["\<\"ProbabilityDistribution\"\>", "OverviewSection",
    StripOnInput->False],
   BoxFrame->2,
   FrameMargins->{{15, 15}, {5, 5}},
   FrameStyle->None,
   RoundingRadius->5,
   StripOnInput->False], True->
  TemplateBox[{FrameBox[
     StyleBox[
     "\"ProbabilityDistribution\"", "OverviewSection", StripOnInput -> False, 
      LineColor -> GrayLevel[1], FrontFaceColor -> GrayLevel[1], 
      BackFaceColor -> GrayLevel[1], GraphicsColor -> GrayLevel[1], FontColor -> 
      GrayLevel[1]], Background -> RGBColor[0.811765, 0.117647, 0.145098, 1], 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> None, RoundingRadius -> 
     5, StripOnInput -> False],"\" \[RightGuillemet] \"",FrameBox[
     StyleBox[
     "\"defined by a PDF or other characteristic and the support of the \
distribution\"", "OverviewSection", StripOnInput -> False], Background -> 
     GrayLevel[1], BoxFrame -> 2, FrameMargins -> {{15, 15}, {5, 5}}, 
     FrameStyle -> RGBColor[0.811765, 0.117647, 0.145098, 1], RoundingRadius -> 
     5, StripOnInput -> False]},
   "Row",
   DisplayFunction->(
    RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
   InterpretationFunction->(RowBox[{"Row", "[", 
      RowBox[{"{", 
        RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )]}, Dynamic[
   CurrentValue["MouseOver"]],
  FrameMargins->0,
  ImageSize->Automatic]], "OverviewSection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[BoxData[
 PaneSelectorBox[{False->
  FrameBox[
   StyleBox["\<\"TransformedDistribution\"\>", "OverviewSection",
    StripOnInput->False],
   BoxFrame->2,
   FrameMargins->{{15, 15}, {5, 5}},
   FrameStyle->None,
   RoundingRadius->5,
   StripOnInput->False], True->
  TemplateBox[{FrameBox[
     StyleBox[
     "\"TransformedDistribution\"", "OverviewSection", StripOnInput -> False, 
      LineColor -> GrayLevel[1], FrontFaceColor -> GrayLevel[1], 
      BackFaceColor -> GrayLevel[1], GraphicsColor -> GrayLevel[1], FontColor -> 
      GrayLevel[1]], Background -> RGBColor[0.811765, 0.117647, 0.145098, 1], 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> None, RoundingRadius -> 
     5, StripOnInput -> False],"\" \[RightGuillemet] \"",FrameBox[
     StyleBox[
     "\"distribution of a functional transformation of one or more random \
variates\"", "OverviewSection", StripOnInput -> False], Background -> 
     GrayLevel[1], BoxFrame -> 2, FrameMargins -> {{15, 15}, {5, 5}}, 
     FrameStyle -> RGBColor[0.811765, 0.117647, 0.145098, 1], RoundingRadius -> 
     5, StripOnInput -> False]},
   "Row",
   DisplayFunction->(
    RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
   InterpretationFunction->(RowBox[{"Row", "[", 
      RowBox[{"{", 
        RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )]}, Dynamic[
   CurrentValue["MouseOver"]],
  FrameMargins->0,
  ImageSize->Automatic]], "OverviewSection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[BoxData[
 PaneSelectorBox[{False->
  FrameBox[
   StyleBox["\<\"TruncatedDistribution\"\>", "OverviewSection",
    StripOnInput->False],
   BoxFrame->2,
   FrameMargins->{{15, 15}, {5, 5}},
   FrameStyle->None,
   RoundingRadius->5,
   StripOnInput->False], True->
  TemplateBox[{FrameBox[
     StyleBox[
     "\"TruncatedDistribution\"", "OverviewSection", StripOnInput -> False, 
      LineColor -> GrayLevel[1], FrontFaceColor -> GrayLevel[1], 
      BackFaceColor -> GrayLevel[1], GraphicsColor -> GrayLevel[1], FontColor -> 
      GrayLevel[1]], Background -> RGBColor[0.811765, 0.117647, 0.145098, 1], 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> None, RoundingRadius -> 
     5, StripOnInput -> False],"\" \[RightGuillemet] \"",FrameBox[
     StyleBox[
     "\"distribution with support truncated above or below and rescaled to \
have probability 1\"", "OverviewSection", StripOnInput -> False], Background -> 
     GrayLevel[1], BoxFrame -> 2, FrameMargins -> {{15, 15}, {5, 5}}, 
     FrameStyle -> RGBColor[0.811765, 0.117647, 0.145098, 1], RoundingRadius -> 
     5, StripOnInput -> False]},
   "Row",
   DisplayFunction->(
    RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
   InterpretationFunction->(RowBox[{"Row", "[", 
      RowBox[{"{", 
        RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )]}, Dynamic[
   CurrentValue["MouseOver"]],
  FrameMargins->0,
  ImageSize->Automatic]], "OverviewSection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[BoxData[
 PaneSelectorBox[{False->
  FrameBox[
   StyleBox["\<\"CensoredDistribution\"\>", "OverviewSection",
    StripOnInput->False],
   BoxFrame->2,
   FrameMargins->{{15, 15}, {5, 5}},
   FrameStyle->None,
   RoundingRadius->5,
   StripOnInput->False], True->
  TemplateBox[{FrameBox[
     StyleBox[
     "\"CensoredDistribution\"", "OverviewSection", StripOnInput -> False, 
      LineColor -> GrayLevel[1], FrontFaceColor -> GrayLevel[1], 
      BackFaceColor -> GrayLevel[1], GraphicsColor -> GrayLevel[1], FontColor -> 
      GrayLevel[1]], Background -> RGBColor[0.811765, 0.117647, 0.145098, 1], 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> None, RoundingRadius -> 
     5, StripOnInput -> False],"\" \[RightGuillemet] \"",FrameBox[
     StyleBox[
     "\"distribution with upper and lower tail probabilities concentrated at \
defined censoring points\"", "OverviewSection", StripOnInput -> False], 
     Background -> GrayLevel[1], BoxFrame -> 2, 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> 
     RGBColor[0.811765, 0.117647, 0.145098, 1], RoundingRadius -> 5, 
     StripOnInput -> False]},
   "Row",
   DisplayFunction->(
    RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
   InterpretationFunction->(RowBox[{"Row", "[", 
      RowBox[{"{", 
        RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )]}, Dynamic[
   CurrentValue["MouseOver"]],
  FrameMargins->0,
  ImageSize->Automatic]], "OverviewSection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[BoxData[
 PaneSelectorBox[{False->
  FrameBox[
   StyleBox["\<\"OrderDistribution\"\>", "OverviewSection",
    StripOnInput->False],
   BoxFrame->2,
   FrameMargins->{{15, 15}, {5, 5}},
   FrameStyle->None,
   RoundingRadius->5,
   StripOnInput->False], True->
  TemplateBox[{FrameBox[
     StyleBox[
     "\"OrderDistribution\"", "OverviewSection", StripOnInput -> False, 
      LineColor -> GrayLevel[1], FrontFaceColor -> GrayLevel[1], 
      BackFaceColor -> GrayLevel[1], GraphicsColor -> GrayLevel[1], FontColor -> 
      GrayLevel[1]], Background -> RGBColor[0.811765, 0.117647, 0.145098, 1], 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> None, RoundingRadius -> 
     5, StripOnInput -> False],"\" \[RightGuillemet] \"",FrameBox[
     StyleBox[
     "\"distribution of the \
\\!\\(TraditionalForm\\`\\*SuperscriptBox[\\(k\\), \\(th\\)]\\) order \
statistic for a sample of size \\!\\(TraditionalForm\\`n\\)\"", 
      "OverviewSection", StripOnInput -> False], Background -> GrayLevel[1], 
     BoxFrame -> 2, FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> 
     RGBColor[0.811765, 0.117647, 0.145098, 1], RoundingRadius -> 5, 
     StripOnInput -> False]},
   "Row",
   DisplayFunction->(
    RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
   InterpretationFunction->(RowBox[{"Row", "[", 
      RowBox[{"{", 
        RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )]}, Dynamic[
   CurrentValue["MouseOver"]],
  FrameMargins->0,
  ImageSize->Automatic]], "OverviewSection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[BoxData[
 PaneSelectorBox[{False->
  FrameBox[
   StyleBox["\<\"MixtureDistribution\"\>", "OverviewSection",
    StripOnInput->False],
   BoxFrame->2,
   FrameMargins->{{15, 15}, {5, 5}},
   FrameStyle->None,
   RoundingRadius->5,
   StripOnInput->False], True->
  TemplateBox[{FrameBox[
     StyleBox[
     "\"MixtureDistribution\"", "OverviewSection", StripOnInput -> False, 
      LineColor -> GrayLevel[1], FrontFaceColor -> GrayLevel[1], 
      BackFaceColor -> GrayLevel[1], GraphicsColor -> GrayLevel[1], FontColor -> 
      GrayLevel[1]], Background -> RGBColor[0.811765, 0.117647, 0.145098, 1], 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> None, RoundingRadius -> 
     5, StripOnInput -> False],"\" \[RightGuillemet] \"",FrameBox[
     StyleBox[
     "\"component mixture distribution\"", "OverviewSection", StripOnInput -> 
      False], Background -> GrayLevel[1], BoxFrame -> 2, 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> 
     RGBColor[0.811765, 0.117647, 0.145098, 1], RoundingRadius -> 5, 
     StripOnInput -> False]},
   "Row",
   DisplayFunction->(
    RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
   InterpretationFunction->(RowBox[{"Row", "[", 
      RowBox[{"{", 
        RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )]}, Dynamic[
   CurrentValue["MouseOver"]],
  FrameMargins->0,
  ImageSize->Automatic]], "OverviewSection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[BoxData[
 PaneSelectorBox[{False->
  FrameBox[
   StyleBox["\<\"ParameterMixtureDistribution\"\>", "OverviewSection",
    StripOnInput->False],
   BoxFrame->2,
   FrameMargins->{{15, 15}, {5, 5}},
   FrameStyle->None,
   RoundingRadius->5,
   StripOnInput->False], True->
  TemplateBox[{FrameBox[
     StyleBox[
     "\"ParameterMixtureDistribution\"", "OverviewSection", StripOnInput -> 
      False, LineColor -> GrayLevel[1], FrontFaceColor -> GrayLevel[1], 
      BackFaceColor -> GrayLevel[1], GraphicsColor -> GrayLevel[1], FontColor -> 
      GrayLevel[1]], Background -> RGBColor[0.811765, 0.117647, 0.145098, 1], 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> None, RoundingRadius -> 
     5, StripOnInput -> False],"\" \[RightGuillemet] \"",FrameBox[
     StyleBox[
     "\"parametric mixture distribution\"", "OverviewSection", StripOnInput -> 
      False], Background -> GrayLevel[1], BoxFrame -> 2, 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> 
     RGBColor[0.811765, 0.117647, 0.145098, 1], RoundingRadius -> 5, 
     StripOnInput -> False]},
   "Row",
   DisplayFunction->(
    RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
   InterpretationFunction->(RowBox[{"Row", "[", 
      RowBox[{"{", 
        RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )]}, Dynamic[
   CurrentValue["MouseOver"]],
  FrameMargins->0,
  ImageSize->Automatic]], "OverviewSection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[BoxData[
 PaneSelectorBox[{False->
  FrameBox[
   StyleBox["\<\"ProductDistribution\"\>", "OverviewSection",
    StripOnInput->False],
   BoxFrame->2,
   FrameMargins->{{15, 15}, {5, 5}},
   FrameStyle->None,
   RoundingRadius->5,
   StripOnInput->False], True->
  TemplateBox[{FrameBox[
     StyleBox[
     "\"ProductDistribution\"", "OverviewSection", StripOnInput -> False, 
      LineColor -> GrayLevel[1], FrontFaceColor -> GrayLevel[1], 
      BackFaceColor -> GrayLevel[1], GraphicsColor -> GrayLevel[1], FontColor -> 
      GrayLevel[1]], Background -> RGBColor[0.811765, 0.117647, 0.145098, 1], 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> None, RoundingRadius -> 
     5, StripOnInput -> False],"\" \[RightGuillemet] \"",FrameBox[
     StyleBox[
     "\"multivariate distribution with independent components defined by \
distributions of the components\"", "OverviewSection", StripOnInput -> False],
      Background -> GrayLevel[1], BoxFrame -> 2, 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> 
     RGBColor[0.811765, 0.117647, 0.145098, 1], RoundingRadius -> 5, 
     StripOnInput -> False]},
   "Row",
   DisplayFunction->(
    RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
   InterpretationFunction->(RowBox[{"Row", "[", 
      RowBox[{"{", 
        RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )]}, Dynamic[
   CurrentValue["MouseOver"]],
  FrameMargins->0,
  ImageSize->Automatic]], "OverviewSection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[BoxData[
 PaneSelectorBox[{False->
  FrameBox[
   StyleBox["\<\"MarginalDistribution\"\>", "OverviewSection",
    StripOnInput->False],
   BoxFrame->2,
   FrameMargins->{{15, 15}, {5, 5}},
   FrameStyle->None,
   RoundingRadius->5,
   StripOnInput->False], True->
  TemplateBox[{FrameBox[
     StyleBox["\"MarginalDistribution\"", "OverviewSection", 
      GrayLevel[1], StripOnInput -> False], 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> None, RoundingRadius -> 
     5, Background -> RGBColor[0.811765, 0.117647, 0.145098, 1], StripOnInput -> 
     False],"\" \[RightGuillemet] \"",FrameBox[
     StyleBox[
     "\"lower dimensional distribution obtained from a multivariate \
distribution\"", "OverviewSection", StripOnInput -> False], 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> 
     RGBColor[0.811765, 0.117647, 0.145098, 1], BoxFrame -> 2, RoundingRadius -> 
     5, Background -> GrayLevel[1], StripOnInput -> False]},
   "Row",
   DisplayFunction->(
    RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
   InterpretationFunction->(RowBox[{"Row", "[", 
      RowBox[{"{", 
        RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )]}, Dynamic[
   CurrentValue["MouseOver"]],
  FrameMargins->0,
  ImageSize->Automatic]], "OverviewSection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[BoxData[
 PaneSelectorBox[{False->
  FrameBox[
   StyleBox["\<\"CopulaDistribution\"\>", "OverviewSection",
    StripOnInput->False],
   BoxFrame->2,
   FrameMargins->{{15, 15}, {5, 5}},
   FrameStyle->None,
   RoundingRadius->5,
   StripOnInput->False], True->
  TemplateBox[{FrameBox[
     StyleBox[
     "\"CopulaDistribution\"", "OverviewSection", StripOnInput -> False, 
      LineColor -> GrayLevel[1], FrontFaceColor -> GrayLevel[1], 
      BackFaceColor -> GrayLevel[1], GraphicsColor -> GrayLevel[1], FontColor -> 
      GrayLevel[1]], Background -> RGBColor[0.811765, 0.117647, 0.145098, 1], 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> None, RoundingRadius -> 
     5, StripOnInput -> False],"\" \[RightGuillemet] \"",FrameBox[
     StyleBox[
     "\"multivariate distribution defined by marginal distributions and a \
kernel that defines how they are combined\"", "OverviewSection", StripOnInput -> 
      False], Background -> GrayLevel[1], BoxFrame -> 2, 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> 
     RGBColor[0.811765, 0.117647, 0.145098, 1], RoundingRadius -> 5, 
     StripOnInput -> False]},
   "Row",
   DisplayFunction->(
    RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
   InterpretationFunction->(RowBox[{"Row", "[", 
      RowBox[{"{", 
        RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )]}, Dynamic[
   CurrentValue["MouseOver"]],
  FrameMargins->0,
  ImageSize->Automatic]], "OverviewSection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell["\<\
We will work with several of these in the following examples.\
\>", "Text"],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Statistical Distributions: ProbabilityDistribution", "Section"],

Cell[TextData[{
 Cell[BoxData[
  ButtonBox["ProbabilityDistribution",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/ProbabilityDistribution"]], "InlineFormula"],
 " is the constructor for distributions defined by a PDF or some other \
property. It differs from the other constructor in that it is based on first \
principles while the other constructors are built upon other distributions."
}], "Text",
 CellChangeTimes->{{3.498233926876479*^9, 3.4982339287983913`*^9}, {
  3.4982344999237533`*^9, 3.4982345420657268`*^9}}],

Cell["\<\
This defines a continuous distribution on the interval from 1 to 9.\
\>", "MathCaption",
 CellChangeTimes->{{3.4982332189188256`*^9, 3.498233245947654*^9}}],

Cell[BoxData[
 RowBox[{"probdist", "=", 
  RowBox[{"ProbabilityDistribution", "[", 
   RowBox[{
    FractionBox[
     SqrtBox["11"], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", " ", 
        RowBox[{"ArcTan", "[", 
         FractionBox[
          RowBox[{"4", " ", 
           SqrtBox["11"]}], "17"], "]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", "x", "+", 
        SuperscriptBox["x", "2"]}], ")"}]}]], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "1", ",", "9"}], "}"}]}], "]"}]}]], "Input"],

Cell["", "Spacer"],

Cell[TextData[{
 "Note that the \[FormalX] is just a placeholder variable in the formula. ",
 Cell[BoxData[
  ButtonBox["ProbabilityDistribution",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/ProbabilityDistribution"]], "InlineFormula"],
 " assumes the given density is properly normalized."
}], "Text",
 CellChangeTimes->{{3.498312907183592*^9, 3.4983129464197245`*^9}, {
  3.504287273574974*^9, 3.504287275528149*^9}}],

Cell["\<\
The object is just like any other distribution, though it will usually need \
to rely on general methods which may be slower in general. This is true of \
other constructors as well.\
\>", "Text",
 CellChangeTimes->{{3.4982333525318527`*^9, 3.4982334497489696`*^9}, {
   3.4982353815202656`*^9, 3.498235393847386*^9}, 3.498325460251862*^9}],

Cell["\<\
This is the CDF for the distribution. It is computed by way of an integral \
and takes a little time.\
\>", "MathCaption",
 CellChangeTimes->{{3.4982333319555717`*^9, 3.4982333391580515`*^9}, {
  3.498235404331493*^9, 3.4982354255184507`*^9}}],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"cdf", "=", 
   RowBox[{"CDF", "[", 
    RowBox[{"probdist", ",", "x"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4982327356396656`*^9, 3.4982327421399155`*^9}, {
  3.498233322987625*^9, 3.498233325284294*^9}}],

Cell["Here we visualize the PDF and CDF.", "MathCaption",
 CellChangeTimes->{{3.4982333319555717`*^9, 3.4982333391580515`*^9}, {
  3.4982334732642937`*^9, 3.4982334839672813`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"PDF", "[", 
       RowBox[{"probdist", ",", "x"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", "11"}], "}"}]}], "]"}], ",", 
    RowBox[{"Plot", "[", 
     RowBox[{"cdf", ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", "11"}], "}"}]}], "]"}]}], "}"}], "//", 
  "GraphicsRow"}]], "Input",
 CellChangeTimes->{{3.4982326675901775`*^9, 3.49823267923125*^9}, {
  3.498232716951448*^9, 3.4982327599530993`*^9}, {3.498233462451932*^9, 
  3.498233464108161*^9}}],

Cell["\<\
Observations from the distribution can also be easily generated since there \
are no undefined parameters.\
\>", "MathCaption",
 CellChangeTimes->{{3.4982333319555717`*^9, 3.4982333391580515`*^9}, {
  3.4982334732642937`*^9, 3.4982335225917873`*^9}}],

Cell[BoxData[
 RowBox[{"Histogram", "[", 
  RowBox[{"RandomVariate", "[", 
   RowBox[{"probdist", ",", 
    SuperscriptBox["10", "4"]}], "]"}], "]"}]], "Input"],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Statistical Distributions: Mixture distributions", "Section"],

Cell[TextData[{
 "Mixture distributions play an important role in statistical analysis. \
Component mixtures are defined via ",
 Cell[BoxData[
  ButtonBox["MixtureDistribution",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/MixtureDistribution"]], "InlineFormula"],
 " and parametric mixtures are defined via ",
 Cell[BoxData[
  ButtonBox["ParameterMixtureDistribution",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/ParameterMixtureDistribution"]], "InlineFormula"],
 ". Component mixtures can be used to model data with more than one mode."
}], "Text",
 CellChangeTimes->{{3.498230720006686*^9, 3.498230835166621*^9}}],

Cell["\<\
The following data are waiting times for eruptions of the Old Faithful geyser.\
\>", "MathCaption",
 CellChangeTimes->{{3.4982308432450047`*^9, 3.498230876355439*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"waiting", "=", 
   RowBox[{
    RowBox[{"ExampleData", "[", 
     RowBox[{"{", 
      RowBox[{"\"\<Statistics\>\"", ",", "\"\<OldFaithful\>\""}], "}"}], 
     "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2"}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.4979782038400984`*^9, {3.4979786999905815`*^9, 3.4979787064440365`*^9}, 
   3.497979027912885*^9}],

Cell["", "Spacer"],

Cell["\<\
The times can be modeled as a mixture of two normal distributions.\
\>", "Text",
 CellChangeTimes->{{3.4982308785742598`*^9, 3.4982309046219683`*^9}}],

Cell["\<\
Here is the maximum likelihood estimate for the mixture and a plot of its PDF \
against the data.\
\>", "MathCaption",
 CellChangeTimes->{{3.4982309171848707`*^9, 3.4982309448107543`*^9}}],

Cell[BoxData[
 RowBox[{"mix", "=", 
  RowBox[{"EstimatedDistribution", "[", 
   RowBox[{"waiting", ",", 
    RowBox[{"MixtureDistribution", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"p1", ",", "p2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"NormalDistribution", "[", 
         RowBox[{"m1", ",", "s1"}], "]"}], ",", 
        RowBox[{"NormalDistribution", "[", 
         RowBox[{"m2", ",", "s2"}], "]"}]}], "}"}]}], "]"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.497978205215125*^9, 3.497978227887435*^9}, {
   3.497978268747595*^9, 3.49797829742002*^9}, 3.497978679427355*^9, {
   3.497978710194229*^9, 3.497978711069274*^9}, 3.497979369047785*^9}],

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Histogram", "[", 
    RowBox[{"waiting", ",", "25", ",", "\"\<PDF\>\""}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"PDF", "[", 
      RowBox[{"mix", ",", "x"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "40", ",", "100"}], "}"}]}], "]"}]}], 
  "\[IndentingNewLine]", "]"}]], "Input"],

Cell["", "Spacer"],

Cell["\<\
The fitted component probabilities can be used to estimate the probability \
that a given waiting time came from a particular component.\
\>", "Text",
 CellChangeTimes->{{3.498230968608391*^9, 3.498231025224863*^9}, {
  3.4982348191995945`*^9, 3.4982348223871965`*^9}}],

Cell["\<\
The curve above the hashed red line is for the more likely component.\
\>", "MathCaption",
 CellChangeTimes->{{3.4982310372741284`*^9, 3.4982310624509974`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"pNormal", "[", 
    RowBox[{"x_", ",", "index_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"pvals", ",", "distpdfs"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"pvals", "=", 
       RowBox[{"mix", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"distpdfs", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"PDF", "[", 
          RowBox[{"dist", ",", "x"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"dist", ",", 
           RowBox[{"mix", "[", 
            RowBox[{"[", "2", "]"}], "]"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"pvals", "[", 
        RowBox[{"[", "index", "]"}], "]"}], 
       RowBox[{
        RowBox[{"distpdfs", "[", 
         RowBox[{"[", "index", "]"}], "]"}], "/", 
        RowBox[{"(", 
         RowBox[{"pvals", ".", "distpdfs"}], ")"}]}]}]}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{"FillToLinePlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"pNormal", "[", 
      RowBox[{"x", ",", "1"}], "]"}], ",", 
     RowBox[{"mix", "[", 
      RowBox[{"[", 
       RowBox[{"2", ",", "1"}], "]"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"pNormal", "[", 
      RowBox[{"x", ",", "2"}], "]"}], ",", 
     RowBox[{"mix", "[", 
      RowBox[{"[", 
       RowBox[{"2", ",", "2"}], "]"}], "]"}]}], "}"}], ",", 
   RowBox[{"1", "/", "2"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "40", ",", "100"}], "}"}]}], "]"}]}], "Input"],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Statistical Distributions: Parametric mixtures", "Section"],

Cell[TextData[{
 "In parametric mixtures, one or more of the parameters itself is a random \
variable. This arises often in Bayesian analysis. The parameter\
\[CloseCurlyQuote]s distribution is called a ",
 StyleBox["prior distribution",
  FontSlant->"Italic"],
 " and the resulting distribution is the ",
 StyleBox["posterior distribution",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.4982430709846044`*^9, 3.4982431565649204`*^9}, {
  3.498244386366376*^9, 3.4982443969760904`*^9}}],

Cell[TextData[{
 "This constructs a parametric mixture for a gamma whose scale parameter \
follows a ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Chi]", "2"], TraditionalForm]]],
 " distribution."
}], "MathCaption",
 CellChangeTimes->{{3.4982443552716312`*^9, 3.49824437163153*^9}, {
  3.4982444037263064`*^9, 3.498244428039584*^9}}],

Cell[BoxData[
 RowBox[{"pmdist", "=", 
  RowBox[{"ParameterMixtureDistribution", "[", 
   RowBox[{
    RowBox[{"GammaDistribution", "[", 
     RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], ",", 
    RowBox[{"\[Beta]", "\[Distributed]", 
     RowBox[{"ChiSquareDistribution", "[", "n", "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.498243440933196*^9, 3.4982434718436*^9}, {
  3.4982435286637354`*^9, 3.498243533601899*^9}, {3.498243714101262*^9, 
  3.4982437151638308`*^9}, {3.4982437920750027`*^9, 3.4982438146389465`*^9}, {
  3.4982438673141923`*^9, 3.4982438985033803`*^9}, {3.4982439293641376`*^9, 
  3.498243953099576*^9}}],

Cell["", "Spacer"],

Cell["\<\
Closed form results can sometimes be obtained, but the integrals or sums \
needed to get closed form will be quite difficult in general.\
\>", "Text",
 CellChangeTimes->{{3.498244256440344*^9, 3.4982442893163958`*^9}}],

Cell["\<\
In this particular case, the PDF can be obtained in closed form.\
\>", "MathCaption",
 CellChangeTimes->{{3.4982442935040293`*^9, 3.4982443069107084`*^9}}],

Cell[BoxData[
 RowBox[{"pdf", "=", 
  RowBox[{"PDF", "[", 
   RowBox[{"pmdist", ",", "x"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.498243735305744*^9, 3.4982437515411587`*^9}}],

Cell[TextData[{
 "The PDF can be plotted if numeric values are substituted for ",
 Cell[BoxData[
  StyleBox["\[Alpha]", "TR"]], "InlineFormula"],
 " and ",
 Cell[BoxData[
  StyleBox["n", "TI"]], "InlineFormula"],
 "."
}], "MathCaption",
 CellChangeTimes->{{3.49824431180149*^9, 3.498244343255622*^9}}],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"pdf", "/.", "\[InvisibleSpace]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Alpha]", "\[Rule]", "5"}], ",", 
      RowBox[{"n", "\[Rule]", "3"}]}], "}"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "100"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input"],

Cell["", "Spacer"],

Cell["\<\
Even if closed forms cannot be obtained, observations can be simulated.\
\>", "Text",
 CellChangeTimes->{{3.4982444411806297`*^9, 3.4982444720878687`*^9}}],

Cell["Here are 100,000 random numbers based on the distribution.", \
"MathCaption",
 CellChangeTimes->{{3.4982444768067703`*^9, 3.498244497526087*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"pmvals", "=", 
   RowBox[{"RandomVariate", "[", 
    RowBox[{
     RowBox[{"pmdist", "/.", "\[InvisibleSpace]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[Alpha]", "\[Rule]", "5"}], ",", 
        RowBox[{"n", "\[Rule]", "3"}]}], "}"}]}], ",", 
     SuperscriptBox["10", "5"]}], "]"}]}], ";"}], "\n", 
 RowBox[{"Histogram", "[", 
  RowBox[{"pmvals", ",", "Automatic", ",", "\"\<PDF\>\"", ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "100"}], "}"}], ",", "All"}], "}"}]}]}], 
  "]"}]}], "Input"],

Cell["\<\
Any descriptive measures can now be computed to get an estimate of the \
measures for the distribution.\
\>", "MathCaption",
 CellChangeTimes->{{3.498244500698043*^9, 3.49824453691772*^9}}],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"f", "[", "pmvals", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{"Mean", ",", "Variance", ",", "Skewness", ",", "Kurtosis"}], 
      "}"}]}], "}"}]}], "]"}]], "Input"],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["\<\
Statistical Distributions: Multivariate derived distributions\
\>", "Section"],

Cell[TextData[{
 Cell[BoxData[
  ButtonBox["ProductDistribution",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/ProductDistribution"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  ButtonBox["MarginalDistribution",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/MarginalDistribution"]], "InlineFormula"],
 ", and ",
 Cell[BoxData[
  ButtonBox["CopulaDistribution",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/CopulaDistribution"]], "InlineFormula"],
 " allow for direct construction or decomposition of multivariate \
distributions. ",
 Cell[BoxData[
  ButtonBox["MarginalDistribution",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/MarginalDistribution"]], "InlineFormula"],
 " picks off components of a multivariate distribution."
}], "Text",
 CellChangeTimes->{{3.4982412793606153`*^9, 3.498241316830324*^9}, {
  3.498241930471033*^9, 3.4982419548622828`*^9}, {3.498242695724998*^9, 
  3.498242705068987*^9}}],

Cell["Here is a general trivariate normal distribution.", "MathCaption",
 CellChangeTimes->{{3.4982419595499024`*^9, 3.4982419722846036`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"md", "=", 
   RowBox[{"MultinormalDistribution", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["\[Mu]", "1"], ",", 
       SubscriptBox["\[Mu]", "2"], ",", 
       SubscriptBox["\[Mu]", "3"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["\[CapitalSigma]", "11"], ",", 
         SubscriptBox["\[CapitalSigma]", "12"], ",", 
         SubscriptBox["\[CapitalSigma]", "13"]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["\[CapitalSigma]", "12"], ",", 
         SubscriptBox["\[CapitalSigma]", "22"], ",", 
         SubscriptBox["\[CapitalSigma]", "23"]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["\[CapitalSigma]", "13"], ",", 
         SubscriptBox["\[CapitalSigma]", "23"], ",", 
         SubscriptBox["\[CapitalSigma]", "33"]}], "}"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.4982413415965834`*^9, 3.498241438317809*^9}, {
  3.4982414764594107`*^9, 3.498241531273314*^9}}],

Cell["\<\
This gives the 2\[Hyphen]dimensional marginal distributions.\
\>", "MathCaption",
 CellChangeTimes->{{3.498241974847169*^9, 3.4982419972852435`*^9}}],

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{"MarginalDistribution", "[", 
       RowBox[{"md", ",", "i"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{"Subsets", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", 
        RowBox[{"{", "2", "}"}]}], "]"}]}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.4982415399610367`*^9, 3.498241579368295*^9}, {
  3.4982416288070607`*^9, 3.4982416335571823`*^9}}],

Cell["\<\
This gives the 1\[Hyphen]dimensional marginal distributions.\
\>", "MathCaption",
 CellChangeTimes->{{3.498241999660304*^9, 3.498242019942074*^9}}],

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{"univariates", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"MarginalDistribution", "[", 
        RowBox[{"md", ",", "i"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4982414414116383`*^9, 3.4982414627559347`*^9}, {
  3.498241587837262*^9, 3.498241621588126*^9}}],

Cell["", "Spacer"],

Cell[TextData[{
 Cell[BoxData[
  ButtonBox["ProductDistribution",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/ProductDistribution"]], "InlineFormula"],
 " constructs a multivariate distribution from marginals. The distribution \
will have no correlation between components."
}], "Text",
 CellChangeTimes->{{3.498242044661456*^9, 3.4982420867250333`*^9}, 
   3.498242763148599*^9}],

Cell["\<\
Comparing the covariance for the product of univariate marginals with that of \
the original distribution shows that the correlation structure is removed.\
\>", "MathCaption",
 CellChangeTimes->{{3.498242112741324*^9, 3.498242159742527*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"product", "=", 
   RowBox[{"Apply", "[", 
    RowBox[{"ProductDistribution", ",", 
     RowBox[{"univariates", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "2"}], "]"}], "]"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"MatrixForm", "[", 
    RowBox[{"Covariance", "[", "dd", "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"dd", ",", 
     RowBox[{"{", 
      RowBox[{"product", ",", "md"}], "}"}]}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.4982416374479065`*^9, 3.4982416954650173`*^9}, {
  3.498242089756361*^9, 3.4982421040067253`*^9}, {3.498244557668251*^9, 
  3.4982445695279303`*^9}}],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Statistical Distributions: Copulas", "Section"],

Cell[TextData[{
 "Copulas are effectively a type of multivariate mixture where marginal \
distributions are combined to make a multivariate distribution by way of a \
kernel function. Several common named ",
 ButtonBox["kernels",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/CopulaDistribution"],
 " are built in."
}], "Text",
 CellChangeTimes->{{3.5316679963967705`*^9, 3.531667996414772*^9}, {
  3.531668026970827*^9, 3.5316680387660065`*^9}}],

Cell["\<\
Here we generate some data from a bivariate normal distribution with \
correlation 0.5.\
\>", "MathCaption",
 CellChangeTimes->{{3.498242365638423*^9, 3.498242394936048*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[ScriptCapitalD]o", "=", 
   RowBox[{"BinormalDistribution", "[", ".5", "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"BlockRandom", "[", 
    RowBox[{
     RowBox[{"SeedRandom", "[", "987", "]"}], ";", 
     RowBox[{"RandomVariate", "[", 
      RowBox[{"\[ScriptCapitalD]o", ",", "100"}], "]"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.4982397890918913`*^9, 3.4982398261392407`*^9}, {
   3.4982398882181606`*^9, 3.498239977234925*^9}, {3.4982401827544174`*^9, 
   3.4982401972391634`*^9}, {3.498240762581761*^9, 3.498240763800542*^9}, 
   3.498240886256802*^9}],

Cell["\<\
This estimates a Clayton copula distribution with Cauchy marginals from the \
data.\
\>", "MathCaption",
 CellChangeTimes->{{3.498242365638423*^9, 3.4982424698754663`*^9}}],

Cell[BoxData[
 RowBox[{"\[ScriptCapitalD]e", "=", 
  RowBox[{"EstimatedDistribution", "[", 
   RowBox[{"data", ",", 
    RowBox[{"CopulaDistribution", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\"\<Clayton\>\"", ",", "c"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"CauchyDistribution", "[", 
         RowBox[{"m1", ",", "s1"}], "]"}], ",", 
        RowBox[{"CauchyDistribution", "[", 
         RowBox[{"m2", ",", "s2"}], "]"}]}], "}"}]}], "]"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4982397890918913`*^9, 3.4982398261392407`*^9}, {
  3.4982398882181606`*^9, 3.498239977234925*^9}, {3.4982401827544174`*^9, 
  3.4982401972391634`*^9}, {3.498240762581761*^9, 3.498240763800542*^9}, {
  3.498240886256802*^9, 3.49824089849149*^9}}],

Cell["", "Spacer"],

Cell["\<\
Plotting the PDF and CDF for the original normal distribution and the fitted \
Clayton copulas shows the difference in the structures of the two \
distributions.\
\>", "MathCaption",
 CellChangeTimes->{{3.498242507048293*^9, 3.4982425537057376`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Partition", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Plot3D", "[", 
       RowBox[{"f", ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", 
          RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", 
          RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
        RowBox[{"MeshFunctions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"#3", "&"}], "}"}]}], ",", 
        RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
        RowBox[{"Mesh", "\[Rule]", "20"}], ",", 
        RowBox[{"PlotPoints", "\[Rule]", "20"}], ",", 
        RowBox[{"ColorFunction", "\[Rule]", "\"\<SouthwestColors\>\""}]}], 
       "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"f", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"PDF", "[", 
           RowBox[{"\[ScriptCapitalD]o", ",", 
            RowBox[{"{", 
             RowBox[{"x", ",", "y"}], "}"}]}], "]"}], ",", 
          RowBox[{"PDF", "[", 
           RowBox[{"\[ScriptCapitalD]e", ",", 
            RowBox[{"{", 
             RowBox[{"x", ",", "y"}], "}"}]}], "]"}], ",", 
          RowBox[{"CDF", "[", 
           RowBox[{"\[ScriptCapitalD]o", ",", 
            RowBox[{"{", 
             RowBox[{"x", ",", "y"}], "}"}]}], "]"}], ",", 
          RowBox[{"CDF", "[", 
           RowBox[{"\[ScriptCapitalD]e", ",", 
            RowBox[{"{", 
             RowBox[{"x", ",", "y"}], "}"}]}], "]"}]}], "}"}]}], "}"}]}], 
     "]"}], ",", "2"}], "]"}], "//", "GraphicsGrid"}]], "Input",
 CellChangeTimes->{{3.4982397890918913`*^9, 3.4982398261392407`*^9}, {
  3.4982398882181606`*^9, 3.498239977234925*^9}, {3.4982401827544174`*^9, 
  3.4982401972391634`*^9}, {3.498240384103322*^9, 3.4982403917910185`*^9}, {
  3.4982408317085304`*^9, 3.4982408652406387`*^9}}],

Cell["", "Spacer"],

Cell["\<\
The PDFs show more differences, while the CDF for the copula of Cauchy\
\[CloseCurlyQuote]s seems to basically just be more spread out.\
\>", "Text",
 CellChangeTimes->{{3.498242490969756*^9, 3.498242503923213*^9}, {
  3.498242560080901*^9, 3.4982426099571776`*^9}, {3.498308263446607*^9, 
  3.4983082850413246`*^9}}],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Statistical Distributions: Nonparametric distributions", "Section"],

Cell[TextData[{
 "Distributions based on data include empirical distributions, kernel density \
estimates, survival distributions, and histogram\[Hyphen]based distribution \
objects. These distributions have different constructors but are represented \
by ",
 Cell[BoxData[
  ButtonBox["DataDistribution",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/DataDistribution"]], "InlineFormula"],
 " objects."
}], "Text",
 CellChangeTimes->{3.531668069448075*^9}],

Cell["\<\
This constructs an empirical distribution for time to failure for aircraft \
windows.\
\>", "MathCaption",
 CellChangeTimes->{{3.4982313651599584`*^9, 3.4982314102580376`*^9}, {
  3.4982315185809355`*^9, 3.4982315318947134`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"glass", "=", 
   RowBox[{"ExampleData", "[", 
    RowBox[{"{", 
     RowBox[{"\"\<Statistics\>\"", ",", "\"\<AirplaneGlass\>\""}], "}"}], 
    "]"}]}], ";"}], "\n", 
 RowBox[{"emp", "=", 
  RowBox[{"EmpiricalDistribution", "[", "glass", "]"}]}]}], "Input",
 CellChangeTimes->{{3.4979797230702066`*^9, 3.4979798316204767`*^9}, {
   3.4979800276111236`*^9, 3.49798004328341*^9}, 3.497980087690797*^9, 
   3.4979802366164837`*^9, {3.4979808531743126`*^9, 3.4979808600806065`*^9}, 
   3.4982186056617727`*^9}],

Cell["\<\
This constructs kernel density estimate for the data\[CloseCurlyQuote]s \
distribution.\
\>", "MathCaption",
 CellChangeTimes->{{3.4982313651599584`*^9, 3.4982314102580376`*^9}, {
  3.4982315185809355`*^9, 3.498231552396682*^9}}],

Cell[BoxData[
 RowBox[{"kern", "=", 
  RowBox[{"SmoothKernelDistribution", "[", "glass", "]"}]}]], "Input",
 CellChangeTimes->{{3.4979797230702066`*^9, 3.4979798316204767`*^9}, {
   3.4979800276111236`*^9, 3.49798004328341*^9}, 3.497980087690797*^9, 
   3.4979802366164837`*^9, {3.4979808531743126`*^9, 3.4979808600806065`*^9}, 
   3.4982186056617727`*^9}],

Cell["\<\
The empirical distribution is a discrete distribution on the actual data \
values, while the kernel density estimate is smoothed over a continuous range.\
\>", "MathCaption",
 CellChangeTimes->{{3.4982313651599584`*^9, 3.4982314102580376`*^9}, {
  3.4982315185809355`*^9, 3.4982316090265226`*^9}, {3.4982319370292335`*^9, 
  3.498231937357373*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"pdfs", "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"DiscretePlot", "[", 
      RowBox[{
       RowBox[{"PDF", "[", 
        RowBox[{"emp", ",", "x"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "glass"}], "}"}], ",", 
       RowBox[{"FillingStyle", "\[Rule]", 
        RowBox[{"Opacity", "[", ".6", "]"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"10", ",", "60"}], "}"}], ",", "All"}], "}"}]}], ",", 
       RowBox[{"PlotLabel", "\[Rule]", "\"\<PDF\>\""}]}], "]"}], ",", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"PDF", "[", 
        RowBox[{"kern", ",", "x"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "10", ",", "60"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"ColorData", "[", 
            RowBox[{"1", ",", "2"}], "]"}], ",", "Thick"}], "}"}], "}"}]}]}], 
      "]"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"cdfs", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"CDF", "[", 
        RowBox[{"emp", ",", "x"}], "]"}], ",", 
       RowBox[{"CDF", "[", 
        RowBox[{"kern", ",", "x"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "10", ",", "60"}], "}"}], ",", 
     RowBox[{"Exclusions", "\[Rule]", "None"}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<CDF\>\""}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Thick"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"GraphicsRow", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"pdfs", ",", "cdfs"}], "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "Large"}]}], "]"}]}], "Input"],

Cell["", "Spacer"],

Cell[TextData[{
 Cell[BoxData[
  ButtonBox["EmpiricalDistribution",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/EmpiricalDistribution"]], "InlineFormula"],
 " can be used directly to perform bootstrap estimates by generating random \
samples via ",
 Cell[BoxData[
  ButtonBox["RandomVariate",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/RandomVariate"]], "InlineFormula"],
 "."
}], "Text",
 CellChangeTimes->{{3.498307980225212*^9, 3.498308022838467*^9}}],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Statistical Distributions: Survival distributions", "Section"],

Cell[TextData[{
 Cell[BoxData[
  ButtonBox["SurvivalDistribution",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/SurvivalDistribution"]], "InlineFormula"],
 " is specifically designed for estimating survival distributions from any \
combination of censored and uncensored survival data. The glass failure times \
are a type of uncensored survival data, so they could also be modeled by ",
 Cell[BoxData[
  ButtonBox["SurvivalDistribution",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/SurvivalDistribution"]], "InlineFormula"],
 "."
}], "Text",
 CellChangeTimes->{{3.498231616183185*^9, 3.498231699484858*^9}, 
   3.498231792755855*^9, {3.498238649392269*^9, 3.4982386628301125`*^9}, {
   3.498307976193575*^9, 3.4983079772405505`*^9}, {3.49830992230058*^9, 
   3.498310001428112*^9}}],

Cell["\<\
The data are not censored, so Kaplan\[Hyphen]Meier product limit and Nelson\
\[Hyphen]Aalen cumulative hazard estimates would be reasonable.\
\>", "MathCaption",
 CellChangeTimes->{{3.4983078144124203`*^9, 3.4983078741525297`*^9}, 
   3.498309987240158*^9}],

Cell[BoxData[
 RowBox[{"kmest", "=", 
  RowBox[{"SurvivalDistribution", "[", 
   RowBox[{"glass", ",", 
    RowBox[{"Method", "\[Rule]", "\"\<KaplanMeier\>\""}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4983073122127037`*^9, 3.4983074067904387`*^9}, {
  3.4983074830691013`*^9, 3.4983074841161437`*^9}, {3.498307527669986*^9, 
  3.4983075298734636`*^9}, {3.4983077234349375`*^9, 3.49830775440666*^9}, {
  3.498309903706235*^9, 3.4983099061125617`*^9}}],

Cell[BoxData[
 RowBox[{"naest", "=", 
  RowBox[{"SurvivalDistribution", "[", 
   RowBox[{"glass", ",", 
    RowBox[{"Method", "\[Rule]", "\"\<NelsonAalen\>\""}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4983073122127037`*^9, 3.4983074067904387`*^9}, {
  3.4983074830691013`*^9, 3.4983074841161437`*^9}, {3.498307527669986*^9, 
  3.4983075298734636`*^9}, {3.4983077234349375`*^9, 3.49830775440666*^9}, {
  3.498309903706235*^9, 3.4983099061125617`*^9}}],

Cell["\<\
Here we see slight differences in the estimates by way of survival curves.\
\>", "MathCaption",
 CellChangeTimes->{{3.4983078805750217`*^9, 3.498307910781046*^9}}],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"SurvivalFunction", "[", 
      RowBox[{"kmest", ",", "x"}], "]"}], ",", 
     RowBox[{"SurvivalFunction", "[", 
      RowBox[{"naest", ",", "x"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "10", ",", "60"}], "}"}], ",", 
   RowBox[{"Exclusions", "\[Rule]", "None"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4983074094631863`*^9, 3.4983076774752007`*^9}, {
  3.4983077614385853`*^9, 3.4983077910039234`*^9}}],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Hypothesis Testing", "Section"],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " includes a framework for ",
 ButtonBox["hypothesis testing",
  BaseStyle->"Link",
  ButtonData->"paclet:guide/HypothesisTests"],
 " covering tests of location, variance or scale, and distributional goodness \
of fit. These include parametric and nonparametric tests. The general \
framework includes the following features:"
}], "Text",
 CellChangeTimes->{{3.4983167438462715`*^9, 3.498316764596006*^9}, {
  3.4983171220363903`*^9, 3.4983171445525923`*^9}, {3.4983172085386047`*^9, 
  3.4983172243046336`*^9}, {3.498317595535674*^9, 3.4983175958794374`*^9}, {
  3.498317633162119*^9, 3.498317641084298*^9}, {3.4983224454704247`*^9, 
  3.4983224589393396`*^9}, {3.531668114164546*^9, 3.5316681174088707`*^9}}],

Cell[CellGroupData[{

Cell["\<\
functions that automatically choose a test based on the data and assumptions \
of the test\
\>", "Item",
 CellChangeTimes->{{3.4976273936145062`*^9, 3.4976273952239327`*^9}, {
   3.497704577482078*^9, 3.497704579841529*^9}, {3.49823406581734*^9, 
   3.4982340946774535`*^9}, {3.498317245008399*^9, 3.4983172806657896`*^9}, {
   3.4983173636528206`*^9, 3.4983173759657145`*^9}, 3.5316681281429434`*^9}],

Cell["functions for common named tests", "Item",
 CellChangeTimes->{{3.4976234941113987`*^9, 3.4976235056114726`*^9}, {
  3.497627289845561*^9, 3.497627291533115*^9}, {3.4977043213957586`*^9, 
  3.497704336818127*^9}, {3.498234103412052*^9, 3.498234129584597*^9}, {
  3.4983172735718126`*^9, 3.498317316166926*^9}}],

Cell["\<\
control over the alternative hypothesis and significance level\
\>", "Item",
 CellChangeTimes->{{3.4976234941113987`*^9, 3.4976235056114726`*^9}, {
  3.497627289845561*^9, 3.497627291533115*^9}, {3.4977043213957586`*^9, 
  3.497704336818127*^9}, {3.498234103412052*^9, 3.498234129584597*^9}, {
  3.4983172735718126`*^9, 3.4983173450741005`*^9}}],

Cell[TextData[{
 "numerous properties for results including ",
 Cell[BoxData[
  StyleBox["p", "TI"]], "InlineFormula"],
 "\[Hyphen]values, test statistics, tables, conclusions, etc."
}], "Item",
 CellChangeTimes->{{3.4976234941113987`*^9, 3.4976235056114726`*^9}, {
  3.497627289845561*^9, 3.497627291533115*^9}, {3.4977043213957586`*^9, 
  3.497704336818127*^9}, {3.498234103412052*^9, 3.498234129584597*^9}, {
  3.4983172735718126`*^9, 3.4983173450741005`*^9}, {3.498317391653716*^9, 
  3.498317395513215*^9}, {3.498317711352621*^9, 3.4983177469008613`*^9}, {
  3.4983178161066437`*^9, 3.4983178183879814`*^9}}],

Cell["\<\
objects containing test information allowing for ease of report generation\
\>", "Item",
 CellChangeTimes->{{3.4976234941113987`*^9, 3.4976235056114726`*^9}, {
  3.497627289845561*^9, 3.497627291533115*^9}, {3.4977043213957586`*^9, 
  3.497704336818127*^9}, {3.498234103412052*^9, 3.498234129584597*^9}, {
  3.4983172735718126`*^9, 3.4983173450741005`*^9}, {3.498317391653716*^9, 
  3.498317395513215*^9}, {3.498317711352621*^9, 3.498317851748637*^9}}]
}, Open  ]],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Hypothesis Testing: Tests of location", "Section"],

Cell[TextData[{
 "In parametric tests, hypotheses are written in terms of some parameter, say \
\[Theta]. The null hypothesis ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["H", "0"], TraditionalForm]]],
 " assumes the true value of \[Theta] is a predetermined value ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Theta]", "0"], TraditionalForm]]],
 ", and the alternative hypothesis ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["H", "a"], TraditionalForm]]],
 " is that the true value of \[Theta] differs from ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Theta]", "0"], TraditionalForm]]],
 " in some way."
}], "Text",
 CellChangeTimes->{3.532094908988535*^9, 3.5320959447380953`*^9},
 CellTags->"Testing Framework"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["H", "0"], TraditionalForm]]],
 ": ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Theta]", "=", 
    SubscriptBox["\[Theta]", "0"]}], TraditionalForm]]],
 "\n",
 Cell[BoxData[
  FormBox[
   SubscriptBox["H", "a"], TraditionalForm]]],
 ": \[Theta] and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Theta]", "0"], TraditionalForm]]],
 " differ in some specified way"
}], "DisplayFormula",
 CellTags->"Testing Framework"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["H", "0"], TraditionalForm]]],
 " is rejected in favor of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["H", "a"], TraditionalForm]]],
 " if there is significant evidence against ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["H", "0"], TraditionalForm]]],
 ". "
}], "Text",
 CellTags->"Testing Framework"],

Cell["For a two\[Hyphen]sided test, write:", "Text",
 CellTags->"Testing Framework"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["H", "0"], TraditionalForm]]],
 ": ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Theta]", "=", 
    SubscriptBox["\[Theta]", "0"]}], TraditionalForm]]],
 "\n",
 Cell[BoxData[
  FormBox[
   SubscriptBox["H", "a"], TraditionalForm]]],
 ": ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Theta]", "\[NotEqual]", 
    SubscriptBox["\[Theta]", "0"]}], TraditionalForm]]]
}], "DisplayFormula",
 CellTags->"Testing Framework"],

Cell["\<\
The probabilities can be visualized as follows.\
\>", "Text",
 CellChangeTimes->{{3.5320949415057864`*^9, 3.532094957332369*^9}, {
  3.532095459412567*^9, 3.5320954975953856`*^9}},
 CellTags->"Testing Framework"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJztmXk01e3770WmBhUys7chFWUjNnvTvm5DikwVhcxFRcZklqFIpqRkyFRJ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        "], {{{}, 
          {RGBColor[0, 0, 1], EdgeForm[None], 
           GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwl1HdslVUYwOFLsUVpKQUp0IpAHRgEQe1QtAOrFjdtGVEqCFXUbulwVaWA
gAwRNW4FcSQMJ4kLwgxqxC1xT1ATQXElCGpAnzf948nvPef2jn7fuTenuqmy
MSmRSHShvEtnz+6aSCw09Keep+3N1B91lB6lOzjSfA33mreSZJ7IleY5rOVP
yuyV6gTaeIofON1+tmbRn370JZM+8fr05izG08qTfM9pnttLRzOOFp5gFwUe
y9BqZvMif3Cu/RJdzHr+Zay9Sm1mBTvJt9dT72FLXBvrCUwzv0OaeSqzzC/w
O+dYF+vxehMfmDP0KhaZj9YZrIvPpP/oJVqhd2oObbxpfbt2oyqeY71A+1HH
49a36Xeap+l6l55AOx9Zz9feXM3d1oO0hc2Jzhs9Pj6/8Vi9gbfNqXoFHeZs
beR5829xHsxF+j494/6y0Pwaf3Oxdbm+QYp5EteZl/MtudY9dCmb+C/uWbxf
nCue41dK7RXG/8urHOAie2O1iWV8w6n20nRKXAueZW+cE/tnxnWlkcf4mlPs
p+pkbuUZfomzY/+M+Pw08ChfcbL97nHW4/2p5xG+ZKTHjtDD6RZnmAup42G+
YIS/SYkzygXU8hCfc5LHkvVybmENP1Niv0DPp4YH+Yzh9g/TKtpZzR6K7efr
HbzC/vgc9s7Ta3mATxlmr2ucETZyiMq4R7qd7uYp3GxexW6KrPP0PdLN1cw3
D4j7ysvmv+J/M4/R10k2Xxa/B+a+Wsv95k840Ry/MUPiffjQ3Euns8Q8UJvZ
YD5IRbyWHqPX85Z5blx3Jsf3yzpLG1hp7tCftFBzdYkex428az0vzl98f5ln
vSh+w2jiJetZui+uvZbpYh1MK9us58Q94NL4TsU110xquC/OlH6sQ/V/NL6T
LQ==
             "]]]}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, {}, 
          {GrayLevel[0], LineBox[CompressedData["
1:eJwl1H9w13McwPEv1ma/7Jf9alFDOuVHtRBlpBoR2sg1v9omW5JmM7T8qqZs
a5ly+Zn8qjsKxZ3f5+eJo1K4ilAUd+Vn3FHqxON1/njs+Xq/v9u+n30+731L
6xqrph2USCQu8iV6nC8b9XZdpNdqPu3UW0/QJNp437pF+9BFhfUY/VNn6Uva
qCXMY651rWbGzDrr6XoM91BmPVx36kx9Wq/XYlrNV2oqc/jI+mY9impzpf6j
b9JsPjJ+p/kazeFT8ww9loPN/XWT3s8UcwEN5mrtwWrzOZxn/ktf5gZzL+42
1+lhfGIewhnmXfpMvA9XWafxsfkyqswH9C26OYQB9jbrA0zmXM63t0dfoZ2T
Kbf3oy7nVi4niePtf6EPxnOKe88pnGn/J13BbVxBD06w/6U+FH9z/G2cSjIn
em2LPsx1cR0MJYVDSeUk3/OVPsJUxnIaaQz02te6OJ4ZF3A6Z9n/WZ+NMxXP
kHQG2f9GH2UaFzKMEfZ/0ee4I+4jGQy2v1WXxJmK8xrvb2+vvkpHnB3Otver
Ps+dTORie//q29xLJmX2tulj8VzjGVkn84F5XFy/+W99jU6uts5ifTxrRpp/
05Vx/eaezIz303TWmG/Ro6kxXxL/XLwjN2pvFpjrNTfOFJ/F89V+dMf5irOl
38a90Mfj2WghHTTFWdAU7uJD65u0lPlUxn3VfTpbX9cmPSL+H82TNJsN5lbt
S7l5lO7WVcyixjqDteZaxsdnBe+aF5IV59T6O32CZqoS/3+m7Nc36IpzyWh7
v+sLcU3UkR3n1v52fTLuTzyzODvkxBn12g59ipa4l3FOyCWPw8mngEKKKKZn
nGE/+70ujXsT1x5nhAr7f+iLtMXz5dL4bOA98300mPP43FwSZ938Q5wrXaZT
tYhO/gMfnJLk
            "]], 
           LineBox[{118, 348, 264, 200, 86, 336, 252, 188, 141, 67, 327, 243, 
            179, 132, 100, 28, 314, 230, 166, 119, 87, 68, 29, 30, 31, 32, 33,
             34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 
            315, 231, 167, 120, 88, 69, 328, 244, 180, 133, 101, 343, 259, 
            195, 148, 360, 276, 212, 380, 296, 400, 50}]}, 
          {GrayLevel[0], LineBox[CompressedData["
1:eJwl1He8zmUYB+D3nGMrEkKKTiRUNmmgRAMNo11CGZXQjoa2iqY9s/fee++9
R8Pee+/RdX/64/K97/t9ft7X83s8qQ2a12qWlEgkRvujPX8lJxLfUDIlkagk
88lF8gGZSWaVk2U5+YEsLNfIinKn55PlMH0Z2VgWkMtlBVlK5pKz5X3yM3m3
3CAfkgs8f07dm9L6V2SqXCrvJLt6uiwvP5FF5Tp5zXMZ1WPVzSikXhXfQV71
fPklxdSbZAfr/5bfxveS33yxzMwN6inyQ3ZZl6Ifrm5CQfWK+G3kVs+Rn7PQ
uvOyD6/GnpDD5zNkSxJk0o+Tzbmfjp75R37Hw1zHbrM01o1Qvxl7yCKzC7Iv
dSlCEp3M/5XfU5nr2WO2mIvqfrwWe0Qync23yjY8Qhb2mi2hC9v0P1Al3jH7
zJbSlW50Z7v5j1SNfWK/2TJ6sEP/E4+SjQNmy7mk7k897iKFnuY7ZVse40YO
mq3gsnoA9eNskIZe5rtkOx6Pc8Ahs7T2aqT6Lcqy0uyKHEgD7iFtvFfrxssW
cY7507rd8meeiHcVv9maqfIjDvs8nX6U+u046+TRz5VfsMrnV+UgXud2ny2L
80VO9UzZKv696vUyXbxf9QT5bpxl9Wr5ILfEuY8zIb+SxeXmOBOyt+/Zo/6F
Uvpq8ja5JJ6VOWPv5DR5r/w4zodcKyvJI55PL0fH/sim8g65MtZzs3qebB17
pd4oV3vmmhzMG/F7uMlns+SnpI+zpp8o36NCnHvP7JW/Uj3Wc9Qsg3Vj1O9Q
njVx0ZgNUTekBBnibJvvk79Rg1wcM1tLP/brf+dJcnPcbB39GcBABjGYIQxl
GMMZwUhGJf1/x41hLOMYzwQmcsDf+wdPxbvmhNl6JnFQ356nY884abaByRzS
d+AZ8nLKbCNTOKzvSM14z5w228RUjug7UYtbOWO2mWkc1XemNvk4a7aF6RzT
d6EO+TkXdzYzOK7vyrNxTjgf9xwzOaHvxnOkciHuH2ZxUt+d5+MsczHuFmZz
St+DFyjApbhHmMNpfU9epCCX4x5hLmf0vXgpzhxX4v5gHmfj/yAvU4ircX+Q
5GwM1TeiJBnJYjZJvk/F2Cv9Qvl1nB/1Flk57njP/wdGGeNT
            "]]}, 
          {RGBColor[0, 0, 1], LineBox[{402, 401}]}}, {{}, {}, {}, {}}}], 
       GraphicsComplexBox[CompressedData["
1:eJztmXk01e3390WFBhUyc46xokxxOIaztyFFhuaQuUhkSEKGDCEZSkqGTJUU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        "], {{{}, 
          {RGBColor[1, 0, 0], Opacity[0.6], EdgeForm[None], 
           GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwtznkvFwAABuCfPge5ylWOzFkiWeSqHDVnitybs0KOjs1RckZYmyOUI5GZ
z+ex9cezvXu3d3vDG7vLu64EAoEgFqiiXdFBsnzOD874xBqndPKBFU54drlj
jGX+kkclrYzwjT/c4j4VtDDMIockkUs5zbz7/+uARO5RxiuGmGefBHJ4QhOD
zLFHPNk8ppEBZvnNTe7yiJe8ZYZf3CCLUl7whq/sEscdSmjgNdPsEMttinlO
P1/YJoZMiqinj8/8JJoMCqmjlym2iCKdh9TSwySbXCeNAmroZoINrhFJBOGE
EcpVQkgln2q6GGedYJ7SxihLHJFCB+/5zjEP+Mgq/7gA+i88yA==
             "]]]}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, {}, 
          {GrayLevel[0], 
           LineBox[{1, 156, 131, 108, 87, 68, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 
            11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 
            27, 157, 132, 109, 179, 154, 181}], 
           LineBox[{88, 177, 152, 129, 69, 175, 150, 127, 106, 52, 173, 148, 
            125, 104, 85, 28, 158, 133, 110, 89, 70, 53, 29, 30, 31, 32, 33, 
            34, 35, 36, 159, 134, 111, 90, 71, 54, 37, 160, 135, 112, 91, 72, 
            55, 38, 161, 136, 113, 92, 73, 56, 39, 162, 137, 114, 93, 74, 57, 
            40, 163, 138, 115, 94, 75, 58, 41, 164, 139, 116, 95, 76, 59, 42, 
            165, 140, 117, 96, 77, 60, 43, 166, 141, 118, 97, 78, 61, 44, 167,
             142, 119, 98, 79, 62, 45, 168, 143, 120, 99, 80, 63, 46, 169, 
            144, 121, 100, 81, 64, 47, 170, 145, 122, 101, 82, 65, 48, 171, 
            146, 123, 102, 83, 66, 49, 172, 147, 124, 103, 84, 67, 174, 149, 
            126, 105, 86, 176, 151, 128, 107, 178, 153, 130, 180, 155, 182, 
            50}]}, 
          {GrayLevel[0], LineBox[CompressedData["
1:eJwl1GW4VVUUheFzL93deUkRlTQQQVFCEEFRBAVRaTAQBQQMDBAsyi4UCxSU
suju7u6W7o53Pv74+MYca5+9D2uve1Jad2nyQlIikRjrn4mcSE4kfpWbcTuu
zUf4Ga7It/I2bslfcSM+x205Pd/AK/kJ/ojr80luw825Bu/jp/gHbsKXuD0f
8vgiPM/8OL/N9fg4P4hq8i5uxcP4Ib7ApVFB3sCfoKF8Jp6BWvJ//Asela/w
JM9Jkn+L56KOfJQr4TZ5O3+NDChnXsUD0UA+Fd8NNeX9/CMOu19R83z5ndgT
3Gnezd+hDCqaN/KneBqTY6t1o+QOqIyMuFG3mgfFHuKI64rpFsh90RhlMUWf
Sj9a7ogqyISj+uL6hXK/2KN4J5iqT63/Xe6EqsiMY/ppSGPtD3PneMfIguP6
6ZiBmUjrmjH6Z2OfkBUn9LOQLvn/M/Qcbkc2nNSn6BfJ7+Lh2E/M1qfXj5Of
xx3IjlP6EvrFcv84G7EfmKPPoB8vx2Gthhwor1vDg9ECp11XUrdEHoBH4pp4
r7pN/FmcY8x1XUbdBLlLvKv4zuYd/A1y4ibzWh4SZx13mw/wTzjj86XMS+X3
cL98Is4Xqst7+Pv4/8oX417xfuXN/HmcZfkst8a9ce7jTPAIbspX40zE34Hn
ZOI/zc35Ra7Lx+KzXD32jnfyk/xtnA8+z+04F9/M62J/eCg/wKfjetwjH+Sf
Y6/ky3zWM0vLy+T34/vgLvNeHh73i7Nm3sJfoA3m+0xm3V9y17geuXGLbj1/
jFY457oyuuXyB3gsrsECfRb93/JLqIE8OK9fiKzW/jG/jJrIiwv6RViMJViK
ZViOFViJVViNNViLdViPDdiITdiMLcjmGf+6b7d418iHi/qtyG5torl77Bny
45J+G3JYm2TugVoogMv67chpbbL5lXjPKIgr+h3IZW2KuSfuQyFc1e9EbmtT
zb1QG4VxTb8LeaxNM/dGHRRJih8zvzWU19p0+dU4JyiKJOyxls/aDPk11EMx
JGOvtfzWZsqvx1lGcaTCPmsFrM2S30B9pCA19lsraG223AcNUAJpcMBaIWtz
5DfjzKEk0uKgtcLW5spvoSFKIR3K6lfwh2iGCqiq28pfom3slfkwj4zzI1/j
jvEb777XAcYh1g8=
            "]]}, 
          {RGBColor[1, 0, 0], Opacity[0.6], 
           LineBox[{184, 183}]}}, {{}, {}, {}, {}}}]},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, False},
      AxesOrigin->{0, 0},
      Epilog->{{
         AbsoluteDashing[{10, 8}], 
         LineBox[{{9.34, 0}, {9.34, 0.0928690609970643}}]}, {
         InsetBox[
          FormBox[
           StyleBox[
            RowBox[{"P", " ", 
              RowBox[{"(", 
                RowBox[{"X", ">", 
                  OverscriptBox["\[Theta]", "^"]}], ")"}]}], 12, StripOnInput -> 
            False], TraditionalForm], {23, 0.045}]}, {
         ArrowBox[{{22, 0.038}, {20, 0.015}}]}, {
         InsetBox[
          FormBox[
           StyleBox[
            RowBox[{"P", " ", 
              RowBox[{"(", 
                RowBox[{"X", "<", 
                  OverscriptBox["\[Theta]", "^"]}], ")"}]}], 12, StripOnInput -> 
            False], TraditionalForm], {18, 0.075}]}, {
         ArrowBox[{{17, 0.068}, {14.5, 0.047}}]}},
      ImageSize->300,
      Method->{"AxesInFront" -> True},
      PlotLabel->FormBox[
       "\"P\[Hyphen]value = 2P(X > \\!\\(\\*OverscriptBox[\\(\[Theta]\\), \
\\(^\\)]\\))\"", TraditionalForm],
      PlotRange->{All, All},
      PlotRangeClipping->True,
      PlotRangePadding->{Automatic, Automatic},
      Ticks->{{{15.987179172105261`, 
          FormBox[
           StyleBox[
            OverscriptBox["\[Theta]", "^"], 12, StripOnInput -> False], 
           TraditionalForm]}}, None}], {160., -97.34035322810844}, 
     ImageScaled[{0.5, 0.5}], {300, 185.41019662496845`}], InsetBox[
     GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJzFmnk0lV8b9w0VGszzdI65kCnTQefahpSxUsqYIVRkSEKGzJKhRDIkJClk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        "], {{{}, 
          {RGBColor[0, 0, 1], EdgeForm[None], 
           GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwt0mlPDwAABvB/hfoaPoOibLm3CkvCJsd0MCkyR02FFTkmhQ3VUmk5oqGc
WyraKllyDAmTorLlPj5Av6YXvz3b8/Z5pqduT8wKDgQCQdyYzCuKo/IXDbxn
E7f4zH5qecFSirjMG9aTQwWPmU0q+VTzlEWsIotTtBPGEtaRTTndRLGQlWzj
JA8JJZIFrGArJ3jANGYxn0QyKaWNqSxmLbsp4xEzmcdyMiihlSnEsYZdnKWL
CFLIo4pe5pLAFo7TQggb2cd5nhPLQS7RRxI7OUMn4Rye2IG3JNPEELmc4wlz
KOQCr1jGdQZIp5j7TOx7jy8c4SrvSOMmn9hLDc+I4Q4jHOAHF3nN6sD/n3xk
B185TQcz+MddRjnET+rpZwN/aGSQPXyjkh6i+ctthingO3W8JJ7fXOMDmxnj
GM2MAzmWY5E=
             "]]]}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, {}, 
          {GrayLevel[0], 
           LineBox[{1, 186, 138, 234, 103, 221, 173, 241, 78, 211, 163, 237, 
            128, 228, 180, 243, 61, 203, 155, 236, 120, 224, 176, 242, 95, 
            216, 168, 239, 133, 230, 182, 244, 51, 196, 148, 235, 113, 223, 
            175, 88, 213, 165, 238, 130, 229, 181, 71, 207, 159, 124, 226, 
            178, 99, 218, 170, 135, 231, 183, 2, 187, 139, 104, 222, 174, 79, 
            212, 164, 129, 62, 204, 156, 121, 225, 177, 96, 217, 169, 134, 52,
             197, 149, 114, 89, 214, 166, 131, 72, 208, 160, 125, 100, 3, 188,
             140, 105, 80, 63, 205, 157, 122, 97, 53, 198, 150, 115, 90, 73, 
            4, 189, 141, 106, 81, 64, 54, 199, 151, 116, 91, 74, 5, 190, 142, 
            107, 82, 65, 55, 6, 191, 143, 108, 83, 66, 56, 7, 192, 144, 109, 
            84, 67, 57, 200, 152, 117, 92, 75, 8, 193, 145, 110, 85, 68, 206, 
            158, 123, 98, 58, 201, 153, 118, 93, 215, 167, 132, 76, 209, 161, 
            126, 227, 179, 101, 219, 171, 240, 136}], 
           LineBox[{232, 184, 245, 9, 194, 146, 111, 86, 69, 59, 10, 11, 12, 
            13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 
            29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 
            45, 46, 47, 48, 49, 195, 147, 112, 87, 70, 60, 202, 154, 119, 94, 
            77, 210, 162, 127, 102, 220, 172, 137, 233, 185, 246, 50}]}, 
          {GrayLevel[0], LineBox[CompressedData["
1:eJwl1Hecz3UcB/DfHbL33s7eWzZ3NpFyySjrkAaOQiIVkYimFZcRWSG7SXvv
SaWiRaWElszn++GPp9fr8/l8z32/n+/neykZmX3GJiUSia3+OSVTkxOJX/TF
8gk5U9ZjFeOMJ8oKZPGV8f2yOWvoZny9LMxS3jeeIxuzmiXG02R1VvC98cOy
NWupYzxIXsKjvGI8WzZkvn6brMxyvjV+ULZkpJ4pS/GZPk82i9+hT5e1+Vlf
INvyv+dMk7+aW8ssvT7j9UmyIl/r3blBL8IH+lzZJO5Nv0PW4Ae9LoP1nLwa
e8IUvQrf6dcxTi/N5/pKTruHDsa/6eu4mR7caK4oH+pLqccQ41y8pj/AKM74
+Y7mjurruYXLqM9Q87l5PfYo3glnXd/J3O/6BibQkwacs9bZ2h/6xnjH9KIh
560lZBJdXHNMPhn7xOU0Ipmu1v6Um7iV3jRmmPk8vKE/FPtJNrqZOy43M5kr
aEKG+by8GWcj9oPs8S7MnZBb4hxwJTeZK8ZH+jKaMtw4H2/pj8Q1jDcuwxf6
KnLEXhuflE/Fu4p7Nq7EAb0Po/XifKxncadekx/1ZozQ8/O2fq9sxAJ9qqzK
wXhe2YrR8X5lWfbp8+WlPK7PiHPPSg4bL5TtWBffQbxT+ZdcknzxG71HNoif
ZWrsnUzhMb6J8yFbxLdLuvEYWYJlfGJ8n2wa1+t3yVr8FHsl28R96SNlAd6J
++F2vRqH4v+Ls6aXY7++mpxxloz/ltvieq5irLmSfKovp3l8C8YFeVdfFNeQ
K86buX/kdqbRlxbkjnNm7V+5I747rqYlechLPvJTgIIUojBFKEoxilOCkpSi
NGUoS7k4r37Hf3JnvGv60YrycTatnZK7Ys/oT2sqxDmMvydyN9MZQBsqxjmy
dlo+He+ZgbSlEunWzshnuJtraEdK7J21s/JZZnIt7akc+2LtnHyOWQwilSqx
L9bOy+fjnDCYNKrG81hL8II+myF0oFo8j/kk9sRZZigdqR7PYz6ZvfochtGJ
GvE85rPxoj6XDDpTM57HfHZeijPHcLpQK57HfA5e1ucxgq6MMleI9/TFZDLB
uDxf6mtir/S6HInzI9uzntrGFwANC8KP
            "]]}, 
          {RGBColor[0, 0, 1], LineBox[{248, 247}]}}, {{}, {}, {}, {}}}], 
       GraphicsComplexBox[CompressedData["
1:eJztmXk0le3Xx5XKUKmQmXOMFUVkOoaztyFFqJQyZigqMiSZZQjJUCIZQiop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        "], {{{}, 
          {RGBColor[1, 0, 0], Opacity[0.6], EdgeForm[None], 
           GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwl03eMz2ccwPHfWck56+y9z+zhjpq1x7kj1KrWdgSlKUqN1h6hw4qR2Ls2
UdSKPUJit1ZtqRZFtDWD8nrij9e9n+fzJPf9fb+/769Yav/WX6aJRCJRVPCn
Pm/DIG0kkijN7TPQkOP2r6lhPUf38x+V7L/QKWznPqXNmmlPJrKJ2xQxT9AU
ejCBjdyisLNKmkwq49nATQo5q6hN6c441nODgs4qaBLdGMs6rlPAWbw2oStj
WMs18jv7QBvThdGs4Sr5nJXXRnRmFKu5Ql5n5bQhnRjJKn4nj7Oy2oCOjOAn
LpPbWRmtTwe+ZSWXyOWstNbjM75hBRfJ6ayU1uVThrOcC+RwFqd1aM8wlnGe
7M5KagmKU4yi4TsIzzo80/DswjMKzyLcc7i3cA/hs4bPFK4drhH+F7X5hKEs
5TdiXSNWP6IdQ1jCr2Rzlk378SO/cI9S5rV0Brt5RHmztvo1izlHVrOsOpt9
/EtFs756mOdUsf9Bt3GXOPuamlbrcdT6JVWtp+vb8Fmtd4XvXR9qOW2jyRpF
HQ6Gd0afaqIO1qb6RmvqovBu6FnNolm0maanAcfsk/SVVtdZGn5ktdlr+U/k
/e/tc02jdTlk/YzK1t/r/9Sy3qp/UdK6hh7hBR/aT9OdPKCsfWs9wBMS7Afp
Qs6Q2T6zzmQPj4k366PfsYU/w/tiVl2nsoO/KWPWSr9iAafJZJZJezOZn7kT
3jXzavoxA5nPKWLMY7QXk9jMH+G9NK+qLRnAPE6S0TxjuE9a0J+5nCDaWbSm
aDreASoGgk4=
             "]]]}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, {}, 
          {GrayLevel[0], 
           LineBox[{1, 263, 202, 151, 109, 76, 51, 2, 3, 4, 5, 6, 7, 8, 264, 
            203, 152, 110, 77, 52, 288, 227, 176, 134, 101, 300, 239, 188, 
            146, 311, 250, 199}], LineBox[CompressedData["
1:eJwV0nfwz3UcwPGfpDtbqOz87OL3s7fwy/j5/TgrJMnslHF2dhlxhFQX3WXP
sh2yTxq4upOZvZ2ReVbojDxefzx+z/e4+30/n/f7k9itX+u+GRISEsr5k8KL
pJPZWmbdo9/Tj+ZUJUuw95fOpD8tqEai9Yu6lon0IGuwvldnMYCWVKeY9Uu6
jkl8RLZgfZ/OZiCtKGPtum5mGjUobu2yrucLPibJ2m3dzrdkD9b26xwGUdH8
vv5Ka94wv6Fb+Cre0/yR7qImJcyv6E/UNn6mk6ls/EB/p57xC/Q0TtY7+jNv
xQEzPZ5ZH2uq/qFvayaaksM8hx7QhjpXa+lTbaKDtZL+q431N62rGUjjHfM3
9aY20q1aR//Xr+N+jP/T3dQ3zkgt45L6j25gClXMH+pOelHe/K7uYAY5g7WD
Oo9PaENZa7d0G9/EOVHK2lXdyFR6kytYP6TzGULbeFZeDvb+1gUMpV2cIbnJ
Q15e4VVeIx/5KUBBClGYIrxO0fgu41uL7yXuMv6X3zisCxnGu3GWcRbxG/aO
6CKG0z7uNt4lftveUV3MCN6Ls6R0PJO9Y7qEkXQghTLxrPaO6w+M4v24+/ju
4h3sndAf+ZSONIi7jHezd1KX8hkfxLcRZx3vbO+ULmM0neLeKRdnYe+0LmcM
neObISnOyN4ZXcFYupBKcpydvbO6knF0pUl8A3Gm9s7pKj6nG2lUiLO2d15X
M57upFMx7sDeBV3DBD6kaZyZ9Wu6iS/pE//L2j39he+oaf5E/4wzMX6JZlQy
fw4NaIFG
            "]]}, 
          {GrayLevel[0], LineBox[CompressedData["
1:eJwl1He8zXUYB/BzNVRSGkQpbtJOhWS0iEoRrk3Wte/FtffK3txrj4yKaBel
QoO4Ze+ZkUoolDRQ6v28+uN9n+/n+Z5zz/l9z/P7JadmpHRISiQS7/pTjSk5
EonHOcF5ea86mD9ZI69Tu3KaB/iesZxjtv1P1db8QhEOMoKznLS/Te3L75Tm
KJn8zYv2F6svcIr87GcY39nbpPbkDCU5wniW2VutduBuDjM6PkN/lzqQRzjO
RKrrT1WfiM+13qcOIdt6vdqNB5kjf6a24TYOMTK+m/52tR9lGCQvURtRIM5E
3qz24iGWy2vUDO7hD7kG06zL84/1V8zlc7ktReMM5cF8YN2YG/lBXkEK0+UK
XLD+mnkM4UO9JtwUZxS/CTWZIT/Jv9ZreZmh1GKmfkUSrJNfYRi1qUNdZtmr
RBLr5VcZTj1e0nuKHGyQ5zOCpXJTCvJjnCf1mS0/zUVslBcwko/kZtwcsxHn
QQPmyM9wMZvk1/jCOo3b+VUexcfWqdzCsXgN2dYduTfmWG4YZ21dmUvYLG9Q
u1OchfJKNZ07YtblHWp/ysZsyZ+ozSnEAYbHfOlvUXtTKq6XCayM31ftxH0x
y4zhL/3dMfcxEzzKT0yKmYj7IH5T9VlOcinfMDTeyxb7G9Ue/EaJmA/GcZ5F
9lep7eJ8uJNvGRWvt7dTHUC5OCuy4nvpL1NbUDi+j7xV7cPDrIpZUztTjLNy
o5gl6+fIyVb5db60bs9dnJHHsty6Jcn8HK+hccybXIXL2Ca/wTiaxJzpVeVy
tstvMp6mNCOV5rSgJa1oTRvakkY67WhPPPAy6EgnOse8+t/PcwU75LeYQJeY
Tb1q5GKn/DaZdI051KvOleyS3yGLbizUq0Fudif9/4ydSHcW6aVwFXvk95hE
jzg7vZpczV75fSbTM85FrxZ52CcvZgq94lz0anNNzIm8hKn0juvRq8O17I9n
CtPoE9ejV5frYpbj+cF0+sb16NXjeg7G/RzPEfrF9ejVJy+H4t6N5wj943r0
GpAvZi7uy3h+MCCuR68hN3A47qV4frBCbsWtnJBXs9a6C/dzTt6jDuKxmB8m
c4GB9v4DIhf3DA==
            "]]}, 
          {RGBColor[1, 0, 0], Opacity[0.6], 
           LineBox[{334, 333}]}}, {{}, {}, {}, {}}}]},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, False},
      AxesOrigin->{0, 0},
      Epilog->{{
         AbsoluteDashing[{10, 8}], 
         LineBox[{{9.34, 0}, {9.34, 0.0928690609970643}}]}, {
         InsetBox[
          FormBox[
           StyleBox[
            RowBox[{"P", " ", 
              RowBox[{"(", 
                RowBox[{"X", ">", 
                  OverscriptBox["\[Theta]", "^"]}], ")"}]}], 12, StripOnInput -> 
            False], TraditionalForm], {23, 0.045}]}, {
         ArrowBox[{{22, 0.038}, {20, 0.015}}]}, {
         InsetBox[
          FormBox[
           StyleBox[
            RowBox[{"P", " ", 
              RowBox[{"(", 
                RowBox[{"X", "<", 
                  OverscriptBox["\[Theta]", "^"]}], ")"}]}], 12, StripOnInput -> 
            False], TraditionalForm], {2.2, 0.075}]}, {
         ArrowBox[{{2.2, 0.068}, {2.9, 0.04}}]}},
      ImageSize->300,
      Method->{"AxesInFront" -> True},
      PlotLabel->FormBox[
       "\"P\[Hyphen]value = 2P(X < \\!\\(\\*OverscriptBox[\\(\[Theta]\\), \
\\(^\\)]\\))\"", TraditionalForm],
      PlotRange->{All, All},
      PlotRangeClipping->True,
      PlotRangePadding->{Automatic, Automatic},
      Ticks->{{{4.865182051925329, 
          FormBox[
           StyleBox[
            OverscriptBox["\[Theta]", "^"], 12, StripOnInput -> False], 
           TraditionalForm]}}, None}], {480., -97.34035322810844}, 
     ImageScaled[{0.5, 0.5}], {300, 185.41019662496845`}]}, {}},
  ContentSelectable->True,
  ImageSize->{652., 206.68070645621688`},
  PlotRangePadding->{6, 5}]], "Picture",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{3.5321076510842533`*^9},
 CellTags->"Testing Framework"],

Cell[TextData[{
 "For one\[Hyphen]sided tests, you might want to test if \[Theta] is greater \
(",
 Cell[BoxData[
  FormBox[
   SubscriptBox["H", "a"], TraditionalForm]]],
 ": ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Theta]", ">", 
    SubscriptBox["\[Theta]", "0"]}], TraditionalForm]]],
 ") or less (",
 Cell[BoxData[
  FormBox[
   SubscriptBox["H", "a"], TraditionalForm]]],
 ": ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Theta]", "<", 
    SubscriptBox["\[Theta]", "0"]}], TraditionalForm]]],
 ") than the assumed value ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Theta]", "0"], TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->{{3.5320952829375534`*^9, 3.532095315101985*^9}, 
   3.532095437898416*^9},
 CellTags->"Testing Framework"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJztmXk01e3390WFBioyc44hFWWKwzGcvQ0pMlQakLlIZEgyyywZSkqGTJUU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       "], {{{}, 
         {RGBColor[1, 0, 0], Opacity[0.6], EdgeForm[None], 
          GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwtzXkvFgAABvCXz5FEB4kOK+SmKZWcsTlyn6/NFSpEtancucqxUVGRc6jP
52fzx2979mzPnoj6zuKO0EAgEMIcS7QpgsTL/1nlhA8sc0Q77/jGIWVnO4ZZ
ZJ8HPKeFIebZ5Q7ZlNDM4Pn3DrfJopgmBpjlL7fIpIhG3vCFbW6SQSENvGaG
LeJIp4B6XjHNH2JJI586+pniNzdI5Rm19DHJL2JIIY8aeplgk+sk85RqXjLO
BtHc5wkv6GGMn0SRxGOq6OYzP7hGIrlU0sUnvnOVBB5RQScfWecKl4kkgkuE
c5Ew7vGQcjoYZY0LlNLKWxbY4y5BRvjKATmscMx7/nEKheE9wg==
            "]]]}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, {}, 
         {GrayLevel[0], 
          LineBox[{1, 156, 131, 108, 87, 68, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 
           11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27,
            157, 132, 109, 88, 177}], 
          LineBox[{152, 181, 129, 179, 154, 69, 175, 150, 127, 106, 52, 173, 
           148, 125, 104, 85, 28, 158, 133, 110, 89, 70, 53, 29, 30, 31, 32, 
           33, 34, 35, 36, 159, 134, 111, 90, 71, 54, 37, 160, 135, 112, 91, 
           72, 55, 38, 161, 136, 113, 92, 73, 56, 39, 162, 137, 114, 93, 74, 
           57, 40, 163, 138, 115, 94, 75, 58, 41, 164, 139, 116, 95, 76, 59, 
           42, 165, 140, 117, 96, 77, 60, 43, 166, 141, 118, 97, 78, 61, 44, 
           167, 142, 119, 98, 79, 62, 45, 168, 143, 120, 99, 80, 63, 46, 169, 
           144, 121, 100, 81, 64, 47, 170, 145, 122, 101, 82, 65, 48, 171, 
           146, 123, 102, 83, 66, 49, 172, 147, 124, 103, 84, 67, 174, 149, 
           126, 105, 86, 176, 151, 128, 107, 178, 153, 130, 180, 155, 182, 
           50}]}, 
         {GrayLevel[0], LineBox[CompressedData["
1:eJwl1GW4VVUUheFzL93deUkRlTQQQVFCEEFRBAVRaTAQBQQMDBAsyi4UCxSU
suju7u6W7o53Pv74+MYca5+9D2uve1Jad2nyQlIikRjrn4mcSE4kfpWbcTuu
zUf4Ga7It/I2bslfcSM+x205Pd/AK/kJ/ojr80luw825Bu/jp/gHbsKXuD0f
8vgiPM/8OL/N9fg4P4hq8i5uxcP4Ib7ApVFB3sCfoKF8Jp6BWvJ//Asela/w
JM9Jkn+L56KOfJQr4TZ5O3+NDChnXsUD0UA+Fd8NNeX9/CMOu19R83z5ndgT
3Gnezd+hDCqaN/KneBqTY6t1o+QOqIyMuFG3mgfFHuKI64rpFsh90RhlMUWf
Sj9a7ogqyISj+uL6hXK/2KN4J5iqT63/Xe6EqsiMY/ppSGPtD3PneMfIguP6
6ZiBmUjrmjH6Z2OfkBUn9LOQLvn/M/Qcbkc2nNSn6BfJ7+Lh2E/M1qfXj5Of
xx3IjlP6EvrFcv84G7EfmKPPoB8vx2Gthhwor1vDg9ECp11XUrdEHoBH4pp4
r7pN/FmcY8x1XUbdBLlLvKv4zuYd/A1y4ibzWh4SZx13mw/wTzjj86XMS+X3
cL98Is4Xqst7+Pv4/8oX417xfuXN/HmcZfkst8a9ce7jTPAIbspX40zE34Hn
ZOI/zc35Ra7Lx+KzXD32jnfyk/xtnA8+z+04F9/M62J/eCg/wKfjetwjH+Sf
Y6/ky3zWM0vLy+T34/vgLvNeHh73i7Nm3sJfoA3m+0xm3V9y17geuXGLbj1/
jFY457oyuuXyB3gsrsECfRb93/JLqIE8OK9fiKzW/jG/jJrIiwv6RViMJViK
ZViOFViJVViNNViLdViPDdiITdiMLcjmGf+6b7d418iHi/qtyG5torl77Bny
45J+G3JYm2TugVoogMv67chpbbL5lXjPKIgr+h3IZW2KuSfuQyFc1e9EbmtT
zb1QG4VxTb8LeaxNM/dGHRRJih8zvzWU19p0+dU4JyiKJOyxls/aDPk11EMx
JGOvtfzWZsqvx1lGcaTCPmsFrM2S30B9pCA19lsraG223AcNUAJpcMBaIWtz
5DfjzKEk0uKgtcLW5spvoSFKIR3K6lfwh2iGCqiq28pfom3slfkwj4zzI1/j
jvEb777XAcYh1g8=
           "]]}, 
         {RGBColor[1, 0, 0], Opacity[0.6], 
          LineBox[{184, 183}]}}, {{}, {}, {}, {}}}],
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, False},
      AxesOrigin->{0, 0},
      Epilog->{{
         AbsoluteDashing[{10, 8}], 
         LineBox[{{9.34, 0}, {9.34, 0.0928690609970643}}]}, {
         InsetBox[
          FormBox[
           StyleBox[
            RowBox[{"P", " ", 
              RowBox[{"(", 
                RowBox[{"X", ">", 
                  OverscriptBox["\[Theta]", "^"]}], ")"}]}], 12, StripOnInput -> 
            False], TraditionalForm], {23, 0.045}]}, {
         ArrowBox[{{22, 0.038}, {20, 0.015}}]}},
      ImageSize->300,
      Method->{"AxesInFront" -> True},
      PlotLabel->FormBox[
       "\"\\!\\(TraditionalForm\\`\\*SubscriptBox[\\(H\\), \\(a\\)] : \
\[Theta] > \\*SubscriptBox[\\(\[Theta]\\), \\(0\\)]\\)\"", TraditionalForm],
      PlotRange->{{0, 30}, {0., 0.09768340027493218}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->{{{16, 
          FormBox[
           StyleBox[
            OverscriptBox["\[Theta]", "^"], 12, StripOnInput -> False], 
           TraditionalForm]}}, Automatic}], {160., -97.34035322810844}, 
     ImageScaled[{0.5, 0.5}], {300, 185.41019662496845`}], InsetBox[
     GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJztmXk01W3b9w2ZGlTIzN6GVBQRe9toH6chReahzFNRkTGZZQjJlJQMmSop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       "], {{{}, 
         {RGBColor[1, 0, 0], Opacity[0.6], EdgeForm[None], 
          GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwt1HdslVUYwOFbLdphaRXaCnUEFAKCgrRlSFsUFSsySqVRpK1SB120QEWR
oYBKleWKuHAwTMQBYuIkgBDRqOAgAiooKCQOUDFxB9DnDf7x5Peec3Nvv/t9
p7dTTXN503GJRCKJEUnHOvj4RGKs4RbzvZpDPc9a76e/OU8fYlO817qC6813
8gq/cqm9wVrBFFawj372O2oHTiWXHLJpTztO4SJGczPL+Za+3nuyXsiVtLCM
byj0WpbWMIc1HOIS+4N0AWv55//vWq6TWcpeCuxl6oNsTBy7KaMZZ9xCuvla
Zptf5hcuti7Rs3Uqn5gz414w35ynzbxlnqV/63AdFdejZ9LCe3HNegLXMMn6
Hs2mjmesZ+oezde2uki7Mo1t1nPj3nAjD1ifHp/D2+Z/436Zr9PO8Wz50Jym
1cyKZ6GNrDb/HOfAXKwf09Zcwzzzm/zFMOsyfZc25jFMND/N1/SxztD72cBR
yuMe6h2s4qd4zvaK4qzxBn9yhb2R2sxTfMX59k7Sam7nJQ7GWbA/MJ4pTTzJ
bnrbT9equHe8yAEG2b8gngMTWMIuetlP0wHx3WjkCb7kPK+lagon0j+ukQYe
5wvOjeen/RhKPY/xOT291kYrmcEL/EiJ/b56OXU8yk562E/WsUzneX6g2H5h
nA1e54/4W/ZKtZZH2ME59vwbJ+5jPUcYFWdLPyDVXBVnx7yS7ymyLtCPyIhz
T6u5ozbxmvn3uFbzZbqZZPPVjDe311oWm7fT3Ry/LV30Nj41Z+kNLDKfFueF
debDlMUZ0k46hffNd2kKlfEZ1rnawHNxBvQ7Haj5ulDP4la2Wt8d5yXOPHOt
52kHJvBqnEH9TUt1iM7XM5jMO9az4x5yFTdZt2q7+K48HM9RP9Nu+h9+aZJn

            "]]]}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, {}, 
         {GrayLevel[0], LineBox[CompressedData["
1:eJwl1HlM12UcwHEIMEAQiBvMppVLO8yApDIqLUs7IV0hpoQWaqZBQZJagJlg
dOm0Ozs3NbVj67CWZetYt7W0tDQ7Nrs82rpspr0+648X78/z/HS/H8/3+dG/
YVbNzMSEhIQL/Yge48fnOleXaqPmspCrrS/TJDp4y7pZ+3E7o6zP09/1Fn1B
r9ViFnGbdb1msICPrG/UI7mDMuvTdKferCv0Gi2kzTxBU7mV96xbtD+15kt0
v77Gdea+3Gmeotl8am7ToznEPEg36TKmmvNoNF+uybxtPpfR5j/0ReKgSuIs
zFdqJh+byxlu/lFXchNXWKfxvnk81eZ/dT13kcRge5v13vgMcXaMsfenvkQX
FZxu7yddxRzqSOZY+1/ofUyLz8rJVNn/WZ+O5xjnRgrH2f9S72d6vBfD6MXx
XtuiD8SZcz6VHEoqaZzg32zVB5nBBZxCOkO89pU+FM887hOncob9X3Q18+Jc
6M2J9r/Wh+NcuSiePWfa/1XXxB1gIhkMtb9NH2EWF8dntPeXvkx3PAPOsrdL
18YdZBI19g7o69xNJifZ267L475Qa53CO3GX4ncz/63rWESDdR8+iefBCPNu
fSbOwlxEe3xeTecDc6sOoN58qR7UN2gyH8495qs0J74bfBZ3RwfG3Y33sy7T
b+Ls9NF4zppPF01xt7QXnbxrfb0eQQ/VCf9/r/dpu74SZ6el8X01T9YsNppn
61FUmUfqHn2WjjhD6958GPeesfGHgg2ymCzKrXfoYzTHmccztfePvkpP3AXO
trdXn6MzzpVsKux/q4/H7xDnFXeBnLjTXvtOn+CGeP94zhxGLnnkU0AhRRRT
wjD/93t9khbGxbPjHPu/6fPMj7OI1+wl8qZ5CaVUWv+gTzHdXEA3rdZ1+h8b
KJIf
           "]], 
          LineBox[{263, 387, 200, 372, 288, 86, 335, 251, 188, 141, 67, 326, 
           242, 179, 132, 100, 28, 313, 229, 166, 119, 87, 68, 29, 30, 31, 32,
            33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 
           49, 314, 230, 167, 120, 88, 69, 327, 243, 180, 133, 101, 342, 258, 
           195, 148, 358, 274, 211, 379, 295, 399, 50}]}, 
         {GrayLevel[0], LineBox[CompressedData["
1:eJwl1Xe8jmUYB/D3nGNLKFFERhoq0ZKMUlmhodI0UmgYFWUULRIpe5Oy996b
sveWNOy99/a9Pv3xPb/rup778b7nee5zy1e7UdWGSYlEYrwfXfgzOZH4liIp
iURpmVsulk/I9PJGOU0+KhvLu+VaWUrucH+SHKl/WNaV+eUKWVIWldnlPPm4
/ELeJzfKJ+Uf7j+rHsBD+rdkXrlM3sVN6lmymGwq75Xr5VX3pVNPUDegoHp1
fAY51b/Lr3hAvVl2tX6b/C4+lzzmS2QGMqunyybstC5ZP0pdjwLqlfHdyKGe
L79kkXXn5K+8Hc+Em12fLZtxzfX0+onqhhSnm9lfsjVPkZFdZinWjVa/H8+Q
xWbn5W9U5x4SdDffLttQhhvYbbaEC+qB1IhnRBI9zP+W3/M0mdhjtpSe/KNv
yzPxjtlrtoxe9KYP/5r/wLPxnNhntpy+/KdvR1mysN9sBRfVg6hJIZLpZ75D
tqccWTlgtpJL6sHUir1BCv3Nd8ofKR/7gINmqTyrMeoPeIRVZpflEN7hflLF
e7VukmwU+5hfrNslO1Ah3lV8Z2tmyM845Hpq/Vj1h7HXuVW/QLZktetX5FBq
k8+15bG/yKaeI5vH76veIFPH+1VPlh/HXlavkSXIFfs+9oT8WhaWW2JPyAE+
Z7f6J4rqK8o75NK4V2aLZydnysfk57E/5DpZWh52fxo5Lp6P/EjeKVfFem5T
L5St4lmpN8k17rkqh/FufB9ucW2ubEGa2Gv6KfITSsa+d88e+TPPxXqOmKW1
bry6PsVYa3ZNDuc9HiRt7G3zvbIjlcjOUbN1DGSfvhOVycExs/UMYjBDGMow
hjOCkYxiNGMYy7ik/8+5CUxkEpOZwn7/bmeqxLvmuNkGpnJA34Xn45lxwmwj
0zio78oL5OSk2Samc0jfjRfjPXPKbDMzOKzvzkvczmmzLczkiL4HVcnNGbOt
zOKovicvk4ezcWYzm2P6XrwS+4Rzcc4xh+P63rxKXs7H+cNcTuj7UC32Mhfi
bGEeJ/V9eY38XIxzhPmc0vfjdQpwKc4RFnBa3583Ys9xOc4PFnIm/gZ5k4Jc
ifMj/hOyX0bo61CEdGQymyo/pVQ8K/0i+U3sH/VWWSbOePdfB00V46E=
           "]]}, 
         {RGBColor[1, 0, 0], Opacity[0.6], 
          LineBox[{401, 400}]}}, {{}, {}, {}, {}}}],
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, False},
      AxesOrigin->{0, 0},
      Epilog->{{
         AbsoluteDashing[{10, 8}], 
         LineBox[{{9.34, 0}, {9.34, 0.0928690609970643}}]}, {
         InsetBox[
          FormBox[
           StyleBox[
            RowBox[{"P", " ", 
              RowBox[{"(", 
                RowBox[{"X", "<", 
                  OverscriptBox["\[Theta]", "^"]}], ")"}]}], 12, StripOnInput -> 
            False], TraditionalForm], {18, 0.075}]}, {
         ArrowBox[{{17, 0.068}, {14.5, 0.047}}]}},
      ImageSize->300,
      Method->{"AxesInFront" -> True},
      PlotLabel->FormBox[
       "\"\\!\\(TraditionalForm\\`\\*SubscriptBox[\\(H\\), \\(a\\)] : \
\[Theta] < \\*SubscriptBox[\\(\[Theta]\\), \\(0\\)]\\)\"", TraditionalForm],
      PlotRange->{{0, 30}, {0., 0.09768340027493218}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->{{{16, 
          FormBox[
           StyleBox[
            OverscriptBox["\[Theta]", "^"], 12, StripOnInput -> False], 
           TraditionalForm]}}, Automatic}], {480., -97.34035322810844}, 
     ImageScaled[{0.5, 0.5}], {300, 185.41019662496845`}]}, {}},
  ContentSelectable->True,
  ImageSize->{652., 206.68070645621688`},
  PlotRangePadding->{6, 5}]], "Picture",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{3.532107654589604*^9},
 CellTags->"Testing Framework"],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Hypothesis Testing: Tests of location", "Section"],

Cell[TextData[{
 "For tests of location, there is ",
 Cell[BoxData[
  ButtonBox["LocationTest",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/LocationTest"]], "InlineFormula"],
 " for testing a data set against a location value or comparing two data sets \
and ",
 Cell[BoxData[
  ButtonBox["LocationEquivalenceTest",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/LocationEquivalenceTest"]], "InlineFormula"],
 " for testing equivalence of population locations for multiple data sets. \
Functions for named tests are also included. We will see the basic framework \
in the context of a location test for airplane glass failure times."
}], "Text",
 CellChangeTimes->{{3.498320699378215*^9, 3.498320830405075*^9}, {
   3.498321135715295*^9, 3.4983211378715725`*^9}, 3.498325471220893*^9, {
   3.5320941829944596`*^9, 3.5320941893714595`*^9}}],

Cell["\<\
This loads time to failure data for aircraft windows.\
\>", "MathCaption",
 CellChangeTimes->{{3.4982313651599584`*^9, 3.4982314102580376`*^9}, {
  3.4982315185809355`*^9, 3.4982315318947134`*^9}, {3.5320941975914593`*^9, 
  3.5320942059994593`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"glass", "=", 
   RowBox[{"ExampleData", "[", 
    RowBox[{"{", 
     RowBox[{"\"\<Statistics\>\"", ",", "\"\<AirplaneGlass\>\""}], "}"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4979797230702066`*^9, 3.4979798316204767`*^9}, {
   3.4979800276111236`*^9, 3.49798004328341*^9}, 3.497980087690797*^9, 
   3.4979802366164837`*^9, {3.4979808531743126`*^9, 3.4979808600806065`*^9}, 
   3.4982186056617727`*^9, {3.5320941688444595`*^9, 3.5320941690274596`*^9}}],

Cell[TextData[{
 "This gives a ",
 Cell[BoxData[
  StyleBox["p", "TI"]], "InlineFormula"],
 "\[Hyphen]value for the null hypothesis that the population mean or median \
is 28 against the alternative that it is not."
}], "MathCaption",
 CellChangeTimes->{{3.4983208374049406`*^9, 3.498320889294569*^9}}],

Cell[BoxData[
 RowBox[{"LocationTest", "[", 
  RowBox[{"glass", ",", "28"}], "]"}]], "Input",
 CellChangeTimes->{{3.4983192231107273`*^9, 3.498319227079605*^9}, {
  3.4983199622150726`*^9, 3.498319968027796*^9}, {3.4983201260807395`*^9, 
  3.4983201330341315`*^9}}],

Cell["\<\
Tests with alternative that the true value is less or that it is greater can \
also be performed.\
\>", "MathCaption",
 CellChangeTimes->{{3.4983208374049406`*^9, 3.498320940965452*^9}}],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"LocationTest", "[", 
    RowBox[{"glass", ",", "28", ",", 
     RowBox[{"AlternativeHypothesis", "\[Rule]", "alt"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"alt", ",", 
     RowBox[{"{", 
      RowBox[{
      "\"\<Less\>\"", ",", "\"\<Unequal\>\"", ",", "\"\<Greater\>\""}], 
      "}"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.498319971684186*^9, 3.4983200153421125`*^9}, {
  3.498320128643338*^9, 3.4983201364717636`*^9}}],

Cell["", "Spacer"],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Hypothesis Testing: Tests of location", "Section"],

Cell["\<\
The test is chosen based on the data and assumptions of available tests.\
\>", "Text",
 CellChangeTimes->{{3.498320948309061*^9, 3.4983209736523247`*^9}}],

Cell[TextData[{
 "This shows that a ",
 Cell[BoxData[
  StyleBox["t", "TI"]], "InlineFormula"],
 "\[Hyphen]test was chosen by default."
}], "MathCaption",
 CellChangeTimes->{{3.4983208374049406`*^9, 3.498320940965452*^9}, {
  3.498320979480337*^9, 3.4983210015580387`*^9}}],

Cell[BoxData[
 RowBox[{"LocationTest", "[", 
  RowBox[{"glass", ",", "28", ",", 
   RowBox[{"{", 
    RowBox[{"\"\<AutomaticTest\>\"", ",", "\"\<PValue\>\""}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.4983192347986016`*^9, 3.498319241251933*^9}, {
  3.4983201125020933`*^9, 3.4983201179554276`*^9}, {3.498320513130471*^9, 
  3.4983205135679293`*^9}}],

Cell["\<\
An object can also be obtained and queried for information after the fact.\
\>", "MathCaption",
 CellChangeTimes->{{3.498321006932935*^9, 3.4983210282295437`*^9}}],

Cell[BoxData[
 RowBox[{"h", "=", 
  RowBox[{"LocationTest", "[", 
   RowBox[{"glass", ",", "28", ",", "\"\<HypothesisTestData\>\""}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.498319155311683*^9, 3.4983192096727977`*^9}, {
  3.4983200649065156`*^9, 3.4983200866260996`*^9}, {3.49832015083169*^9, 
  3.498320162238378*^9}, {3.4983205153021383`*^9, 3.4983205157708426`*^9}}],

Cell["This gives the conclusion at the default significance level.", \
"MathCaption",
 CellChangeTimes->{{3.4983210317920895`*^9, 3.498321043995371*^9}}],

Cell[BoxData[
 RowBox[{"h", "[", "\"\<TestConclusion\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.498319294691143*^9, 3.4983193116135597`*^9}, {
  3.4983201736450663`*^9, 3.498320180848468*^9}}],

Cell["\<\
Information about any of the available applicable tests can be obtained from \
the object.\
\>", "MathCaption",
 CellChangeTimes->{{3.4983210317920895`*^9, 3.4983210848865194`*^9}}],

Cell[BoxData[
 RowBox[{"h", "[", 
  RowBox[{"{", 
   RowBox[{"\"\<TestDataTable\>\"", ",", "All"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.4983192128135233`*^9, 3.4983192145792046`*^9}, {
  3.498319257564955*^9, 3.498319282612632*^9}}],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["\<\
Hypothesis Testing: Named tests and assumptions\
\>", "Section",
 CellChangeTimes->{{3.5320945577264595`*^9, 3.5320945743034596`*^9}}],

Cell["\<\
Functions for named tests are also included as well as a mechanicism for \
controling which assumptions to validate.\
\>", "Text",
 CellChangeTimes->{{3.498320699378215*^9, 3.498320830405075*^9}, {
   3.498321135715295*^9, 3.4983211378715725`*^9}, 3.498325471220893*^9, {
   3.5320941829944596`*^9, 3.5320941893714595`*^9}, {3.5320946840084596`*^9, 
   3.5320946846384597`*^9}, {3.5320964307952566`*^9, 3.532096439676256*^9}, {
   3.5320965855802565`*^9, 3.5320966659272566`*^9}}],

Cell["\<\
In this case, the signed\[Hyphen]rank test is chosen by default.\
\>", "MathCaption",
 CellChangeTimes->{{3.4983210317920895`*^9, 3.4983211278245687`*^9}, {
  3.532106435133671*^9, 3.5321064590960665`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"datat", "=", 
   RowBox[{"BlockRandom", "[", 
    RowBox[{
     RowBox[{"SeedRandom", "[", "1234", "]"}], ";", 
     RowBox[{"RandomVariate", "[", 
      RowBox[{
       RowBox[{"StudentTDistribution", "[", "5", "]"}], ",", "100"}], "]"}]}],
     "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.532099098083426*^9, 3.532099147719389*^9}, {
  3.5321037622830334`*^9, 3.5321038640040336`*^9}}],

Cell[BoxData[
 RowBox[{"th", "=", 
  RowBox[{"LocationTest", "[", 
   RowBox[{"datat", ",", "0", ",", "\"\<HypothesisTestData\>\""}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.53209917823044*^9, 3.532099192163833*^9}, 
   3.5321038666160336`*^9, {3.5321043405606575`*^9, 3.5321043436215754`*^9}, 
   3.532104620555231*^9}],

Cell[BoxData[
 RowBox[{"th", "[", "\"\<TestDataTable\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.532099194968114*^9, 3.532099200088626*^9}, 
   3.532104622659441*^9}],

Cell[TextData[{
 "Using a ",
 StyleBox["t",
  FontSlant->"Italic"],
 "\[Hyphen]test we see that a normality assumption is violated at a .05 level."
}], "MathCaption",
 CellChangeTimes->{{3.4983210317920895`*^9, 3.4983211278245687`*^9}, {
  3.532106435133671*^9, 3.5321064590960665`*^9}, {3.532106489853142*^9, 
  3.532106513869543*^9}}],

Cell[BoxData[
 RowBox[{"TTest", "[", 
  RowBox[{"datat", ",", "0"}], "]"}]], "Input",
 CellChangeTimes->{{3.5320991308206997`*^9, 3.5320991372393413`*^9}, 
   3.5320991690325203`*^9, 3.5321038733370333`*^9}],

Cell["\<\
The normality assumption is not violated by much and some might chose to just \
ignore it.\
\>", "MathCaption",
 CellChangeTimes->{{3.4983210317920895`*^9, 3.4983211278245687`*^9}, {
  3.532106435133671*^9, 3.5321064590960665`*^9}, {3.532106489853142*^9, 
  3.532106513869543*^9}, {3.5321065460297594`*^9, 3.532106567110867*^9}}],

Cell[BoxData[
 RowBox[{"DistributionFitTest", "[", 
  RowBox[{"datat", ",", 
   RowBox[{"NormalDistribution", "[", 
    RowBox[{"\[Mu]", ",", "\[Sigma]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5321037463040333`*^9, 3.5321037577100334`*^9}, 
   3.5321038704790335`*^9, {3.5321039281300335`*^9, 3.5321039438470335`*^9}}],

Cell[BoxData[
 RowBox[{"Histogram", "[", 
  RowBox[{"datat", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "4.5"}], ",", "4.5", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5321043654031076`*^9, 3.532104425821228*^9}}],

Cell["\<\
Validation can be turned off, though deciding to ignore assumptions should be \
done with caution.\
\>", "MathCaption",
 CellChangeTimes->{{3.4983210317920895`*^9, 3.4983211278245687`*^9}, {
  3.532106435133671*^9, 3.5321064590960665`*^9}, {3.532106489853142*^9, 
  3.532106513869543*^9}, {3.5321065460297594`*^9, 3.5321066297121267`*^9}}],

Cell[BoxData[
 RowBox[{"t", "=", 
  RowBox[{"TTest", "[", 
   RowBox[{"datat", ",", "0", ",", "\"\<HypothesisTestData\>\"", ",", 
    RowBox[{"VerifyTestAssumptions", "\[Rule]", "None"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5320992175053673`*^9, 3.532099232304847*^9}, 
   3.532103876862034*^9, {3.532103916980034*^9, 3.532103917336034*^9}, {
   3.532104452427207*^9, 3.5321044725252347`*^9}}],

Cell["\<\
Results can be obtained as before.\
\>", "MathCaption",
 CellChangeTimes->{{3.4983210317920895`*^9, 3.4983211278245687`*^9}, {
  3.532106435133671*^9, 3.5321064590960665`*^9}, {3.532106489853142*^9, 
  3.532106513869543*^9}, {3.5321065460297594`*^9, 3.5321066648886437`*^9}}],

Cell[BoxData[
 RowBox[{"t", "[", 
  RowBox[{"{", 
   RowBox[{
   "\"\<TestStatistic\>\"", ",", "\"\<PValue\>\"", ",", 
    "\"\<ShortTestConclusion\>\""}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.498320201568013*^9, 3.498320209646448*^9}, {
   3.4983205053499684`*^9, 3.4983205358782873`*^9}, {3.4983205888888226`*^9, 
   3.498320667318793*^9}, 3.5321043480809126`*^9, {3.5321044574877253`*^9, 
   3.5321044583659887`*^9}}],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Hypothesis Testing: Tests of variance", "Section"],

Cell[TextData[{
 "Tests of variance, scale or dispersion are performed via ",
 Cell[BoxData[
  ButtonBox["VarianceTest",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/VarianceTest"]], "InlineFormula"],
 " (one or two data sets) and ",
 Cell[BoxData[
  ButtonBox["VarianceEquivalenceTest",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/VarianceEquivalenceTest"]], "InlineFormula"],
 " (two or more data sets)."
}], "Text",
 CellChangeTimes->{{3.498322959434269*^9, 3.4983230720106163`*^9}}],

Cell["\<\
In the airplane glass data, we might want to know about the variability of \
failure times.\
\>", "Text",
 CellChangeTimes->{{3.4983231255890846`*^9, 3.4983231562611556`*^9}}],

Cell["\<\
This tests the null that the variance is 25 against the alternative that it \
is greater than 25.\
\>", "MathCaption",
 CellChangeTimes->{{3.4983235226562457`*^9, 3.498323548437991*^9}}],

Cell[BoxData[
 RowBox[{"vtest", "=", 
  RowBox[{"VarianceTest", "[", 
   RowBox[{"glass", ",", "25", ",", "\"\<HypothesisTestData\>\"", ",", 
    RowBox[{"AlternativeHypothesis", "\[Rule]", "\"\<Greater\>\""}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.49832330305897*^9, 3.498323307277747*^9}, {
  3.4983233864036293`*^9, 3.498323415841695*^9}}],

Cell["\<\
The test is significant, so we would conclude there is significant evidence \
that the population variance is greater than 25.\
\>", "MathCaption",
 CellChangeTimes->{{3.498323553125581*^9, 3.498323598704581*^9}}],

Cell[BoxData[
 RowBox[{"vtest", "[", "\"\<TestDataTable\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.498323421248049*^9, 3.4983234609988117`*^9}}],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Hypothesis Testing: Distributional goodness of fit", "Section"],

Cell["\<\
Distributional goodness of fit tests mostly rely on some comparison between \
the empirical CDF for data and the theoretical CDF for a distribution or the \
empirical CDF for a second data set. A few common distributional goodness of \
fit tests include Kolmogorov\[Hyphen]Smirnov, Anderson\[Hyphen]Darling, and \
Shapiro\[Hyphen]Wilk.\
\>", "Text",
 CellChangeTimes->{{3.49832383239769*^9, 3.4983239916673923`*^9}}],

Cell["\<\
We could ask if 100 data points are significantly different from a particular \
Weibull distribution.\
\>", "Text",
 CellChangeTimes->{{3.498324382474272*^9, 3.4983244373194256`*^9}, {
  3.498324546447219*^9, 3.498324559369425*^9}, {3.5321049730724792`*^9, 
  3.5321049750516768`*^9}}],

Cell["\<\
Testing the data against the original distribution would effectively perform \
some comparison between the following CDF curves. \
\>", "MathCaption",
 CellChangeTimes->{{3.498324442257052*^9, 3.4983244476634407`*^9}, {
  3.4983244806955357`*^9, 3.4983245405720687`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ewdata", "=", 
   RowBox[{"BlockRandom", "[", 
    RowBox[{
     RowBox[{"SeedRandom", "[", "12345", "]"}], ";", 
     RowBox[{"RandomVariate", "[", 
      RowBox[{
       RowBox[{"WeibullDistribution", "[", 
        RowBox[{"5", ",", "10"}], "]"}], ",", 
       SuperscriptBox["10", "2"]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ewdist", "=", 
   RowBox[{"EmpiricalDistribution", "[", "ewdata", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"CDF", "[", 
      RowBox[{"ewdist", ",", "x"}], "]"}], ",", 
     RowBox[{"CDF", "[", 
      RowBox[{
       RowBox[{"WeibullDistribution", "[", 
        RowBox[{"5", ",", "10"}], "]"}], ",", "x"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "20"}], "}"}], ",", 
   RowBox[{"Exclusions", "\[Rule]", "None"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", "Thick"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.4983240529658365`*^9, 3.4983242096104717`*^9}, {
  3.498324451788546*^9, 3.4983244608669033`*^9}, {3.532104686865861*^9, 
  3.532104713613536*^9}}],

Cell["", "Spacer"],

Cell[TextData[{
 "In distributional tests, the null hypothesis is that the data are from the \
distribution. A small ",
 Cell[BoxData[
  StyleBox["p", "TI"]], "InlineFormula"],
 "\[Hyphen]value would indicate significant evidence that the distributions \
are different."
}], "Text"],

Cell["\<\
This tests the data against the distribution they were generated from.\
\>", "MathCaption",
 CellChangeTimes->{{3.4983245805105915`*^9, 3.498324583307538*^9}, {
  3.498324677278693*^9, 3.4983246932166014`*^9}}],

Cell[BoxData[
 RowBox[{"DistributionFitTest", "[", 
  RowBox[{"ewdata", ",", 
   RowBox[{"WeibullDistribution", "[", 
    RowBox[{"5", ",", "10"}], "]"}], ",", "\"\<TestDataTable\>\""}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.4983242327360635`*^9, 3.498324293096984*^9}, {
  3.498324464867006*^9, 3.4983244673670697`*^9}}],

Cell["", "Spacer"],

Cell["\<\
As with tests of location or variance, named tests are also available and \
results for multiple tests could also be obtained.\
\>", "Text",
 CellChangeTimes->{{3.498324949301282*^9, 3.498324984536559*^9}}],

Cell["\<\
This gives the result for a Kolmogorov\[Hyphen]Smirnov test.\
\>", "MathCaption",
 CellChangeTimes->{{3.4983245805105915`*^9, 3.498324583307538*^9}, {
  3.498324677278693*^9, 3.498324758030761*^9}, {3.4983248515800304`*^9, 
  3.4983249059876733`*^9}, {3.498325016412375*^9, 3.498325034303458*^9}}],

Cell[BoxData[
 RowBox[{"KolmogorovSmirnovTest", "[", 
  RowBox[{"ewdata", ",", 
   RowBox[{"WeibullDistribution", "[", 
    RowBox[{"5", ",", "10"}], "]"}], ",", "\"\<TestDataTable\>\""}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.4983249277538557`*^9, 3.4983249357228093`*^9}}],

Cell["\<\
These are the results for all applicable goodness of fit tests.\
\>", "MathCaption",
 CellChangeTimes->{{3.4983245805105915`*^9, 3.498324583307538*^9}, {
  3.498324677278693*^9, 3.498324758030761*^9}, {3.4983248515800304`*^9, 
  3.4983249059876733`*^9}, {3.498325016412375*^9, 3.4983250531789412`*^9}}],

Cell[BoxData[
 RowBox[{"DistributionFitTest", "[", 
  RowBox[{"ewdata", ",", 
   RowBox[{"WeibullDistribution", "[", 
    RowBox[{"5", ",", "10"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"\"\<TestDataTable\>\"", ",", "All"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4983249180817327`*^9, 3.4983249205349207`*^9}}],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Hypothesis Testing: Testing with estimated parameters", "Section"],

Cell[TextData[{
 "Symbolic parameters need to be estimated and the estimation has an impact \
on the test statistic\[CloseCurlyQuote]s distribution and ",
 Cell[BoxData[
  StyleBox["p", "TI"]], "InlineFormula"],
 "\[Hyphen]values. If the parameter values are numeric, they are assumed \
known."
}], "Text",
 CellChangeTimes->{{3.4983247649059367`*^9, 3.4983248454861245`*^9}, {
  3.498325481549282*^9, 3.498325509549999*^9}}],

Cell["\<\
This tests the data against the Weibull distribution with maximum likelihood \
parameter estimates.\
\>", "MathCaption",
 CellChangeTimes->{{3.4983245805105915`*^9, 3.498324583307538*^9}, {
  3.498324677278693*^9, 3.498324758030761*^9}}],

Cell[BoxData[
 RowBox[{"dh", "=", 
  RowBox[{"DistributionFitTest", "[", 
   RowBox[{"ewdata", ",", 
    RowBox[{"WeibullDistribution", "[", 
     RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], ",", 
    "\"\<HypothesisTestData\>\""}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4983242990346355`*^9, 3.49832434922342*^9}, 
   3.4983244717734327`*^9, {3.4983251786196527`*^9, 3.498325184276047*^9}}],

Cell["\<\
This give the test result and the estimate of the distribution.\
\>", "MathCaption",
 CellChangeTimes->{{3.4983245805105915`*^9, 3.498324583307538*^9}, {
  3.498324677278693*^9, 3.498324758030761*^9}, {3.4983252181362886`*^9, 
  3.4983252329335427`*^9}}],

Cell[BoxData[
 RowBox[{"dh", "[", 
  RowBox[{"{", 
   RowBox[{"\"\<TestDataTable\>\"", ",", "\"\<FittedDistribution\>\""}], 
   "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.4983251902293243`*^9, 3.4983252094798174`*^9}}],

Cell[TextData[{
 "Treating the fitted distribution as known shows no difference in the test \
statistic but there is a difference in the ",
 Cell[BoxData[
  StyleBox["p", "TI"]], "InlineFormula"],
 "\[Hyphen]value."
}], "MathCaption",
 CellChangeTimes->{{3.4983245805105915`*^9, 3.498324583307538*^9}, {
  3.498324677278693*^9, 3.498324758030761*^9}, {3.4983248515800304`*^9, 
  3.4983249059876733`*^9}}],

Cell[BoxData[
 RowBox[{"DistributionFitTest", "[", 
  RowBox[{"ewdata", ",", 
   RowBox[{"dh", "[", "\"\<FittedDistribution\>\"", "]"}], ",", 
   "\"\<TestDataTable\>\""}], "]"}]], "Input"],

Cell["", "Spacer"],

Cell["\<\
The examples shown for location, variance, and goodness of fit have all been \
for univariate data and distributions. The testing functions also allow for \
multivariate data and distributions. The named tests in those cases include \
tests designed for multivariate data and suitable extensions of univariate \
tests to the multivariate case.\
\>", "Text",
 CellChangeTimes->{{3.4983227950311756`*^9, 3.49832289634173*^9}, {
  3.4983251226807203`*^9, 3.4983251394467745`*^9}}],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Model Fitting and Analysis", "Section"],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " includes a framework and functionality for linear and nonlinear \
regression, logit, probit, and generalized linear models. An extensive set of \
optimization functions, linear algebra functions, and a package for analysis \
of variance (ANOVA) all provide capabilities of interest in model fitting and \
analysis."
}], "Text"],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Model Fitting and Analysis: Linear regression", "Section"],

Cell["Here we import some data from an Excel spreadsheet.", "Text"],

Cell[BoxData[
 RowBox[{"lineardata", "=", 
  RowBox[{"Import", "[", 
   RowBox[{"\"\<linearfitdata.xls\>\"", ",", 
    RowBox[{"{", 
     RowBox[{"\"\<Data\>\"", ",", "1"}], "}"}]}], "]"}]}]], "Input",
 PageWidth->WindowWidth],

Cell[TextData[{
 "The data can be fitted to a linear model using ",
 Cell[BoxData[
  ButtonBox["LinearModelFit",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/LinearModelFit"]], "InlineFormula"],
 "."
}], "MathCaption",
 CellChangeTimes->{{3.434112033393976*^9, 3.434112038865075*^9}}],

Cell[BoxData[
 RowBox[{"lm", "=", 
  RowBox[{"LinearModelFit", "[", 
   RowBox[{"lineardata", ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}]}]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.434112048756946*^9, 3.4341120565795193`*^9}, {
   3.4341121136106267`*^9, 3.434112114237687*^9}, 3.4341138585746155`*^9, 
   3.438088489327569*^9}],

Cell[BoxData[
 RowBox[{"Normal", "[", "lm", "]"}]], "Input",
 CellChangeTimes->{{3.442051101928609*^9, 3.442051105915276*^9}}],

Cell["", "Spacer"],

Cell[TextData[{
 Cell[BoxData[
  ButtonBox["LinearModelFit",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/LinearModelFit"]], "InlineFormula"],
 " produces a ",
 Cell[BoxData[
  ButtonBox["FittedModel",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/FittedModel"]], "InlineFormula"],
 " object that can be evaluated at a point and from which diagnostics and \
results can be obtained.  "
}], "Text"],

Cell[TextData[{
 "This gives the predicted value for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", "y", ",", "z"}], "}"}], "=", 
    RowBox[{"{", 
     RowBox[{"1", ",", "3", ",", "5"}], "}"}]}], TraditionalForm]]],
 "."
}], "MathCaption"],

Cell[BoxData[
 RowBox[{"lm", "[", 
  RowBox[{"1", ",", "3", ",", "5"}], "]"}]], "Input",
 CellChangeTimes->{{3.4976267989628434`*^9, 3.497626827167593*^9}}],

Cell[TextData[{
 "A list of available results can be obtained by asking for the ",
 StyleBox["\"Properties\"", "MR"],
 "."
}], "MathCaption"],

Cell[BoxData[
 RowBox[{"lm", "[", "\"\<Properties\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.4341121810352535`*^9, 3.4341121858479385`*^9}}],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Model Fitting and Analysis: Linear regression diagnostics", "Section"],

Cell["\<\
Individual properties or lists of properties can be obtained in the same \
manner.\
\>", "Text",
 CellChangeTimes->{{3.434112227806865*^9, 3.434112247423827*^9}}],

Cell["\<\
Here the standardized residuals and Cook\[CloseCurlyQuote]s distances are \
extracted.\
\>", "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"stresids", ",", "cookd"}], "}"}], "=", 
  RowBox[{"lm", "[", 
   RowBox[{"{", 
    RowBox[{"\"\<StandardizedResiduals\>\"", ",", "\"\<CookDistances\>\""}], 
    "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4341122527667856`*^9, 3.434112266351375*^9}}],

Cell["\<\
In a linear regression, we might wish to look at plots of the standardized \
residuals and Cook\[CloseCurlyQuote]s distances to assess approximate \
normality of errors and influence of individual points.\
\>", "MathCaption",
 CellChangeTimes->{{3.434112591172591*^9, 3.4341125913606005`*^9}, {
  3.434113067409542*^9, 3.4341130689603176`*^9}}],

Cell[BoxData[
 RowBox[{"GraphicsRow", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"QuantilePlot", "[", "stresids", "]"}], ",", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"cookd", ",", 
       RowBox[{"Filling", "\[Rule]", "Bottom"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", " ", "Large"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.43534243542308*^9, 3.43534243996564*^9}, {
  3.4353424753349524`*^9, 3.4353424894795437`*^9}, {3.4354995274510136`*^9, 
  3.4354995511115456`*^9}, {3.442051172081203*^9, 3.44205119481553*^9}, {
  3.442138105616831*^9, 3.442138114452799*^9}, {3.5322660919284596`*^9, 
  3.532266093110578*^9}}],

Cell["\<\
Residuals can also be viewed against predictors to check for systematic \
trends which would violate the model assumptions.\
\>", "MathCaption",
 CellChangeTimes->{{3.4355120984917855`*^9, 3.4355121850098476`*^9}}],

Cell[BoxData[
 RowBox[{"GraphicsRow", "[", 
  RowBox[{
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"resids", "=", 
       RowBox[{"lm", "[", "\"\<FitResiduals\>\"", "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"ListPlot", "[", 
        RowBox[{
         RowBox[{"Transpose", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"lineardata", "[", 
             RowBox[{"[", 
              RowBox[{"All", ",", "i"}], "]"}], "]"}], ",", "resids"}], "}"}],
           "]"}], ",", 
         RowBox[{"Frame", "\[Rule]", "True"}], ",", 
         RowBox[{"FrameLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"{", 
              RowBox[{"x", ",", "y", ",", "z"}], "}"}], "[", 
             RowBox[{"[", "i", "]"}], "]"}], ",", "\"\<residual\>\""}], 
           "}"}]}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}], "]"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", " ", "Large"}]}], "]"}]], "Input"],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Model Fitting and Analysis: Generalized linear models (GLM)", "Section"],

Cell["For linear regression, the model is of the form", "Text",
 CellChangeTimes->{{3.434112612965945*^9, 3.4341126385971403`*^9}, {
   3.434992072481764*^9, 3.434992075638519*^9}, {3.435510526398472*^9, 
   3.4355105683180103`*^9}, 3.4355108494225554`*^9}],

Cell[TextData[{
 " ",
 Cell[BoxData[
  RowBox[{
   StyleBox[
    OverscriptBox[
     StyleBox["y", "TI"], "^"], "TI"], "=", 
   RowBox[{
    SubscriptBox[
     StyleBox["\[Beta]", "TR"], 
     StyleBox["0", "TR"]], "+", 
    RowBox[{
     SubscriptBox[
      StyleBox["\[Beta]", "TR"], 
      StyleBox["1", "TR"]], " ", 
     SubscriptBox[
      StyleBox["f", "TI"], 
      StyleBox["1", "TR"]]}], "+", 
    RowBox[{
     SubscriptBox[
      StyleBox["\[Beta]", "TR"], 
      StyleBox["2", "TR"]], " ", 
     SubscriptBox[
      StyleBox["f", "TI"], 
      StyleBox["2", "TR"]]}], "+", 
    StyleBox["\[Ellipsis]", "TR"]}]}]], "InlineFormula"]
}], "Text",
 CellChangeTimes->{{3.434112612965945*^9, 3.4341126385971403`*^9}, {
  3.434992072481764*^9, 3.434992075638519*^9}, {3.435510526398472*^9, 
  3.4355105812969728`*^9}},
 TextAlignment->-0.5],

Cell[TextData[{
 "for basis functions ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["f", "TI"], 
   StyleBox["1", "TR"]]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["f", "TI"], 
   StyleBox["2", "TR"]]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  StyleBox["\[Ellipsis]", "TR"]], "InlineFormula"],
 ". Each observed ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["y", "TI"], 
   StyleBox["i", "TI"]]], "InlineFormula"],
 " is assumed to be from a normal distribution with mean ",
 Cell[BoxData[
  StyleBox[
   OverscriptBox[
    StyleBox[
     SubscriptBox[
      StyleBox["y", "TI"], 
      StyleBox["i", "TI"]], "TI"], "^"], "TI"]]],
 "."
}], "Text",
 CellChangeTimes->{{3.434112612965945*^9, 3.4341126385971403`*^9}, {
  3.434992072481764*^9, 3.434992075638519*^9}, {3.435510526398472*^9, 
  3.4355105742242503`*^9}, {3.435510633109463*^9, 3.435510828917861*^9}}],

Cell["For generalized linear models, the model is of the form", "Text",
 CellChangeTimes->{{3.434112612965945*^9, 3.4341126385971403`*^9}, {
  3.434992072481764*^9, 3.434992075638519*^9}, {3.435510526398472*^9, 
  3.4355105683180103`*^9}, {3.435510839070819*^9, 3.435510847725299*^9}}],

Cell[TextData[{
 " ",
 Cell[BoxData[
  RowBox[{
   StyleBox[
    OverscriptBox[
     StyleBox["y", "TI"], "^"], "TI"], "=", 
   RowBox[{
    SuperscriptBox[
     StyleBox["g", "TI"], 
     RowBox[{"-", 
      StyleBox["1", "TR"]}]], 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox[
       StyleBox["\[Beta]", "TR"], 
       StyleBox["0", "TR"]], "+", 
      RowBox[{
       SubscriptBox[
        StyleBox["\[Beta]", "TR"], 
        StyleBox["1", "TR"]], " ", 
       SubscriptBox[
        StyleBox["f", "TI"], 
        StyleBox["1", "TR"]]}], "+", 
      RowBox[{
       SubscriptBox[
        StyleBox["\[Beta]", "TR"], 
        StyleBox["2", "TR"]], " ", 
       SubscriptBox[
        StyleBox["f", "TI"], 
        StyleBox["2", "TR"]]}], "+", 
      StyleBox["\[Ellipsis]", "TR"]}], ")"}]}]}]], "InlineFormula"]
}], "Text",
 CellChangeTimes->{{3.434112612965945*^9, 3.4341126385971403`*^9}, {
   3.434992072481764*^9, 3.434992075638519*^9}, {3.435510526398472*^9, 
   3.4355105812969728`*^9}, 3.435510859957779*^9},
 TextAlignment->-0.5],

Cell[TextData[{
 "where ",
 Cell[BoxData[
  FormBox["g", TraditionalForm]]],
 " is an invertible function called the ",
 StyleBox["link",
  FontSlant->"Italic"],
 " function, and each observed ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["y", "TI"], 
   StyleBox["i", "TI"]]], "InlineFormula"],
 " is assumed to be from an exponential family distribution with mean ",
 Cell[BoxData[
  StyleBox[
   OverscriptBox[
    StyleBox[
     SubscriptBox[
      StyleBox["y", "TI"], 
      StyleBox["i", "TI"]], "TI"], "^"], "TI"]]],
 ".  Common special cases include linear, logistic and probit regression, \
log-linear models for count data, and gamma and inverse Gaussian models. \
These and quasi\[Hyphen]likelihood models are all built\[Hyphen]in. Note that \
the errors are not independent of the ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]]],
 " values."
}], "Text",
 CellChangeTimes->{{3.4976266950134716`*^9, 3.4976267257357607`*^9}}],

Cell["\<\
Built\[Hyphen]in functions for generalized linear models include:\
\>", "Text"],

Cell[BoxData[
 PaneSelectorBox[{False->
  FrameBox[
   StyleBox["\<\"LinearModelFit\"\>", "OverviewSection",
    StripOnInput->False],
   BoxFrame->2,
   FrameMargins->{{15, 15}, {5, 5}},
   FrameStyle->None,
   RoundingRadius->5,
   StripOnInput->False], True->
  TemplateBox[{FrameBox[
     StyleBox[
     "\"LinearModelFit\"", "OverviewSection", StripOnInput -> False, 
      LineColor -> GrayLevel[1], FrontFaceColor -> GrayLevel[1], 
      BackFaceColor -> GrayLevel[1], GraphicsColor -> GrayLevel[1], FontColor -> 
      GrayLevel[1]], Background -> RGBColor[0.811765, 0.117647, 0.145098, 1], 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> None, RoundingRadius -> 
     5, StripOnInput -> False],"\" \[RightGuillemet] \"",FrameBox[
     StyleBox[
     "\"linear regression\"", "OverviewSection", StripOnInput -> False], 
     Background -> GrayLevel[1], BoxFrame -> 2, 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> 
     RGBColor[0.811765, 0.117647, 0.145098, 1], RoundingRadius -> 5, 
     StripOnInput -> False]},
   "Row",
   DisplayFunction->(
    RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
   InterpretationFunction->(RowBox[{"Row", "[", 
      RowBox[{"{", 
        RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )]}, Dynamic[
   CurrentValue["MouseOver"]],
  FrameMargins->0,
  ImageSize->Automatic]], "OverviewSection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[BoxData[
 PaneSelectorBox[{False->
  FrameBox[
   StyleBox["\<\"LogitModelFit\"\>", "OverviewSection",
    StripOnInput->False],
   BoxFrame->2,
   FrameMargins->{{15, 15}, {5, 5}},
   FrameStyle->None,
   RoundingRadius->5,
   StripOnInput->False], True->
  TemplateBox[{FrameBox[
     StyleBox["\"LogitModelFit\"", "OverviewSection", 
      GrayLevel[1], StripOnInput -> False], 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> None, RoundingRadius -> 
     5, Background -> RGBColor[0.811765, 0.117647, 0.145098, 1], StripOnInput -> 
     False],"\" \[RightGuillemet] \"",FrameBox[
     StyleBox[
     "\"logistic regression\"", "OverviewSection", StripOnInput -> False], 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> 
     RGBColor[0.811765, 0.117647, 0.145098, 1], BoxFrame -> 2, RoundingRadius -> 
     5, Background -> GrayLevel[1], StripOnInput -> False]},
   "Row",
   DisplayFunction->(
    RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
   InterpretationFunction->(RowBox[{"Row", "[", 
      RowBox[{"{", 
        RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )]}, Dynamic[
   CurrentValue["MouseOver"]],
  FrameMargins->0,
  ImageSize->Automatic]], "OverviewSection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[BoxData[
 PaneSelectorBox[{False->
  FrameBox[
   StyleBox["\<\"ProbitModelFit\"\>", "OverviewSection",
    StripOnInput->False],
   BoxFrame->2,
   FrameMargins->{{15, 15}, {5, 5}},
   FrameStyle->None,
   RoundingRadius->5,
   StripOnInput->False], True->
  TemplateBox[{FrameBox[
     StyleBox["\"ProbitModelFit\"", "OverviewSection", 
      GrayLevel[1], StripOnInput -> False], 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> None, RoundingRadius -> 
     5, Background -> RGBColor[0.811765, 0.117647, 0.145098, 1], StripOnInput -> 
     False],"\" \[RightGuillemet] \"",FrameBox[
     StyleBox[
     "\"probit regression\"", "OverviewSection", StripOnInput -> False], 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> 
     RGBColor[0.811765, 0.117647, 0.145098, 1], BoxFrame -> 2, RoundingRadius -> 
     5, Background -> GrayLevel[1], StripOnInput -> False]},
   "Row",
   DisplayFunction->(
    RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
   InterpretationFunction->(RowBox[{"Row", "[", 
      RowBox[{"{", 
        RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )]}, Dynamic[
   CurrentValue["MouseOver"]],
  FrameMargins->0,
  ImageSize->Automatic]], "OverviewSection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[BoxData[
 PaneSelectorBox[{False->
  FrameBox[
   StyleBox["\<\"GeneralizedLinearModelFit\"\>", "OverviewSection",
    StripOnInput->False],
   BoxFrame->2,
   FrameMargins->{{15, 15}, {5, 5}},
   FrameStyle->None,
   RoundingRadius->5,
   StripOnInput->False], True->
  TemplateBox[{FrameBox[
     StyleBox["\"GeneralizedLinearModelFit\"", "OverviewSection", 
      GrayLevel[1], StripOnInput -> False], 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> None, RoundingRadius -> 
     5, Background -> RGBColor[0.811765, 0.117647, 0.145098, 1], StripOnInput -> 
     False],"\" \[RightGuillemet] \"",FrameBox[
     StyleBox[
     "\"generalized linear models with specified distributional structures \
and links\"", "OverviewSection", StripOnInput -> False], 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> 
     RGBColor[0.811765, 0.117647, 0.145098, 1], BoxFrame -> 2, RoundingRadius -> 
     5, Background -> GrayLevel[1], StripOnInput -> False]},
   "Row",
   DisplayFunction->(
    RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
   InterpretationFunction->(RowBox[{"Row", "[", 
      RowBox[{"{", 
        RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )]}, Dynamic[
   CurrentValue["MouseOver"]],
  FrameMargins->0,
  ImageSize->Automatic]], "OverviewSection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell["\<\
Each of these functions support continuous and nominal predictor variables.\
\>", "Text"],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["\<\
Model Fitting and Analysis: GLM\[LongDash]Logit and probit models\
\>", "Section"],

Cell[TextData[{
 "Logit and probit models are commonly used to model probabilities. The \
observed probabilities are assumed to be success probabilities realized from \
binomial distributions. Logit and probit models can be fitted via the ",
 Cell[BoxData[
  ButtonBox["LogitModelFit",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/LogitModelFit"]], "InlineFormula"],
 " and ",
 Cell[BoxData[
  ButtonBox["ProbitModelFit",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/ProbitModelFit"]], "InlineFormula"],
 " functions."
}], "Text",
 CellChangeTimes->{{3.436118003505559*^9, 3.436118005068839*^9}, {
  3.4378469431856613`*^9, 3.437846998661125*^9}, {3.4378491428924274`*^9, 
  3.437849160607336*^9}, {3.437929893859988*^9, 3.4379299332004642`*^9}}],

Cell["\<\
Here is some data with responses written as number of successes over number \
of trials.\
\>", "MathCaption",
 CellChangeTimes->{{3.4378510742083063`*^9, 3.437851131699672*^9}}],

Cell[BoxData[
 RowBox[{"binomdata", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", 
      FractionBox["3", "8"]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"1.5", ",", 
      FractionBox["2", "10"]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"2.1", ",", 
      FractionBox["4", "6"]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"2.5", ",", 
      FractionBox["3", "7"]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"3.4", ",", 
      FractionBox["8", "11"]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"4", ",", 
      FractionBox["12", "14"]}], "}"}]}], "}"}]}]], "Input"],

Cell["The fractions are treated as probabilities.", "MathCaption",
 CellChangeTimes->{{3.4341126639277687`*^9, 3.4341127119416065`*^9}, {
  3.4349920829834433`*^9, 3.4349920843742914`*^9}, {3.437851138157092*^9, 
  3.437851167098218*^9}, {3.437929222040888*^9, 3.4379292221815014`*^9}}],

Cell[BoxData[
 RowBox[{"logit1", "=", 
  RowBox[{"LogitModelFit", "[", 
   RowBox[{"binomdata", ",", "x", ",", "x"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.434112700709658*^9, 3.4341127077746634`*^9}, 
   3.434992087406026*^9, {3.4378470667545986`*^9, 3.437847080076215*^9}}],

Cell["\<\
Weights can be used to incorporate the number of trials, in this case the \
denominators of the probabilities.\
\>", "MathCaption",
 CellChangeTimes->{{3.4378511700845795`*^9, 3.4378512131132*^9}, {
  3.437929233024349*^9, 3.4379292608657827`*^9}}],

Cell[BoxData[
 RowBox[{"logit2", "=", 
  RowBox[{"LogitModelFit", "[", 
   RowBox[{"binomdata", ",", "x", ",", "x", ",", 
    RowBox[{"Weights", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"8", ",", "10", ",", "6", ",", "7", ",", "11", ",", "14"}], 
      "}"}]}]}], "]"}]}]], "Input"],

Cell["", "Spacer"],

Cell[TextData[{
 Cell[BoxData[
  ButtonBox["ProbitModelFit",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/ProbitModelFit"]], "InlineFormula"],
 " is the analogous function for probit models. The general features and \
available results are the same as those for ",
 Cell[BoxData[
  ButtonBox["LogitModelFit",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/LogitModelFit"]], "InlineFormula"],
 "."
}], "Text"],

Cell["This is a probit model for the same data.", "MathCaption",
 CellChangeTimes->{{3.437929580026726*^9, 3.437929593963066*^9}}],

Cell[BoxData[
 RowBox[{"probit", "=", 
  RowBox[{"ProbitModelFit", "[", 
   RowBox[{"binomdata", ",", "x", ",", "x"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.437929489362395*^9, 3.4379295999625673`*^9}}],

Cell["", "Spacer"],

Cell[TextData[{
 "The functional form as well as numerous results for a fitted function can \
be obtained from the ",
 Cell[BoxData[
  ButtonBox["FittedModel",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/FittedModel"]], "InlineFormula"],
 " as was the case for linear models."
}], "Text",
 CellChangeTimes->{{3.437929296815916*^9, 3.437929340406039*^9}}],

Cell["The fitted models with and without weights differ somewhat.", \
"MathCaption",
 CellChangeTimes->{{3.437929279426738*^9, 3.437929293691176*^9}, {
  3.437929384402378*^9, 3.4379294200869093`*^9}}],

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Normal", "[", "logit1", "]"}], ",", "\"\<   \>\"", ",", 
    RowBox[{"Normal", "[", "logit2", "]"}], ",", "\"\<   \>\"", ",", 
    RowBox[{"Normal", "[", "probit", "]"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.4421383446848497`*^9, 3.442138427657987*^9}, {
  3.4976266186453*^9, 3.497626623036431*^9}}],

Cell["", "Spacer"],

Cell[TextData[{
 "The available properties differ somewhat from those for linear models. As \
with linear models, a list of available properties can be obtained by \
evaluating the ",
 Cell[BoxData[
  ButtonBox["FittedModel",
   BaseStyle->"Link"]], "InlineFormula"],
 " object with argument ",
 Cell[BoxData["\"\<Properties\>\""], "InlineFormula"],
 "."
}], "Text"],

Cell["Here are the parameter tables for the three models.", "MathCaption",
 CellChangeTimes->{{3.4379294223679695`*^9, 3.437929444584871*^9}, {
  3.437930280343455*^9, 3.437930281468361*^9}, {3.497626889077409*^9, 
  3.4976268899055815`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"logit1", "[", "\"\<ParameterTable\>\"", "]"}], ",", 
   RowBox[{"logit2", "[", "\"\<ParameterTable\>\"", "]"}], ",", 
   RowBox[{"probit", "[", "\"\<ParameterTable\>\"", "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.4378492794989176`*^9, 3.4378493012321234`*^9}, {
  3.497626631318635*^9, 3.4976266387413645`*^9}}],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["\<\
Model Fitting and Analysis: GLM\[LongDash]Poisson count models\
\>", "Section"],

Cell[TextData[{
 "Logit and probit models are generalized linear models for probability \
responses. These models could equivalently be fit via ",
 Cell[BoxData[
  ButtonBox["GeneralizedLinearModelFit",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/GeneralizedLinearModelFit"]], "InlineFormula"],
 " using the option ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["ExponentialFamily",
    BaseStyle->"Link"], "\[Rule]", "\"\<Binomial\>\""}]], "InlineFormula"],
 " and an appropriate choice of ",
 Cell[BoxData[
  ButtonBox["LinkFunction",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/LinkFunction"]], "InlineFormula"],
 ". "
}], "Text"],

Cell["\<\
Models of count data commonly assume Poisson distributed responses. Predictor \
variables can be continuous (real\[Hyphen]valued) or nominal (taking on one \
of a finite number of distinct names or categories).\
\>", "Text",
 CellChangeTimes->{{3.437934672273569*^9, 3.4379348243465724`*^9}}],

Cell["Here is some count data for two categorical variables.", "MathCaption",
 CellChangeTimes->{{3.436118003505559*^9, 3.436118005068839*^9}, {
  3.4378478174013414`*^9, 3.4378478299878893`*^9}, {3.437934839475638*^9, 
  3.437934892442997*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"countdata", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "agree", ",", "53"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", "disagree", ",", "24"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", "undecided", ",", "13"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"b", ",", "agree", ",", "78"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"b", ",", "disagree", ",", "48"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"b", ",", "undecided", ",", "110"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"c", ",", "agree", ",", "20"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"c", ",", "disagree", ",", "58"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"c", ",", "undecided", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"d", ",", "agree", ",", "42"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"d", ",", "disagree", ",", "38"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"d", ",", "undecided", ",", "4"}], "}"}]}], "}"}]}], 
  ";"}]], "Input"],

Cell["", "Spacer"],

Cell[TextData[{
 "The ",
 Cell[BoxData[
  ButtonBox["NominalVariables",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/NominalVariables"]], "InlineFormula"],
 " option can be used to specify which variables are to be treated as nominal."
}], "Text",
 CellChangeTimes->{{3.437935169329904*^9, 3.4379351957901397`*^9}, 
   3.4379352299555707`*^9, 3.437935270200761*^9}],

Cell["The default Poisson model is a log-linear model.", "MathCaption",
 CellChangeTimes->{{3.4341126639277687`*^9, 3.4341127119416065`*^9}, {
   3.4349920829834433`*^9, 3.4349920843742914`*^9}, {3.4379352742174654`*^9, 
   3.437935286580162*^9}, 3.437936828994652*^9}],

Cell[BoxData[
 RowBox[{"loglinmodel", "=", 
  RowBox[{"GeneralizedLinearModelFit", "[", 
   RowBox[{"countdata", ",", 
    RowBox[{"{", 
     RowBox[{"group", ",", "opinion"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"group", ",", "opinion"}], "}"}], ",", 
    RowBox[{"ExponentialFamily", "\[Rule]", "\"\<Poisson\>\""}], ",", 
    RowBox[{"NominalVariables", "\[Rule]", "All"}]}], "]"}]}]], "Input"],

Cell["", "Spacer"],

Cell[TextData[{
 "As with continuous predictors, the ",
 Cell[BoxData[
  ButtonBox["FittedModel",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/FittedModel"]], "InlineFormula"],
 " can be evaluated at a particular point. Terms arising from nominal \
variables are represented as ",
 Cell[BoxData[
  ButtonBox["DiscreteIndicator",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/DiscreteIndicator"]], "InlineFormula"],
 " functions."
}], "Text",
 CellChangeTimes->{{3.43793548100741*^9, 3.437935517329671*^9}, {
   3.4379355534643817`*^9, 3.4379355918340673`*^9}, 3.4379368311358523`*^9}],

Cell[TextData[{
 "These are the predicted count for group ",
 StyleBox["a", "MR"],
 " and ",
 StyleBox["agree", "MR"],
 ", and the predicted function for group ",
 StyleBox["a", "MR"],
 "."
}], "MathCaption",
 CellChangeTimes->{{3.4379355952881207`*^9, 3.437935645082752*^9}, {
  3.437935715476669*^9, 3.4379357289802976`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"loglinmodel", "[", 
    RowBox[{"a", ",", "agree"}], "]"}], ",", 
   RowBox[{"loglinmodel", "[", 
    RowBox[{"a", ",", "opinion"}], "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.437935406690564*^9, 3.437935440730962*^9}}],

Cell["", "Spacer"],

Cell["\<\
Other forms of Poisson model can be fitted by specifying a different \
invertible link function.\
\>", "Text",
 CellChangeTimes->{{3.437935737482582*^9, 3.437935782400903*^9}}],

Cell["This gives a linear Poisson count model.", "MathCaption",
 CellChangeTimes->{{3.4379357869646297`*^9, 3.4379358132842026`*^9}}],

Cell[BoxData[
 RowBox[{"linmodel", "=", 
  RowBox[{"GeneralizedLinearModelFit", "[", 
   RowBox[{"countdata", ",", 
    RowBox[{"{", 
     RowBox[{"group", ",", "opinion"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"group", ",", "opinion"}], "}"}], ",", 
    RowBox[{"ExponentialFamily", "\[Rule]", "\"\<Poisson\>\""}], ",", 
    RowBox[{"NominalVariables", "\[Rule]", "All"}], ",", 
    RowBox[{"LinkFunction", "\[Rule]", "\"\<IdentityLink\>\""}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4379352963953*^9, 3.4379353179948545`*^9}}],

Cell["\<\
This model is easily visualized using the charting functions.\
\>", "MathCaption",
 CellChangeTimes->{{3.443780505377714*^9, 3.443780534303816*^9}, 
   3.443780639162862*^9}],

Cell[BoxData[
 RowBox[{"BarChart", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"linmodel", "[", 
        RowBox[{"a", ",", "#"}], "]"}], ",", 
       RowBox[{"linmodel", "[", 
        RowBox[{"b", ",", "#"}], "]"}], ",", 
       RowBox[{"linmodel", "[", 
        RowBox[{"c", ",", "#"}], "]"}]}], "}"}], "&"}], "/@", 
    RowBox[{"{", 
     RowBox[{"agree", ",", "disagree", ",", "undecided"}], "}"}]}], ",", 
   RowBox[{"ChartElementFunction", "\[Rule]", "\"\<GlassRectangle\>\""}], ",", 
   RowBox[{"ChartLabels", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "\"\<agree\>\"", ",", "\"\<disagree\>\"", ",", "\"\<undecided\>\""}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<a\>\"", ",", "\"\<b\>\"", ",", "\"\<c\>\""}], "}"}]}], 
     "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4437799596346483`*^9, 3.4437800101139317`*^9}, {
  3.44378007558885*^9, 3.443780094926303*^9}, {3.443780340549735*^9, 
  3.4437803860999403`*^9}}],

Cell["", "Spacer"],

Cell[TextData[{
 Cell[BoxData[
  ButtonBox["GeneralizedLinearModelFit",
   BaseStyle->"Link"]], "InlineFormula"],
 "\[CloseCurlyQuote]s ",
 Cell[BoxData[
  ButtonBox["ExponentialFamily",
   BaseStyle->"Link"]], "InlineFormula"],
 " option also includes special cases for gamma and inverse Gaussian models \
as well as a general quasi\[Hyphen]likelihood framework for defining \
additional model structures."
}], "Text",
 CellChangeTimes->{{3.4977167692543116`*^9, 3.497716878431077*^9}, {
  3.497716926948876*^9, 3.497716964997455*^9}}],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Model Fitting and Analysis: Nonlinear regression", "Section"],

Cell[TextData[{
 "The ",
 Cell[BoxData[
  ButtonBox["NonlinearModelFit",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/NonlinearModelFit"]], "InlineFormula"],
 " function works for nonlinear least squares models in much the same way the \
other model fit functions we have just seen work with linear and generalized \
linear models."
}], "Text",
 CellChangeTimes->{{3.434112612965945*^9, 3.4341126385971403`*^9}, {
  3.437937105459571*^9, 3.437937154260797*^9}}],

Cell["\<\
This fits the previously used linear data set to a nonlinear model.\
\>", "MathCaption",
 CellChangeTimes->{{3.4380898385465317`*^9, 3.438089858468534*^9}}],

Cell[BoxData[
 RowBox[{"nlm", "=", 
  RowBox[{"NonlinearModelFit", "[", 
   RowBox[{"lineardata", ",", 
    RowBox[{"Sqrt", "[", 
     RowBox[{
      RowBox[{"a", "*", "x"}], "+", 
      RowBox[{"b", "*", "y", "*", "z"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4341126420591497`*^9, 3.4341126450042067`*^9}, {
   3.4341126979682484`*^9, 3.434112698532195*^9}, 3.4341127487704916`*^9, 
   3.434113863963032*^9, 3.438088492499484*^9, {3.4383659982328215`*^9, 
   3.438366010482587*^9}, {3.438366183416766*^9, 3.438366187432314*^9}, {
   3.438366359882128*^9, 3.438366458848978*^9}, {3.4383664994419484`*^9, 
   3.43836650300438*^9}, {3.4383665347068963`*^9, 3.438366534831894*^9}}],

Cell["", "Spacer"],

Cell[TextData[{
 "Nonlinear model properties differ somewhat from linear and generalized \
linear properties, and a list can be obtained by evaluating ",
 StyleBox["nlm[\[OpenCurlyDoubleQuote]Properties\[CloseCurlyDoubleQuote]]", 
  "MR"],
 "."
}], "Text"],

Cell["Here we obtain the functional form of the fitted model.", "MathCaption"],

Cell[BoxData[
 RowBox[{"Normal", "[", "nlm", "]"}]], "Input",
 CellChangeTimes->{{3.4341127209334316`*^9, 3.434112727575476*^9}, {
   3.442051958332156*^9, 3.44205198972167*^9}, 3.442054069820277*^9, {
   3.442059663835105*^9, 3.4420596835662527`*^9}}],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["\<\
Model Fitting and Analysis: Nonlinear regression\[LongDash]starting values \
and constraints\
\>", "Section"],

Cell["\<\
Fitting nonlinear models requires an iterative process. Choosing good \
starting values for parameters can be important to get good results. By \
default, all parameters have starting value 1.\
\>", "Text"],

Cell[TextData[{
 "Here the model is changed to have a negative sign in front of the \
coefficient ",
 Cell[BoxData[
  StyleBox["a", "TI"]], "InlineFormula"],
 "."
}], "MathCaption",
 CellChangeTimes->{{3.4383674150024943`*^9, 3.438367445892526*^9}}],

Cell[BoxData[
 RowBox[{"NonlinearModelFit", "[", 
  RowBox[{"lineardata", ",", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "a"}], "*", "x"}], "+", 
     RowBox[{"b", "*", "y", "*", "z"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4383665921901674`*^9, 3.438366592705783*^9}}],

Cell["", "MR"],

Cell[TextData[{
 "This is really the same model as before except that the sign for the \
coefficient ",
 StyleBox["a", "MR"],
 " is different. In this case the fitting fails because the starting values \
result in complex numbers. The iterative method would need to pass from \
positive values of ",
 StyleBox["a", "MR"],
 " to negative values with this starting value."
}], "Text"],

Cell[TextData[{
 "Giving a negative starting value for ",
 StyleBox["a", "MR"],
 " gets a good result in this case."
}], "MathCaption",
 CellChangeTimes->{{3.4383675293127995`*^9, 3.4383675508280115`*^9}, {
  3.4383675894835196`*^9, 3.4383676246390944`*^9}}],

Cell[BoxData[
 RowBox[{"nlm2", "=", 
  RowBox[{"NonlinearModelFit", "[", 
   RowBox[{"lineardata", ",", 
    RowBox[{"Sqrt", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "a"}], "*", "x"}], "+", 
      RowBox[{"b", "*", "y", "*", "z"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"a", ",", 
        RowBox[{"-", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"b", ",", "5"}], "}"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.438366515847883*^9, 3.4383665377068386`*^9}, {
  3.438367699278286*^9, 3.438367700512637*^9}}],

Cell["The estimates are equivalent up to a sign change.", "MathCaption",
 CellChangeTimes->{{3.43836773473073*^9, 3.438367758355277*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"nlm", "[", "\"\<ParameterTable\>\"", "]"}], ",", 
   RowBox[{"nlm2", "[", "\"\<ParameterTable\>\"", "]"}]}], "}"}]], "Input"],

Cell["", "Spacer"],

Cell["\<\
Constraints can also be used. Some properties derived from unconstrained \
distributional assumptions, however, may not be valid.\
\>", "Text"],

Cell[TextData[{
 "Here ",
 StyleBox["b", "MR"],
 " is constrained to be greater than 15."
}], "MathCaption"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"nlmc", "=", 
   RowBox[{"NonlinearModelFit", "[", 
    RowBox[{"lineardata", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{"a", "*", "x"}], "+", 
         RowBox[{"b", "*", "y", "*", "z"}]}], "]"}], ",", 
       RowBox[{"b", ">", "15"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", "b"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Normal", "[", "nlmc", "]"}]}], "Input",
 CellChangeTimes->{{3.434112735627389*^9, 3.4341127926800475`*^9}, 
   3.434113866954856*^9, 3.4380884931244926`*^9, {3.438367792713992*^9, 
   3.438367793448353*^9}, {3.44213911641383*^9, 3.442139124539835*^9}}],

Cell["", "MR"],

Cell["\<\
A warning is generated if affected properties are requested. If the estimates \
are far from the constraint boundaries so that the constraint region covers \
nearly all of the probability for the parameter vector, results from the \
unconstrained distributional assumptions are likely fine.\
\>", "Text",
 CellChangeTimes->{{3.4383701987928834`*^9, 3.438370278516427*^9}, {
  3.438370399071311*^9, 3.438370470037462*^9}, {3.438370735605375*^9, 
  3.4383707736062007`*^9}}],

Cell["\<\
In this case the confidence intervals contain points outside the constraint \
region.\
\>", "MathCaption",
 CellChangeTimes->{{3.4383703041317987`*^9, 3.438370356832533*^9}}],

Cell[BoxData[
 RowBox[{"nlmc", "[", "\"\<ParameterConfidenceIntervals\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.4383683117866964`*^9, 3.4383683583858447`*^9}}],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Model Fitting and Analysis: ANOVA", "Section"],

Cell[TextData[{
 "The analysis of variance (ANOVA) model is a categorical linear regression \
model. While such models can be fit and analyzed using ",
 Cell[BoxData[
  ButtonBox["LinearModelFit",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/LinearModelFit"]], "InlineFormula"],
 " with ",
 Cell[BoxData[
  ButtonBox["NominalVariables",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/NominalVariables"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  ButtonBox["ANOVA",
   BaseStyle->"Link",
   ButtonData->"paclet:ANOVA/ref/ANOVA"]], "InlineFormula"],
 " provides direct computation of cell means and tests of categorical \
differences."
}], "Text",
 CellChangeTimes->{{3.4361177128502846`*^9, 3.436117802201993*^9}, {
  3.4361178412996264`*^9, 3.4361178426596794`*^9}, {3.4361183347544837`*^9, 
  3.436118343958728*^9}}],

Cell["Here we import some data from a text file.", "MathCaption"],

Cell[BoxData[
 RowBox[{"anovadata", "=", 
  RowBox[{"Import", "[", 
   RowBox[{"\"\<anovadata.txt\>\"", ",", "\"\<Table\>\""}], "]"}]}]], "Input"],

Cell[TextData[{
 "The ",
 Cell[BoxData[
  ButtonBox["ANOVA",
   BaseStyle->"Link",
   ButtonData->"paclet:ANOVA/ref/ANOVA"]], "InlineFormula"],
 " function is defined in the ",
 ButtonBox["ANOVA",
  BaseStyle->"Link",
  ButtonData->"paclet:ANOVA/guide/AnalysisOfVariancePackage"],
 " package."
}], "MathCaption"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<ANOVA`\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.4355133050981565`*^9, 3.435513309939043*^9}}],

Cell["\<\
By default an ANOVA table and table of cell means are returned.\
\>", "MathCaption"],

Cell[BoxData[
 RowBox[{"ANOVA", "[", 
  RowBox[{"anovadata", ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y"}], "}"}]}], "]"}]], "Input"],

Cell["", "MR"],

Cell["\<\
The cell means can be omitted and significance tests performed if desired.\
\>", "Text"],

Cell["\<\
This gives an analysis of variance performing Bonferroni and Tukey tests for \
significant differences between levels of categorical variables.\
\>", "MathCaption"],

Cell[BoxData[
 RowBox[{"ANOVA", "[", 
  RowBox[{"anovadata", ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y"}], "}"}], ",", 
   RowBox[{"CellMeans", "\[Rule]", "False"}], ",", 
   RowBox[{"PostTests", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Bonferroni", ",", "Tukey"}], "}"}]}]}], "]"}]], "Input"],

Cell[TextData[{
 "The same model could be fit using ",
 Cell[BoxData[
  ButtonBox["LinearModelFit",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/LinearModelFit"]], "InlineFormula"],
 " as follows."
}], "MathCaption",
 CellChangeTimes->{{3.4361182893864965`*^9, 3.4361183299101443`*^9}}],

Cell[BoxData[
 RowBox[{"anovalm", "=", 
  RowBox[{"LinearModelFit", "[", 
   RowBox[{"anovadata", ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y"}], "}"}], ",", 
    RowBox[{"NominalVariables", "\[Rule]", "All"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4361180679462805`*^9, 3.4361180971715755`*^9}}],

Cell[BoxData[
 RowBox[{"anovalm", "[", "\"\<ANOVATable\>\"", "]"}]], "Input"],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Further Resources", "Section"],

Cell[CellGroupData[{

Cell["Tutorials", "MoreExamplesSection"],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["Basic Statistics",
 BaseStyle->"Link",
 ButtonData->"paclet:tutorial/BasicStatistics"]], "Item",
 CellID->900583006],

Cell[TextData[ButtonBox["Continuous Distributions",
 BaseStyle->"Link",
 ButtonData->"paclet:tutorial/ContinuousDistributions"]], "Item",
 CellID->633837786],

Cell[TextData[ButtonBox["Discrete Distributions",
 BaseStyle->"Link",
 ButtonData->"paclet:tutorial/DiscreteDistributions"]], "Item",
 CellID->1392780182],

Cell[TextData[ButtonBox["Descriptive Statistics",
 BaseStyle->"Link",
 ButtonData->"paclet:tutorial/DescriptiveStatistics"]], "Item",
 CellID->884766574],

Cell[TextData[ButtonBox["Convolutions and Correlations",
 BaseStyle->"Link",
 ButtonData->"paclet:tutorial/ConvolutionsAndCorrelations"]], "Item",
 CellID->1095037390],

Cell[TextData[ButtonBox["Curve Fitting",
 BaseStyle->"Link",
 ButtonData->"paclet:tutorial/CurveFitting"]], "Item",
 CellID->358558940],

Cell[TextData[ButtonBox["Importing and Exporting Data",
 BaseStyle->"Link",
 ButtonData->"paclet:tutorial/ImportingAndExportingData"]], "Item",
 CellID->460991098],

Cell[TextData[ButtonBox["Pseudorandom Numbers",
 BaseStyle->"Link",
 ButtonData->"paclet:tutorial/PseudorandomNumbers"]], "Item",
 CellID->1903869357],

Cell[TextData[ButtonBox["Random Number Generation",
 BaseStyle->"Link",
 ButtonData->"paclet:tutorial/RandomNumberGeneration"]], "Item",
 CellID->825942799],

Cell[TextData[ButtonBox["Numerical Operations on Data",
 BaseStyle->"Link",
 ButtonData->"paclet:tutorial/NumericalOperationsOnDataOverview"]], "Item",
 CellID->286328585]
}, Open  ]],

Cell["", "Spacer"]
}, Closed]],

Cell[CellGroupData[{

Cell["Wolfram Education Group Seminars and Courses", "MoreExamplesSection"],

Cell[CellGroupData[{

Cell[TextData[{
 ButtonBox["S18: Import and Export Formats in ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/services/education/seminars/s18.html"], None},
  
  ButtonNote->"http://www.wolfram.com/services/education/seminars/s20.html"],
 StyleBox[ButtonBox["Mathematica",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/services/education/seminars/s18.html"], None},
  
  ButtonNote->"http://www.wolfram.com/services/education/seminars/s18.html"],
  FontSlant->"Italic"]
}], "Item",
 CellChangeTimes->{{3.5111067695579042`*^9, 3.511106770854638*^9}}],

Cell[TextData[{
 ButtonBox["S24: Working with Imported Data in ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/services/education/seminars/s24.html"], None},
  
  ButtonNote->"http://www.wolfram.com/services/education/seminars/s24.html"],
 StyleBox[ButtonBox["Mathematica",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/services/education/seminars/s24.html"], None},
  
  ButtonNote->"http://www.wolfram.com/services/education/seminars/s24.html"],
  FontSlant->"Italic"],
 " "
}], "Item"],

Cell[TextData[{
 ButtonBox["S41: Statistical Visualization with ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/services/education/seminars/s41.html"], None},
  
  ButtonNote->"http://www.wolfram.com/services/education/seminars/s41.html"],
 StyleBox[ButtonBox["Mathematica",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/services/education/seminars/s41.html"], None},
  
  ButtonNote->"http://www.wolfram.com/services/education/seminars/s41.html"],
  FontSlant->"Italic"],
 ButtonBox[" ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/services/education/seminars/s41.html"], None},
  
  ButtonNote->"http://www.wolfram.com/services/education/seminars/s41.html"]
}], "Item"],

Cell[TextData[{
 ButtonBox["M215: Applied Statistical Analysis with ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/services/education/courses/m215.html"], None}],
 StyleBox[ButtonBox["Mathematica",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/services/education/courses/m215.html"], None}],
  FontSlant->"Italic"]
}], "Item"],

Cell[TextData[{
 ButtonBox["M221: Introduction to Programming in ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/services/education/courses/m221.html"], None}],
 StyleBox[ButtonBox["Mathematica",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/services/education/courses/m221.html"], None}],
  FontSlant->"Italic"]
}], "Item"]
}, Open  ]],

Cell["", "Spacer"]
}, Closed]],

Cell[CellGroupData[{

Cell["Resources on the Web", "MoreExamplesSection"],

Cell[CellGroupData[{

Cell[TextData[{
 "Examples on the Web: ",
 ButtonBox["Statistical Visualization",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/mathematica/new-in-8/statistical-\
visualization/"], None},
  ButtonNote->
   "http://www.wolfram.com/mathematica/new-in-8/statistical-visualization/"]
}], "Item",
 CellChangeTimes->{{3.5111069448583307`*^9, 3.511106974879408*^9}, {
  3.511107029052155*^9, 3.511107036128873*^9}}],

Cell[TextData[{
 "Wolfram Demonstrations Project: ",
 ButtonBox["demonstrations.wolfram.com",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com"], None}]
}], "Item"],

Cell[TextData[{
 "Wolfram Library Archive: ",
 ButtonBox["library.wolfram.com",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://library.wolfram.com"], None}]
}], "Item"],

Cell[TextData[{
 "Training from Wolfram Education Group: ",
 ButtonBox["www.wolfram.com/weg",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/services/education/"], None}]
}], "Item"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Initialization", "Section",
 InitializationGroup->True],

Cell[CellGroupData[{

Cell["StyleTable", "MoreExamplesSection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"StyleTable", "[", 
   RowBox[{"tbl_Style", ",", 
    RowBox[{"rools_List", "?", "OptionQ"}]}], "]"}], ":=", 
  RowBox[{"tbl", "/.", 
   RowBox[{
    RowBox[{"Style", "[", 
     RowBox[{"x_", ",", "\"\<DialogStyle\>\""}], "]"}], "\[RuleDelayed]", 
    RowBox[{"Style", "[", 
     RowBox[{"x", ",", "\"\<DialogStyle\>\"", ",", 
      RowBox[{"Sequence", "@@", "rools"}]}], "]"}]}]}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Overview Mouseover", "MoreExamplesSection",
 CellChangeTimes->{{3.49896919710295*^9, 3.498969204966164*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"m8red", "[", "a_", "]"}], ":=", 
   RowBox[{"RGBColor", "[", 
    RowBox[{"0.811765", ",", "0.117647", ",", "0.145098", ",", "a"}], "]"}]}],
   ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"OverviewMouseover", "[", 
   RowBox[{"header_", ",", "subs_"}], "]"}], ":=", 
  RowBox[{"CellPrint", "@", 
   RowBox[{"Cell", "[", 
    RowBox[{
     RowBox[{"BoxData", "[", 
      RowBox[{"ToBoxes", "@", 
       RowBox[{"Mouseover", "[", 
        RowBox[{
         RowBox[{"Framed", "[", 
          RowBox[{
           RowBox[{"Style", "[", 
            RowBox[{"header", ",", "\"\<OverviewSection\>\""}], "]"}], ",", 
           RowBox[{"FrameMargins", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"15", ",", "15"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"5", ",", "5"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"BoxFrame", "\[Rule]", "2"}], ",", 
           RowBox[{"FrameStyle", "\[Rule]", "None"}], ",", 
           RowBox[{"RoundingRadius", "\[Rule]", "5"}]}], "]"}], ",", 
         "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{"Evaluate", "@", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"subs", "\[Equal]", "\"\<\>\""}], ",", 
            RowBox[{"Framed", "[", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{
               "header", ",", "\"\<OverviewSection\>\"", ",", "White"}], 
               "]"}], ",", 
              RowBox[{"FrameMargins", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"15", ",", "15"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"5", ",", "5"}], "}"}]}], "}"}]}], ",", 
              RowBox[{"BoxFrame", "\[Rule]", "2"}], ",", 
              RowBox[{"FrameStyle", "\[Rule]", "None"}], ",", 
              RowBox[{"RoundingRadius", "\[Rule]", "5"}], ",", 
              RowBox[{"Background", "\[Rule]", 
               RowBox[{"m8red", "[", "1", "]"}]}]}], "]"}], ",", 
            RowBox[{"Row", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Framed", "[", 
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{
                  "header", ",", "\"\<OverviewSection\>\"", ",", "White"}], 
                  "]"}], ",", 
                 RowBox[{"FrameMargins", "\[Rule]", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"15", ",", "15"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"5", ",", "5"}], "}"}]}], "}"}]}], ",", 
                 RowBox[{"FrameStyle", "\[Rule]", "None"}], ",", 
                 RowBox[{"RoundingRadius", "\[Rule]", "5"}], ",", 
                 RowBox[{"Background", "\[Rule]", 
                  RowBox[{"m8red", "[", "1", "]"}]}]}], "]"}], ",", 
               "\"\< \[RightGuillemet] \>\"", ",", 
               RowBox[{"Framed", "[", 
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{"subs", ",", "\"\<OverviewSection\>\""}], "]"}], 
                 ",", 
                 RowBox[{"FrameMargins", "\[Rule]", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"15", ",", "15"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"5", ",", "5"}], "}"}]}], "}"}]}], ",", 
                 RowBox[{"FrameStyle", "\[Rule]", 
                  RowBox[{"m8red", "[", "1", "]"}]}], ",", 
                 RowBox[{"BoxFrame", "\[Rule]", "2"}], ",", 
                 RowBox[{"RoundingRadius", "\[Rule]", "5"}], ",", 
                 RowBox[{"Background", "\[Rule]", "White"}]}], "]"}]}], "}"}],
              "]"}]}], "]"}]}]}], "]"}]}], "]"}], ",", 
     "\"\<OverviewSection\>\""}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MapThread", "[", 
     RowBox[{"OverviewMouseover", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<\!\(\*
StyleBox[\"Descriptive\",
FontWeight->\"Bold\"]\)\!\(\*
StyleBox[\" \",
FontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"and\",
FontWeight->\"Bold\"]\)\!\(\*
StyleBox[\" \",
FontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"Exploratory\",
FontWeight->\"Bold\"]\)\!\(\*
StyleBox[\" \",
FontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"S\",
FontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"tatistics\",
FontWeight->\"Bold\"]\)\>\"", ",", 
           "\"\<descriptive measures and charts, smoothing, transformations, \
clustering, visualization\>\""}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"\"\<\!\(\*
StyleBox[\"Statistical\",
FontWeight->\"Bold\"]\)\!\(\*
StyleBox[\" \",
FontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"D\",
FontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"istributions\",
FontWeight->\"Bold\"]\)\>\"", ",", 
           "\"\<parametric and nonparametric distributions, properties of \
distributions, random numbers, parameter estimation, visualization\>\""}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\"\<\!\(\*
StyleBox[\"Hypothesis\",
FontWeight->\"Bold\"]\)\!\(\*
StyleBox[\" \",
FontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"T\",
FontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"esting\",
FontWeight->\"Bold\"]\)\>\"", ",", 
           "\"\<tests of distributional goodness of fit, tests of location \
and scale\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\"\<\!\(\*
StyleBox[\"Model\",
FontWeight->\"Bold\"]\)\!\(\*
StyleBox[\" \",
FontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"F\",
FontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"itting\",
FontWeight->\"Bold\"]\)\!\(\*
StyleBox[\" \",
FontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"and\",
FontWeight->\"Bold\"]\)\!\(\*
StyleBox[\" \",
FontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"A\",
FontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"nalysis\",
FontWeight->\"Bold\"]\)\>\"", ",", 
           "\"\<linear regression, nonlinear regression, generalized linear \
models including logit and probit, ANOVA\>\""}], "}"}]}], "}"}], "]"}]}], 
     "]"}], ";"}], "\[IndentingNewLine]", "*)"}], 
  "\[IndentingNewLine]"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"MapThread", "[", 
    RowBox[{"OverviewMouseover", ",", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "\"\<ProbabilityDistribution\>\"", ",", 
          "\"\<defined by a PDF or other characteristic and the support of \
the distribution\>\""}], "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<TransformedDistribution\>\"", ",", 
          "\"\<distribution of a functional transformation of one or more \
random variates\>\""}], "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<TruncatedDistribution\>\"", ",", 
          "\"\<distribution with support truncated above or below and \
rescaled to have probability 1\>\""}], "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<CensoredDistribution\>\"", ",", 
          "\"\<distribution with upper and lower tail probabilities \
concentrated at defined censoring points\>\""}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<OrderDistribution\>\"", ",", 
          "\"\<distribution of the \
\!\(TraditionalForm\`\*SuperscriptBox[\(k\), \(th\)]\) order statistic for a \
sample of size \!\(TraditionalForm\`n\)\>\""}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<MixtureDistribution\>\"", ",", 
          "\"\<component mixture distribution\>\""}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<ParameterMixtureDistribution\>\"", ",", 
          "\"\<parametric mixture distribution\>\""}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<ProductDistribution\>\"", ",", 
          "\"\<multivariate distribution with independent components defined \
by distributions of the components\>\""}], "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<MarginalDistribution\>\"", ",", 
          "\"\<lower dimensional distribution obtained from a multivariate \
distribution\>\""}], "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<CopulaDistribution\>\"", ",", 
          "\"\<multivariate distribution defined by marginal distributions \
and a kernel that defines how they are combined\>\""}], "}"}]}], 
       "\[IndentingNewLine]", "}"}], "]"}]}], "]"}], ";"}], 
  "\[IndentingNewLine]", "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"MapThread", "[", 
    RowBox[{"OverviewMouseover", ",", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<LinearModelFit\>\"", ",", "\"\<linear regression\>\""}],
          "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<LogitModelFit\>\"", ",", "\"\<logistic regression\>\""}], "}"}],
         ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"\"\<ProbitModelFit\>\"", ",", "\"\<probit regression\>\""}],
          "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<GeneralizedLinearModelFit\>\"", ",", 
          "\"\<generalized linear models with specified distributional \
structures and links\>\""}], "}"}]}], "\[IndentingNewLine]", "}"}], "]"}]}], 
    "]"}], ";"}], "\[IndentingNewLine]", "*)"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["FillToLinePlot", "MoreExamplesSection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FillToLinePlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"f1_", ",", "lab1_"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"f2_", ",", "lab2_"}], "}"}], ",", "val_", ",", 
    RowBox[{"{", 
     RowBox[{"var_", ",", "min_", ",", "max_"}], "}"}]}], "]"}], ":=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Max", "[", 
       RowBox[{"val", ",", "f1"}], "]"}], ",", 
      RowBox[{"Max", "[", 
       RowBox[{"val", ",", "f2"}], "]"}], ",", 
      RowBox[{"Tooltip", "[", 
       RowBox[{"f1", ",", "lab1"}], "]"}], ",", 
      RowBox[{"Tooltip", "[", 
       RowBox[{"f2", ",", "lab2"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "min", ",", "max"}], "}"}], ",", 
    RowBox[{"Epilog", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Thick", ",", "Dashed", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"min", ",", "val"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"max", ",", "val"}], "}"}]}], "}"}], "]"}]}], "}"}], 
      "}"}]}], ",", 
    RowBox[{"Filling", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"1", "\[Rule]", "val"}], ",", 
       RowBox[{"2", "\[Rule]", "val"}]}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"ColorData", "[", 
        RowBox[{"1", ",", "1"}], "]"}], ",", 
       RowBox[{"ColorData", "[", 
        RowBox[{"1", ",", "2"}], "]"}]}], "}"}]}]}], "]"}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Graphics options", "MoreExamplesSection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"ListPlot", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PlotStyle", "\[Rule]", " ", 
       RowBox[{"PointSize", "[", "Medium", "]"}]}], ",", 
      RowBox[{"ImageSize", "\[Rule]", " ", "Large"}]}], "}"}]}], "]"}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"ListPointPlot3D", ",", 
    RowBox[{"PlotStyle", "\[Rule]", " ", 
     RowBox[{"PointSize", "[", "Medium", "]"}]}]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"DiscretePlot", ",", 
    RowBox[{"PlotStyle", "\[Rule]", " ", 
     RowBox[{"PointSize", "[", "Medium", "]"}]}]}], "]"}], ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Load packages", "MoreExamplesSection"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<HierarchicalClustering`\>\"", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<ANOVA`\>\"", "]"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Set working directory", "MoreExamplesSection"],

Cell[BoxData[
 RowBox[{"SetDirectory", "[", 
  RowBox[{"FileNameJoin", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"NotebookDirectory", "[", "]"}], ",", "\"\<Data\>\""}], "}"}], 
   "]"}], "]"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Lastly", "MoreExamplesSection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"$Line", "=", "0"}], ";"}]], "Input"]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->None,
Saveable->True,
ScreenStyleEnvironment->"SlideShow",
WindowSize->{1358, 805},
WindowMargins->{{20, Automatic}, {Automatic, 23}},
WindowTitle->"S20 Statistics & Data Analysis",
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{
   Cell[
    TextData[
     StyleBox["MATHEMATICA", FontSlant -> "Italic"], 
     ": A TECHNICAL OVERVIEW"], "Header"], None, None}, {
  None, None, "S20: INTRODUCTION TO STATISTICS WITH MATHEMATICA"}},
PrintingOptions->{"FacingPages"->False},
ShowSelection->True,
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (February 23, 2011)",
StyleDefinitions->Notebook[{
   Cell[
    CellGroupData[{
      Cell[
       TextData[{"Style Definitions for \n", 
         StyleBox["Wolfram Seminars", FontSlant -> "Italic"]}], "Subtitle", 
       CellChangeTimes -> {{3.4995511516058197`*^9, 3.499551154648994*^9}, {
        3.500930285489901*^9, 3.5009302865431967`*^9}}], 
      Cell[
       StyleData[StyleDefinitions -> "Default.nb"]], 
      Cell[
       StyleData[StyleDefinitions -> "StyleMenuClear.nb"]], 
      Cell[
       CellGroupData[{
         Cell["Style Environment Definitions", "Section"], 
         Cell[
          StyleData[
          All, "SlideShow", StyleDefinitions -> 
           StyleData[All, "Presentation"]], PageWidth -> WindowWidth, 
          DockedCells -> Cell[
            BoxData[
             GridBox[{{
                TooltipBox[
                 ButtonBox[
                  StyleBox[
                   RowBox[{"  ", "\[EmptySquare]", " "}], FontSize -> 20, 
                   GrayLevel[0.7]], Appearance -> None, 
                  ButtonFunction :> (
                   FEPrivate`NotebookToggleFullScreen[]; {}), Evaluator -> 
                  None], 
                 DynamicBox[
                  FEPrivate`FrontEndResource[
                  "SlideshowToolbarText", "TooltipToggleFullScreen"]]], 
                StyleBox[
                 RowBox[{
                   TooltipBox[
                    ButtonBox[
                    StyleBox[
                    RowBox[{" ", "\[FirstPage]", " "}], FontSize -> 25, 
                    GrayLevel[0.7]], ButtonData -> "ScrollPageFirst", 
                    Appearance -> None], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipFirstSlide"]]], 
                   "\[InvisibleSpace]", 
                   TooltipBox[
                    ButtonBox[
                    StyleBox[
                    RowBox[{" ", "\[LeftPointer]", " "}], FontSize -> 25, 
                    GrayLevel[0.7]], ButtonData -> "ScrollPagePrevious", 
                    Appearance -> None], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipPreviousSlide"]]], 
                   "\[InvisibleSpace]", 
                   TooltipBox[
                    ButtonBox[
                    StyleBox[
                    RowBox[{" ", "\[RightPointer]", " "}], FontSize -> 25, 
                    GrayLevel[0.7]], ButtonData -> "ScrollPageNext", 
                    Appearance -> None], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipNextSlide"]]], 
                   "\[InvisibleSpace]", 
                   TooltipBox[
                    ButtonBox[
                    StyleBox[
                    RowBox[{" ", "\[LastPage]", " "}], FontSize -> 25, 
                    GrayLevel[0.7]], ButtonData -> "ScrollPageLast", 
                    Appearance -> None], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipLastSlide"]]]}], 
                 ButtonBoxOptions -> {Alignment -> {Automatic, 
                    FEPrivate`If[
                    FEPrivate`SameQ[
                    FEPrivate`$OperatingSystem, "Unix"], -0.4, -0.5]}, 
                   Appearance -> "Palette", 
                   ButtonFunction :> (FEPrivate`FrontEndExecute[
                    FrontEnd`FrontEndToken[
                    FrontEnd`ButtonNotebook[], #]]& ), Evaluator -> None, 
                   FrameMargins -> 0, ImageMargins -> 0, ImageSize -> 
                   Medium}], 
                
                DynamicModuleBox[{$CellContext`cells$$ = {}, \
$CellContext`tagFind$$ = False}, 
                 TagBox[
                  DynamicBox[
                   PopupMenuBox[
                    Dynamic[
                    0, With[{$CellContext`nb$ = ButtonNotebook[]}, 
                    SelectionMove[$CellContext`nb$, Before, Notebook, 
                    AutoScroll -> False]; If[$CellContext`tagFind$$, 
                    Do[
                    
                    NotebookFind[$CellContext`nb$, "SlideShowHeader", Next, 
                    CellTags, AutoScroll -> False], {#}], 
                    Do[
                    
                    NotebookFind[$CellContext`nb$, "SlideShowNavigationBar", 
                    Next, CellStyle, AutoScroll -> False], {#}]]; 
                    SelectionMove[$CellContext`nb$, After, Cell, AutoScroll -> 
                    False]; NotebookWrite[$CellContext`nb$, 
                    Cell["", Deletable -> True, ShowCellBracket -> False], 
                    All]; NotebookDelete[$CellContext`nb$]; 
                    SelectionMove[$CellContext`nb$, 
                    If[$CellContext`tagFind$$, Previous, Next], 
                    Cell]]& ], $CellContext`cells$$, 
                    StyleBox[
                    RowBox[{
                    DynamicBox[
                    CurrentValue[{"CounterValue", "SlideShowNavigationBar"}]], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "SlideshowToolbarCounterText"]], 
                    DynamicBox[
                    
                    CurrentValue[{
                    "MaxCounterValue", "SlideShowNavigationBar"}]]}], 
                    "ControlStyle"], Appearance -> None, ImageSize -> 
                    Automatic], ImageSizeCache -> {50., {6., 18.}}], 
                  
                  EventHandlerTag[{
                   "MouseDown" :> 
                    Module[{$CellContext`cnt$, $CellContext`nb$ = 
                    InputNotebook[]}, $CellContext`cells$$ = {}; \
$CellContext`cnt$ = Apply[(
                    NotebookFind[$CellContext`nb$, #, All, #2, AutoScroll -> 
                    False]; CurrentValue[$CellContext`nb$, {
                    "CellCount", True}])& , {{
                    "SlideShowNavigationBar", CellStyle}, {
                    "SlideShowHeader", CellTags}}, {1}]; $CellContext`cnt$ = 
                    Apply[If[$CellContext`tagFind$$ = # == 
                    0, #2, #]& , $CellContext`cnt$]; 
                    SelectionMove[$CellContext`nb$, Before, Notebook, 
                    AutoScroll -> False]; 
                    If[$CellContext`tagFind$$, $CellContext`cells$$ = 
                    Map[# -> StringJoin["Slide ", 
                    ToString[#]]& , 
                    Range[$CellContext`cnt$]], 
                    Do[NotebookFind[$CellContext`nb$, 
                    "SlideShowNavigationBar", Next, CellStyle, AutoScroll -> 
                    False]; SelectionMove[$CellContext`nb$, Next, Cell, 
                    AutoScroll -> False]; AppendTo[$CellContext`cells$$, 
                    ReplaceAll[
                    NotebookRead[$CellContext`nb$], Pattern[$CellContext`s, 
                    Blank[StyleBox]] :> With[{$CellContext`ss = Join[
                    Take[$CellContext`s, 1], 
                    DeleteCases[
                    Rest[$CellContext`s], 
                    Alternatives[
                    Blank[String], 
                    Blank[][FontColor, 
                    Blank[]]]]]}, 
                    
                    Condition[$CellContext`ss, 
                    True]]]], {$CellContext`cnt$}]; $CellContext`cells$$ = 
                    Replace[
                    Part[$CellContext`cells$$, All, 1], {BoxData[
                    Pattern[$CellContext`c, 
                    Blank[]]] :> $CellContext`c, TextData[
                    Pattern[$CellContext`c, 
                    Blank[]]] :> RowBox[
                    If[
                    
                    ListQ[$CellContext`c], $CellContext`c, \
{$CellContext`c}]]}, 1]; $CellContext`cells$$ = 
                    Thread[Range[$CellContext`cnt$] -> \
$CellContext`cells$$]]], PassEventsDown -> True, EvaluationOrder -> Before, 
                    PassEventsDown -> Automatic, PassEventsUp -> True}]], 
                 DynamicModuleValues :> {}]}}, AutoDelete -> False, 
              GridBoxItemSize -> {"Columns" -> {Automatic, Fit, Automatic}}]],
             "DockedCell", CellDynamicExpression :> If[CurrentValue[
                EvaluationNotebook[], {TaggingRules, "DisableController"}] === 
              True, Null, 
              (FrontEndExecute[
               FrontEnd`FrontEndToken[
                FrontEnd`InputNotebook[], #]]& )[
               Switch[
                ControllerState["Apple IR", {"B1", "B2"}], {True, 
                 Blank[]}, "ScrollPagePrevious", {
                 Blank[], True}, "ScrollPageNext", 
                Blank[], None]]], Magnification -> 0.75], 
          ScrollingOptions -> {
           "PagewiseDisplay" -> True, "VerticalScrollRange" -> Fit}, 
          ShowGroupOpener -> False, MenuSortingValue -> 1300], 
         Cell[
          StyleData["DockedCell"], Editable -> False, Evaluator -> "Local", 
          PageWidth -> WindowWidth, CellFrame -> {{0, 0}, {0, 0}}, 
          ShowSelection -> True, CellMargins -> {{0, 0}, {0, 0}}, 
          CellElementSpacings -> {
           "ClosedCellHeight" -> 0, "ClosedGroupTopMargin" -> 0}, 
          DynamicUpdating -> True, CellFrameMargins -> {{0, 0}, {0, 4}}, 
          ContextMenu -> None, ComponentwiseContextMenu -> {}, 
          ShowStringCharacters -> False, LineBreakWithin -> False, 
          Magnification -> 1, Background -> GrayLevel[0.97], 
          TooltipBoxOptions -> {TooltipDelay -> Automatic}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
         "Styles for Headings", "Section", 
          CellChangeTimes -> {{3.4990972189360075`*^9, 
           3.499097238491963*^9}, {3.499097561735284*^9, 
           3.4990975868877993`*^9}, {3.499551106974267*^9, 
           3.4995511081393337`*^9}}], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Title"], MenuSortingValue -> 1, MenuCommandKey -> "1",
              FontFamily -> "Georgia", FontSize -> 36, FontWeight -> Plain, 
             FontColor -> RGBColor[0.796078, 0.0705882, 0]], 
            Cell[
             StyleData["Title", "Presentation"], 
             CellMargins -> {{90, 100}, {10, 100}}, FontSize -> 54], 
            Cell[
             StyleData["Title", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subtitle"], MenuSortingValue -> 100, MenuCommandKey -> 
             "2", FontFamily -> "Georgia", FontSize -> 24, FontWeight -> 
             "Plain", FontSlant -> "Italic"], 
            Cell[
             StyleData["Subtitle", "Presentation"], 
             CellMargins -> {{90, 100}, {100, 20}}, FontSize -> 32], 
            Cell[
             StyleData["Subtitle", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubtitle"], MenuSortingValue -> 200, 
             MenuCommandKey -> "3", FontFamily -> "Georgia", FontSize -> 20, 
             FontWeight -> "Plain", FontSlant -> "Italic", FontColor -> 
             GrayLevel[0.2]], 
            Cell[
             StyleData["Subsubtitle", "Presentation"], 
             CellMargins -> {{90, 20}, {2, 120}}, LineSpacing -> {1.25, 1}, 
             FontSize -> 26], 
            Cell[
             StyleData["Subsubtitle", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DateSection"], CellMargins -> {{30, 0}, {12, 24}}, 
             ShowStringCharacters -> False], 
            Cell[
             StyleData["DateSection", "Presentation"], 
             CellMargins -> {{90, 20}, {2, 36}}, ShowStringCharacters -> 
             False, FontSize -> 21], 
            Cell[
             StyleData["DateSection", "SlideShow"]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
         "Styles for Sections", "Section", 
          CellChangeTimes -> {{3.4990972189360075`*^9, 
           3.499097238491963*^9}, {3.499097561735284*^9, 
           3.499097608731983*^9}}], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Chapter"], CellMargins -> {{27, Inherited}, {8, 34}}, 
             CounterIncrements -> {"Chapter"}, MenuSortingValue -> 2410, 
             FontFamily -> "Georgia", FontSize -> 28, FontColor -> 
             RGBColor[0.811765, 0.117647, 0.145098], CellTags -> "Chapter"], 
            Cell[
             StyleData["Chapter", "Presentation"], CellFrame -> None, 
             CellMargins -> {{80, 60}, {20, 30}}, FontSize -> 36], 
            Cell[
             StyleData["Chapter", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "LargeChapter", StyleDefnitions -> StyleData["Chapter"]], 
             CellMargins -> {{27, Inherited}, {8, 34}}, MenuSortingValue -> 
             2430, FontFamily -> "Georgia", FontSize -> 30, FontColor -> 
             RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["LargeChapter", "Presentation"], 
             CellMargins -> {{100, 100}, {10, 150}}, FontSize -> 54], 
            Cell[
             StyleData["LargeChapter", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Section"], CellFrame -> 0, MenuSortingValue -> 1200, 
             MenuCommandKey -> "4", FontFamily -> "Georgia", FontSize -> 24, 
             FontWeight -> Plain, FontColor -> 
             RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["Section", "Presentation"], CellFrame -> None, 
             CellMargins -> {{80, 14}, {30, 30}}, FontFamily -> "Georgia", 
             FontSize -> 34, FontWeight -> Plain, FontColor -> 
             RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["Section", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsection"], CellDingbat -> "\[RightGuillemet]", 
             CellGroupingRules -> {"SectionGrouping", 40}, MenuSortingValue -> 
             1300, MenuCommandKey -> "5", FontFamily -> "Georgia", FontSize -> 
             22, FontWeight -> Plain, FontColor -> GrayLevel[0.25]], 
            Cell[
             StyleData["Subsection", "Presentation"], 
             CellMargins -> {{80, 60}, {12, 20}}, FontSize -> 25], 
            Cell[
             StyleData["Subsection", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubsection"], CellDingbat -> "\[RightGuillemet]", 
             MenuSortingValue -> 1400, MenuCommandKey -> "6", FontFamily -> 
             "Georgia", FontSize -> 20, FontWeight -> Plain, FontColor -> 
             GrayLevel[0.3]], 
            Cell[
             StyleData["Subsubsection", "Presentation"], 
             CellMargins -> {{88, 60}, {0, 12}}, FontSize -> 22], 
            Cell[
             StyleData["Subsubsection", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "MoreExamplesSection", StyleDefinitions -> 
              StyleData["Subsubsection"]], CellDingbat -> None, 
             ShowGroupOpener -> True, 
             CellGroupingRules -> {"SectionGrouping", 45}, MenuSortingValue -> 
             2100, FontColor -> RGBColor[0.636862, 0.0564706, 0.]], 
            Cell[
             StyleData["MoreExamplesSection", "Presentation"], 
             CellMargins -> {{88, 60}, {20, 12}}], 
            Cell[
             StyleData["MoreExamplesSection", "SlideShow"], 
             WholeCellGroupOpener -> True, 
             CellMargins -> {{88, 60}, {20, 12}}]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
         "Styles for Text", "Section", 
          CellChangeTimes -> {{3.4990972189360075`*^9, 
           3.499097238491963*^9}, {3.499097561735284*^9, 
           3.4990976211772275`*^9}}], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Text"], MenuSortingValue -> 2000, MenuCommandKey -> 
             "7", FontFamily -> "Georgia", FontSize -> 18], 
            Cell[
             StyleData["Text", "Presentation"], 
             CellMargins -> {{80, 20}, {12, 12}}, LineSpacing -> {1.25, 1}, 
             FontFamily -> "Georgia", FontSize -> 20], 
            Cell[
             StyleData["Text", "SlideShow"]]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["MathCaption"], MenuSortingValue -> 2010, 
             MenuCommandKey -> "8", FontFamily -> "Georgia", FontSize -> 18, 
             FontColor -> GrayLevel[0]], 
            Cell[
             StyleData["MathCaption", "Presentation"], 
             CellMargins -> {{120, 12}, {6, 34}}, LineSpacing -> {1.25, 1}, 
             FontSize -> 20], 
            Cell[
             StyleData["MathCaption", "SlideShow"]]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "IntegrationMathCaption", StyleDefinitions -> 
              StyleData["MathCaption"]], CellMargins -> {{0, 12}, {2, 24}}, 
             CellFrameMargins -> {{0, 0}, {0, 3}}, CellFrameLabels -> {{
                PaneBox[
                 FrameBox[
                  StyleBox[
                  "Integration", FontFamily -> "Helvetica", FontSize -> 9, 
                   FontColor -> GrayLevel[1], FontWeight -> Plain], 
                  Background -> RGBColor[0.811765, 0.117647, 0.145098], 
                  BoxFrame -> 0, FrameStyle -> None, 
                  FrameMargins -> {{3, 3}, {1, 1}}], ImageSize -> 56, 
                 Alignment -> Left, FrameMargins -> 0], None}, {None, None}}], 
            Cell[
             StyleData["IntegrationMathCaption", "Presentation"], 
             CellMargins -> {{30, 12}, {12, 12}}, 
             CellFrameMargins -> {{10, 0}, {0, 5}}, FontSize -> 20], 
            Cell[
             StyleData["IntegrationMathCaption", "SlideShow"], 
             CellMargins -> {{30, 12}, {12, 12}}, 
             CellFrameMargins -> {{10, 0}, {0, 5}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "AutomationMathCaption", StyleDefinitions -> 
              StyleData["IntegrationMathCaption"]], 
             CellMargins -> {{0, 12}, {2, 24}}, 
             CellFrameMargins -> {{0, 0}, {0, 3}}, CellFrameLabels -> {{
                PaneBox[
                 FrameBox[
                  StyleBox[
                  "Automation", FontFamily -> "Helvetica", FontSize -> 9, 
                   FontColor -> GrayLevel[1], FontWeight -> Plain], 
                  Background -> RGBColor[0.811765, 0.117647, 0.145098], 
                  BoxFrame -> 0, FrameStyle -> None, 
                  FrameMargins -> {{3, 3}, {1, 1}}], ImageSize -> 56, 
                 Alignment -> Left, FrameMargins -> 0], None}, {None, None}}], 
            Cell[
             StyleData["AutomationMathCaption", "Presentation"], 
             CellMargins -> {{30, 12}, {12, 12}}, FontSize -> 20], 
            Cell[
             StyleData["AutomationMathCaption", "SlideShow"], 
             CellMargins -> {{30, 12}, {12, 12}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Comment", StyleDefinitions -> StyleData["Text"]], 
             CellMargins -> {{0, 12}, {2, 24}}, 
             CellFrameMargins -> {{0, 0}, {0, 3}}, CellFrameLabels -> {{
                PaneBox[
                 FrameBox[
                  StyleBox[
                  "Comment", FontFamily -> "Helvetica", FontSize -> 9, 
                   FontColor -> GrayLevel[1], FontWeight -> Plain], 
                  Background -> RGBColor[1., 0.647059, 0], BoxFrame -> 1, 
                  FrameStyle -> RGBColor[1., 0.647059, 0], 
                  FrameMargins -> {{3, 3}, {1, 1}}], ImageSize -> 56, 
                 Alignment -> Left, FrameMargins -> 0], None}, {None, None}}, 
             MenuSortingValue -> 2200, FontSize -> 14], 
            Cell[
             StyleData["Comment", "Presentation"], 
             CellMargins -> {{30, 12}, {12, 12}}, FontSize -> 16], 
            Cell[
             StyleData["Comment", "SlideShow"], 
             CellMargins -> {{30, 12}, {12, 12}}, FontSize -> 16]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DisplayFormula"], 
             CellMargins -> {{60, Inherited}, {Inherited, Inherited}}, 
             StripStyleOnPaste -> True, DefaultFormatType -> 
             DefaultInputFormatType, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, LanguageCategory -> 
             "Formula", ScriptLevel -> 0, SingleLetterItalics -> True, 
             MenuSortingValue -> 1700, 
             UnderoverscriptBoxOptions -> {LimitsPositioning -> True}], 
            Cell[
             StyleData["DisplayFormula", "Presentation"], 
             CellMargins -> {{120, Inherited}, {
               Inherited 1.75, Inherited 1.75}}, LineSpacing -> {1, 5}, 
             FontFamily -> "Georgia", FontSize -> 20], 
            Cell[
             StyleData["DisplayFormula", "SlideShow"]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
         "Styles for Items", "Section", 
          CellChangeTimes -> {{3.4990972189360075`*^9, 
           3.499097238491963*^9}, {3.499097561735284*^9, 
           3.499097638814991*^9}}], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Item"], CellDingbat -> "\[RightGuillemet] ", 
             LineSpacing -> {1.5, 0}, MenuSortingValue -> 2700, FontFamily -> 
             "Georgia", FontSize -> 18, FontColor -> GrayLevel[0.2]], 
            Cell[
             StyleData["Item", "Presentation"], 
             CellMargins -> {{116, 20}, {12, 12}}, FontFamily -> "Georgia", 
             FontSize -> 20], 
            Cell[
             StyleData["Item", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ItemParagraph"], MenuSortingValue -> 2710, FontFamily -> 
             "Georgia", FontSize -> 18, FontColor -> GrayLevel[0.2]], 
            Cell[
             StyleData["ItemParagraph", "Presentation"], 
             CellMargins -> {{120, 90}, {12, 12}}, LineSpacing -> {1.25, 0}, 
             FontFamily -> "Georgia", FontSize -> 20], 
            Cell[
             StyleData["ItemParagraph", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ItemNumbered"], LineSpacing -> {1.5, 0}, 
             MenuSortingValue -> 2720, FontFamily -> "Georgia", FontSize -> 
             18, FontColor -> GrayLevel[0.25]], 
            Cell[
             StyleData["ItemNumbered", "Presentation"], 
             CellMargins -> {{116, 20}, {12, 12}}, FontFamily -> "Georgia", 
             FontSize -> 20], 
            Cell[
             StyleData["ItemNumbered", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subitem"], CellDingbat -> "\[RightGuillemet] ", 
             LineSpacing -> {1.5, 0}, MenuSortingValue -> 2730, FontFamily -> 
             "Georgia", FontSize -> 16, FontColor -> GrayLevel[0.3]], 
            Cell[
             StyleData["Subitem", "Presentation"], 
             CellMargins -> {{136, 20}, {10, 10}}, FontFamily -> "Georgia", 
             FontSize -> 21], 
            Cell[
             StyleData["Subitem", "SlideShow"]]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SubitemParagraph"], LineSpacing -> {1.5, 0}, 
             MenuSortingValue -> 2740, FontFamily -> "Georgia", FontSize -> 
             16, FontColor -> GrayLevel[0.3]], 
            Cell[
             StyleData["SubitemParagraph", "Presentation"], 
             CellMargins -> {{136, 90}, {10, 8}}, FontFamily -> "Georgia", 
             FontSize -> 18], 
            Cell[
             StyleData["SubitemParagraph", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SubitemNumbered"], LineSpacing -> {1.5, 0}, 
             MenuSortingValue -> 2750, FontFamily -> "Georgia", FontSize -> 
             16, FontColor -> GrayLevel[0.3]], 
            Cell[
             StyleData["SubitemNumbered", "Presentation"], 
             CellMargins -> {{136, 20}, {10, 10}}, FontFamily -> "Georgia", 
             FontSize -> 18], 
            Cell[
             StyleData["SubitemNumbered", "SlideShow"]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Input and Output", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Input"], MenuSortingValue -> 2020, MenuCommandKey -> 
             "9", FontSize -> 18], 
            Cell[
             StyleData["Input", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["Input", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["CellLabel"], 
             CellLabelMargins -> {{12, Inherited}, {Inherited, Inherited}}, 
             LanguageCategory -> None, StyleMenuListing -> None, FontFamily -> 
             "Helvetica", FontSize -> 9, FontColor -> 
             RGBColor[0.269993, 0.308507, 0.6]], 
            Cell[
             StyleData["CellLabel", "Presentation"], 
             CellMargins -> {{12, Inherited}, {Inherited 1.5, Inherited 1.5}},
              FontSize -> 12], 
            Cell[
             StyleData["CellLabel", "SlideShow"], 
             CellMargins -> {{12, Inherited}, {Inherited 1.5, Inherited 1.5}},
              FontSize -> 12]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["WolframAlphaShort"], FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaShort", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaShort", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["WolframAlphaShortInput"], FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaShortInput", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaShortInput", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["WolframAlphaLong"], FontFamily -> "Helvetica", 
             FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaLong", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaLong", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["WolframAlphaLongInput"], FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaLongInput", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaLongInput", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Output"], MenuSortingValue -> 2030, FontSize -> 18], 
            Cell[
             StyleData["Output", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["Output", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Print"], FontSize -> 18], 
            Cell[
             StyleData["Print", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["Print", "SlideShow"]]}, Closed]], 
         Cell[
          StyleData["MSG"], FontSize -> 16]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles of Links", "Section"], 
         Cell[
          StyleData["Link", "SlideShow"], 
          CellGroupingRules -> {GroupTogetherGrouping, 10000.}, 
          CellChangeTimes -> {3.501501631339626*^9}, FontSize -> 21], 
         Cell[
          StyleData["SearchLink", StyleDefinitions -> StyleData["Link"]], 
          CellGroupingRules -> {GroupTogetherGrouping, 10000.}, 
          CellChangeTimes -> {3.501501631339626*^9}], 
         Cell[
          StyleData["FunctionLink"], 
          CellGroupingRules -> {GroupTogetherGrouping, 10000.}, 
          CellChangeTimes -> ({3.501501631339626*^9} FontWeight -> Plain)]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
         "Special Styles", "Section", 
          CellChangeTimes -> {{3.4990972189360075`*^9, 
           3.499097238491963*^9}, {3.499097561735284*^9, 
           3.49909768170428*^9}, {3.4991182305818043`*^9, 
           3.499118233792446*^9}, {3.4991270085028014`*^9, 
           3.4991270261172323`*^9}}], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Picture"], CellMargins -> {{100, 100}, {20, 20}}, 
             ShowStringCharacters -> False, MenuSortingValue -> 5000, 
             Magnification -> 1], 
            Cell[
             StyleData["Picture", "Presentation"], 
             CellMargins -> {{100, 100}, {20, 20}}, Magnification -> 1], 
            Cell[
             StyleData["Picture", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "PictureCaption", StyleDefinitions -> StyleData["Text"]], 
             CellDingbat -> "\[FilledUpTriangle]", 
             CellMargins -> {{114, 100}, {15, 4}}, ShowStringCharacters -> 
             False, MenuSortingValue -> 5100, FontSize -> 14, FontColor -> 
             GrayLevel[0.3]], 
            Cell[
             StyleData["PictureCaption", "Presentation"], 
             CellMargins -> {{114, 100}, {20, 4}}, FontSize -> 16], 
            Cell[
             StyleData["PictureCaption", "SlideShow"], 
             CellMargins -> {{114, 100}, {20, 4}}, FontSize -> 16]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["OverviewTitle"], CellFrame -> None, 
             CellMargins -> {{100, 100}, {20, 60}}, FontFamily -> "Calibri", 
             FontSize -> 24, FontWeight -> "Bold", FontColor -> 
             GrayLevel[0.4]], 
            Cell[
             StyleData["OverviewTitle", "Presentation"], CellFrame -> None, 
             CellMargins -> {{100, 100}, {20, 60}}, FontFamily -> "Calibri", 
             FontSize -> 24, FontWeight -> "Bold", FontColor -> 
             GrayLevel[0.4]], 
            Cell[
             StyleData["OverviewTitle", "SlideShow"], CellFrame -> None, 
             CellMargins -> {{100, 100}, {20, 60}}, FontFamily -> "Calibri", 
             FontSize -> 24, FontWeight -> "Bold", FontColor -> 
             GrayLevel[0.4]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["OverviewSection"], CellFrame -> None, 
             CellMargins -> {{120, 100}, {10, 10}}, ReturnCreatesNewCell -> 
             True, FontFamily -> "Georgia", FontSize -> 22, FontWeight -> 
             Plain, FontColor -> RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["OverviewSection", "Presentation"], CellFrame -> None, 
             CellMargins -> {{120, 100}, {10, 10}}, ReturnCreatesNewCell -> 
             True, FontFamily -> "Georgia", FontSize -> 22, FontWeight -> 
             Plain, FontColor -> RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["OverviewSection", "SlideShow"], CellFrame -> None, 
             CellMargins -> {{120, 100}, {10, 10}}, ReturnCreatesNewCell -> 
             True, FontFamily -> "Georgia", FontSize -> 22, FontWeight -> 
             Plain, FontColor -> RGBColor[0.811765, 0.117647, 0.145098]]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ChapterTagline"], CellMargins -> {{60, 90}, {15, 0}}, 
             MenuSortingValue -> 2420, FontFamily -> "Georgia", FontSize -> 
             20, FontWeight -> "Plain", FontSlant -> "Italic", FontColor -> 
             GrayLevel[0.3]], 
            Cell[
             StyleData["ChapterTagline", "Presentation"], 
             CellMargins -> {{90, 90}, {15, 0}}, FontSize -> 24], 
            Cell[
             StyleData["ChapterTagline", "SlideShow"]]}, Closed]], 
         Cell[
          StyleData["PlotLabel"], FontFamily -> "Helvetica", FontSize -> 14], 
         Cell[
          StyleData["NonPrintButton"], 
          CellMargins -> {{128, Inherited}, {16, 0}}, FontFamily -> 
          "Helvetica", FontSize -> 12, FontColor -> GrayLevel[1], 
          ButtonBoxOptions -> {
           Background -> RGBColor[0.811765, 0.117647, 0.145098], 
            ButtonMargins -> 4}], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Program"]], 
            Cell[
             StyleData["Program", "SlideShow"], 
             CellMargins -> {{116, 48}, {16, 16}}, FontSize -> 18]}, Closed]], 
         Cell[
          StyleData["DialogStyle"], FontSize -> 17]}, Closed]]}, Open]]}, 
  Visible -> False, FrontEndVersion -> 
  "8.0 for Microsoft Windows (64-bit) (February 23, 2011)", StyleDefinitions -> 
  "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "SlideShowHeader"->{
  Cell[623, 23, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[1589, 70, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[11599, 298, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[14806, 424, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[18787, 553, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[21941, 648, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[24356, 734, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[29729, 900, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[32884, 1002, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[34761, 1061, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[38178, 1159, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[42641, 1287, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[46815, 1418, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[47997, 1463, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[51821, 1577, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[67384, 1965, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[71376, 2086, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[76442, 2246, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[80855, 2387, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[85960, 2544, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[90886, 2685, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[95608, 2825, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[98512, 2904, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[101692, 2982, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[191958, 4618, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[195087, 4709, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[197454, 4782, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[202338, 4916, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[204167, 4975, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[208905, 5111, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[211813, 5195, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[212415, 5218, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[214965, 5311, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[218207, 5409, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[228232, 5709, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[233928, 5881, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[241419, 6106, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[243725, 6174, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[248488, 6327, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[251900, 6447, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[257797, 6653, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"]},
 "Data Smoothing"->{
  Cell[26237, 791, 1826, 54, 122, "Input",
   CellTags->"Data Smoothing"]},
 "Testing Framework"->{
  Cell[101840, 2989, 719, 21, 59, "Text",
   CellTags->"Testing Framework"],
  Cell[102562, 3012, 474, 19, 39, "DisplayFormula",
   CellTags->"Testing Framework"],
  Cell[103039, 3033, 361, 14, 35, "Text",
   CellTags->"Testing Framework"],
  Cell[103403, 3049, 84, 1, 35, "Text",
   CellTags->"Testing Framework"],
  Cell[103490, 3052, 469, 19, 39, "DisplayFormula",
   CellTags->"Testing Framework"],
  Cell[103962, 3073, 222, 5, 35, "Text",
   CellTags->"Testing Framework"],
  Cell[104187, 3080, 57264, 980, 247, "Picture",
   CellTags->"Testing Framework"],
  Cell[161454, 4062, 751, 28, 35, "Text",
   CellTags->"Testing Framework"],
  Cell[162208, 4092, 29680, 518, 247, "Picture",
   CellTags->"Testing Framework"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"SlideShowHeader", 306480, 7831},
 {"Data Smoothing", 310156, 7914},
 {"Testing Framework", 310256, 7917}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[623, 23, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[690, 26, 113, 4, 172, "Title"],
Cell[806, 32, 169, 6, 158, "Subtitle"],
Cell[978, 40, 131, 6, 191, "Subsubtitle"],
Cell[1112, 48, 419, 15, 64, "DateSection"],
Cell[1534, 65, 18, 0, 23, "Spacer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1589, 70, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[1678, 75, 27, 0, 99, "Section"],
Cell[1708, 77, 305, 7, 48, "Text"],
Cell[2016, 86, 2555, 51, 63, "OverviewSection"],
Cell[4574, 139, 1918, 42, 63, "OverviewSection"],
Cell[6495, 183, 1841, 41, 63, "OverviewSection"],
Cell[8339, 226, 2666, 52, 63, "OverviewSection"],
Cell[11008, 280, 380, 7, 79, "Text"],
Cell[11391, 289, 159, 3, 48, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[11599, 298, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[11688, 303, 47, 0, 99, "Section"],
Cell[11738, 305, 107, 3, 48, "Text"],
Cell[11848, 310, 18, 0, 23, "Spacer"],
Cell[CellGroupData[{
Cell[11891, 314, 43, 0, 39, "Subsubsection"],
Cell[11937, 316, 432, 13, 84, "Text"],
Cell[12372, 331, 1016, 34, 84, "Text"],
Cell[13391, 367, 365, 12, 72, "MathCaption"],
Cell[13759, 381, 276, 6, 40, "Input"],
Cell[14038, 389, 18, 0, 23, "Spacer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14093, 394, 34, 0, 39, "Subsubsection"],
Cell[14130, 396, 594, 19, 80, "Text"],
Cell[14727, 417, 18, 0, 23, "Spacer"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[14806, 424, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[14895, 429, 41, 0, 99, "Section"],
Cell[14939, 431, 375, 6, 48, "Text"],
Cell[15317, 439, 137, 3, 67, "MathCaption"],
Cell[15457, 444, 229, 6, 40, "Input"],
Cell[15689, 452, 476, 13, 98, "MathCaption"],
Cell[16168, 467, 968, 28, 95, "Input"],
Cell[17139, 497, 18, 0, 23, "Spacer"],
Cell[17160, 499, 281, 5, 48, "Text"],
Cell[17444, 506, 147, 3, 67, "MathCaption"],
Cell[17594, 511, 796, 22, 68, "Input"],
Cell[18393, 535, 18, 0, 23, "Spacer"],
Cell[18414, 537, 303, 8, 82, "Text"],
Cell[18720, 547, 18, 0, 23, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[18787, 553, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[18876, 558, 90, 2, 99, "Section"],
Cell[18969, 562, 551, 14, 79, "Text"],
Cell[19523, 578, 756, 20, 40, "Input"],
Cell[20282, 600, 272, 5, 67, "MathCaption"],
Cell[20557, 607, 352, 6, 40, "Input"],
Cell[20912, 615, 244, 5, 98, "MathCaption"],
Cell[21159, 622, 712, 18, 122, "Input"],
Cell[21874, 642, 18, 0, 23, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[21941, 648, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[22030, 653, 61, 0, 99, "Section"],
Cell[22094, 655, 195, 4, 48, "Text"],
Cell[22292, 661, 655, 25, 72, "MathCaption"],
Cell[22950, 688, 434, 12, 40, "Input"],
Cell[23387, 702, 216, 4, 67, "MathCaption"],
Cell[23606, 708, 680, 18, 68, "Input"],
Cell[24289, 728, 18, 0, 23, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[24356, 734, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[24445, 739, 62, 0, 99, "Section"],
Cell[24510, 741, 749, 23, 89, "Text"],
Cell[25262, 766, 193, 2, 67, "MathCaption"],
Cell[25458, 770, 510, 12, 68, "Input"],
Cell[25971, 784, 263, 5, 67, "MathCaption"],
Cell[26237, 791, 1826, 54, 122, "Input",
 CellTags->"Data Smoothing"],
Cell[28066, 847, 18, 0, 23, "Spacer"],
Cell[28087, 849, 305, 5, 48, "Text"],
Cell[28395, 856, 713, 19, 84, "Text"],
Cell[29111, 877, 548, 15, 84, "Text"],
Cell[29662, 894, 18, 0, 23, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[29729, 900, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[29818, 905, 58, 0, 99, "Section"],
Cell[29879, 907, 139, 3, 48, "Text"],
Cell[30021, 912, 715, 18, 121, "Text"],
Cell[30739, 932, 266, 5, 67, "MathCaption"],
Cell[31008, 939, 385, 8, 68, "Input"],
Cell[31396, 949, 305, 8, 103, "MathCaption"],
Cell[31704, 959, 303, 9, 40, "Input"],
Cell[32010, 970, 124, 3, 40, "Input"],
Cell[32137, 975, 259, 7, 72, "MathCaption"],
Cell[32399, 984, 415, 10, 68, "Input"],
Cell[32817, 996, 18, 0, 23, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[32884, 1002, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[32973, 1007, 62, 0, 99, "Section"],
Cell[33038, 1009, 304, 7, 80, "Text"],
Cell[33345, 1018, 154, 2, 40, "Input"],
Cell[33502, 1022, 77, 0, 67, "MathCaption"],
Cell[33582, 1024, 469, 10, 149, "Input"],
Cell[34054, 1036, 172, 4, 67, "MathCaption"],
Cell[34229, 1042, 462, 11, 40, "Input"],
Cell[34694, 1055, 18, 0, 23, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[34761, 1061, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[34850, 1066, 44, 0, 99, "Section"],
Cell[34897, 1068, 266, 6, 48, "Text"],
Cell[CellGroupData[{
Cell[35188, 1078, 232, 6, 49, "Item"],
Cell[35423, 1086, 446, 9, 49, "Item"],
Cell[35872, 1097, 476, 7, 49, "Item"],
Cell[36351, 1106, 499, 11, 49, "Item"],
Cell[36853, 1119, 452, 10, 49, "Item"],
Cell[37308, 1131, 445, 10, 49, "Item"]
}, Open  ]],
Cell[37768, 1144, 340, 7, 79, "Text"],
Cell[38111, 1153, 18, 0, 23, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[38178, 1159, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[38267, 1164, 74, 0, 99, "Section"],
Cell[38344, 1166, 426, 8, 79, "Text"],
Cell[38773, 1176, 133, 3, 67, "MathCaption"],
Cell[38909, 1181, 2556, 66, 176, "Input"],
Cell[41468, 1249, 202, 3, 67, "MathCaption"],
Cell[41673, 1254, 898, 25, 95, "Input"],
Cell[42574, 1281, 18, 0, 23, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[42641, 1287, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[42730, 1292, 76, 0, 99, "Section"],
Cell[42809, 1294, 864, 26, 120, "Text"],
Cell[43676, 1322, 277, 5, 67, "MathCaption"],
Cell[43956, 1329, 811, 22, 68, "Input"],
Cell[44770, 1353, 121, 3, 67, "MathCaption"],
Cell[44894, 1358, 813, 22, 95, "Input"],
Cell[45710, 1382, 244, 3, 67, "MathCaption"],
Cell[45957, 1387, 788, 23, 68, "Input"],
Cell[46748, 1412, 18, 0, 23, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[46815, 1418, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[46904, 1423, 56, 0, 99, "Section"],
Cell[46963, 1425, 403, 11, 84, "Text"],
Cell[47369, 1438, 178, 4, 67, "MathCaption"],
Cell[47550, 1444, 242, 7, 45, "Input"],
Cell[47795, 1453, 132, 2, 40, "Input"],
Cell[47930, 1457, 18, 0, 23, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[47997, 1463, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[48086, 1468, 66, 0, 99, "Section"],
Cell[48155, 1470, 1101, 27, 151, "Text"],
Cell[49259, 1499, 230, 5, 67, "MathCaption"],
Cell[49492, 1506, 223, 5, 40, "Input"],
Cell[49718, 1513, 226, 5, 67, "MathCaption"],
Cell[49947, 1520, 1804, 49, 203, "Input"],
Cell[51754, 1571, 18, 0, 23, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[51821, 1577, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[51910, 1582, 79, 0, 99, "Section"],
Cell[51992, 1584, 365, 6, 110, "Text"],
Cell[52360, 1592, 1494, 34, 63, "OverviewSection"],
Cell[53857, 1628, 1492, 34, 63, "OverviewSection"],
Cell[55352, 1664, 1499, 34, 63, "OverviewSection"],
Cell[56854, 1700, 1511, 35, 63, "OverviewSection"],
Cell[58368, 1737, 1564, 36, 63, "OverviewSection"],
Cell[59935, 1775, 1445, 34, 63, "OverviewSection"],
Cell[61383, 1811, 1464, 34, 63, "OverviewSection"],
Cell[62850, 1847, 1512, 35, 63, "OverviewSection"],
Cell[64365, 1884, 1336, 32, 63, "OverviewSection"],
Cell[65704, 1918, 1522, 35, 63, "OverviewSection"],
Cell[67229, 1955, 85, 2, 48, "Text"],
Cell[67317, 1959, 18, 0, 23, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[67384, 1965, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[67473, 1970, 69, 0, 99, "Section"],
Cell[67545, 1972, 526, 10, 84, "Text"],
Cell[68074, 1984, 166, 3, 67, "MathCaption"],
Cell[68243, 1989, 527, 17, 101, "Input"],
Cell[68773, 2008, 18, 0, 23, "Spacer"],
Cell[68794, 2010, 424, 9, 84, "Text"],
Cell[69221, 2021, 350, 6, 79, "Text"],
Cell[69574, 2029, 253, 5, 67, "MathCaption"],
Cell[69830, 2036, 266, 6, 40, "Input"],
Cell[70099, 2044, 180, 2, 67, "MathCaption"],
Cell[70282, 2048, 598, 17, 40, "Input"],
Cell[70883, 2067, 260, 5, 67, "MathCaption"],
Cell[71146, 2074, 160, 4, 45, "Input"],
Cell[71309, 2080, 18, 0, 23, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[71376, 2086, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[71465, 2091, 67, 0, 99, "Section"],
Cell[71535, 2093, 626, 14, 120, "Text"],
Cell[72164, 2109, 177, 3, 67, "MathCaption"],
Cell[72344, 2114, 412, 12, 40, "Input"],
Cell[72759, 2128, 18, 0, 23, "Spacer"],
Cell[72780, 2130, 160, 3, 48, "Text"],
Cell[72943, 2135, 198, 4, 67, "MathCaption"],
Cell[73144, 2141, 694, 17, 68, "Input"],
Cell[73841, 2160, 430, 12, 122, "Input"],
Cell[74274, 2174, 18, 0, 23, "Spacer"],
Cell[74295, 2176, 279, 5, 48, "Text"],
Cell[74577, 2183, 170, 3, 67, "MathCaption"],
Cell[74750, 2188, 1622, 50, 149, "Input"],
Cell[76375, 2240, 18, 0, 23, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[76442, 2246, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[76531, 2251, 65, 0, 99, "Section"],
Cell[76599, 2253, 503, 12, 79, "Text"],
Cell[77105, 2267, 338, 9, 67, "MathCaption"],
Cell[77446, 2278, 633, 12, 40, "Input"],
Cell[78082, 2292, 18, 0, 23, "Spacer"],
Cell[78103, 2294, 228, 4, 48, "Text"],
Cell[78334, 2300, 165, 3, 67, "MathCaption"],
Cell[78502, 2305, 178, 4, 40, "Input"],
Cell[78683, 2311, 301, 9, 70, "MathCaption"],
Cell[78987, 2322, 363, 10, 40, "Input"],
Cell[79353, 2334, 18, 0, 23, "Spacer"],
Cell[79374, 2336, 165, 3, 48, "Text"],
Cell[79542, 2341, 151, 2, 67, "MathCaption"],
Cell[79696, 2345, 616, 18, 72, "Input"],
Cell[80315, 2365, 199, 4, 67, "MathCaption"],
Cell[80517, 2371, 268, 8, 40, "Input"],
Cell[80788, 2381, 18, 0, 23, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[80855, 2387, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[80944, 2392, 88, 2, 99, "Section"],
Cell[81035, 2396, 922, 25, 89, "Text"],
Cell[81960, 2423, 142, 1, 67, "MathCaption"],
Cell[82105, 2426, 1082, 29, 40, "Input"],
Cell[83190, 2457, 159, 3, 67, "MathCaption"],
Cell[83352, 2462, 580, 16, 40, "Input"],
Cell[83935, 2480, 157, 3, 67, "MathCaption"],
Cell[84095, 2485, 455, 12, 40, "Input"],
Cell[84553, 2499, 18, 0, 23, "Spacer"],
Cell[84574, 2501, 385, 9, 84, "Text"],
Cell[84962, 2512, 251, 4, 98, "MathCaption"],
Cell[85216, 2518, 674, 18, 68, "Input"],
Cell[85893, 2538, 18, 0, 23, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[85960, 2544, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[86049, 2549, 53, 0, 99, "Section"],
Cell[86105, 2551, 447, 10, 81, "Text"],
Cell[86555, 2563, 184, 4, 67, "MathCaption"],
Cell[86742, 2569, 635, 15, 68, "Input"],
Cell[87380, 2586, 182, 4, 67, "MathCaption"],
Cell[87565, 2592, 776, 18, 68, "Input"],
Cell[88344, 2612, 18, 0, 23, "Spacer"],
Cell[88365, 2614, 260, 5, 98, "MathCaption"],
Cell[88628, 2621, 1837, 46, 95, "Input"],
Cell[90468, 2669, 18, 0, 23, "Spacer"],
Cell[90489, 2671, 327, 6, 48, "Text"],
Cell[90819, 2679, 18, 0, 23, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[90886, 2685, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[90975, 2690, 73, 0, 71, "Section"],
Cell[91051, 2692, 460, 11, 60, "Text"],
Cell[91514, 2705, 239, 5, 49, "MathCaption"],
Cell[91756, 2712, 541, 12, 64, "Input"],
Cell[92300, 2726, 239, 5, 49, "MathCaption"],
Cell[92542, 2733, 356, 6, 36, "Input"],
Cell[92901, 2741, 358, 6, 49, "MathCaption"],
Cell[93262, 2749, 1787, 51, 118, "Input"],
Cell[95052, 2802, 18, 0, 23, "Spacer"],
Cell[95073, 2804, 465, 13, 36, "Text"],
Cell[95541, 2819, 18, 0, 23, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[95608, 2825, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[95697, 2830, 68, 0, 71, "Section"],
Cell[95768, 2832, 792, 17, 61, "Text"],
Cell[96563, 2851, 267, 5, 49, "MathCaption"],
Cell[96833, 2858, 454, 8, 36, "Input"],
Cell[97290, 2868, 454, 8, 36, "Input"],
Cell[97747, 2878, 173, 3, 49, "MathCaption"],
Cell[97923, 2883, 519, 13, 36, "Input"],
Cell[98445, 2898, 18, 0, 23, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[98512, 2904, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[98601, 2909, 37, 0, 71, "Section"],
Cell[98641, 2911, 776, 15, 59, "Text"],
Cell[CellGroupData[{
Cell[99442, 2930, 411, 7, 29, "Item"],
Cell[99856, 2939, 315, 4, 29, "Item"],
Cell[100174, 2945, 355, 6, 29, "Item"],
Cell[100532, 2953, 613, 11, 29, "Item"],
Cell[101148, 2966, 462, 7, 29, "Item"]
}, Open  ]],
Cell[101625, 2976, 18, 0, 23, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[101692, 2982, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[101781, 2987, 56, 0, 71, "Section"],
Cell[101840, 2989, 719, 21, 59, "Text",
 CellTags->"Testing Framework"],
Cell[102562, 3012, 474, 19, 39, "DisplayFormula",
 CellTags->"Testing Framework"],
Cell[103039, 3033, 361, 14, 35, "Text",
 CellTags->"Testing Framework"],
Cell[103403, 3049, 84, 1, 35, "Text",
 CellTags->"Testing Framework"],
Cell[103490, 3052, 469, 19, 39, "DisplayFormula",
 CellTags->"Testing Framework"],
Cell[103962, 3073, 222, 5, 35, "Text",
 CellTags->"Testing Framework"],
Cell[104187, 3080, 57264, 980, 247, "Picture",
 CellTags->"Testing Framework"],
Cell[161454, 4062, 751, 28, 35, "Text",
 CellTags->"Testing Framework"],
Cell[162208, 4092, 29680, 518, 247, "Picture",
 CellTags->"Testing Framework"],
Cell[191891, 4612, 18, 0, 23, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[191958, 4618, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[192047, 4623, 56, 0, 71, "Section"],
Cell[192106, 4625, 846, 18, 84, "Text"],
Cell[192955, 4645, 260, 5, 49, "MathCaption"],
Cell[193218, 4652, 502, 10, 36, "Input"],
Cell[193723, 4664, 302, 7, 49, "MathCaption"],
Cell[194028, 4673, 265, 5, 36, "Input"],
Cell[194296, 4680, 196, 4, 49, "MathCaption"],
Cell[194495, 4686, 501, 13, 36, "Input"],
Cell[194999, 4701, 18, 0, 23, "Spacer"],
Cell[195020, 4703, 18, 0, 23, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[195087, 4709, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[195176, 4714, 56, 0, 71, "Section"],
Cell[195235, 4716, 164, 3, 35, "Text"],
Cell[195402, 4721, 273, 7, 49, "MathCaption"],
Cell[195678, 4730, 360, 8, 36, "Input"],
Cell[196041, 4740, 173, 3, 49, "MathCaption"],
Cell[196217, 4745, 375, 7, 36, "Input"],
Cell[196595, 4754, 153, 2, 49, "MathCaption"],
Cell[196751, 4758, 194, 3, 36, "Input"],
Cell[196948, 4763, 191, 4, 49, "MathCaption"],
Cell[197142, 4769, 242, 5, 36, "Input"],
Cell[197387, 4776, 18, 0, 23, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[197454, 4782, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[197543, 4787, 144, 3, 71, "Section"],
Cell[197690, 4792, 490, 8, 35, "Text"],
Cell[198183, 4802, 216, 4, 49, "MathCaption"],
Cell[198402, 4808, 426, 11, 36, "Input"],
Cell[198831, 4821, 325, 7, 36, "Input"],
Cell[199159, 4830, 167, 3, 36, "Input"],
Cell[199329, 4835, 336, 8, 49, "MathCaption"],
Cell[199668, 4845, 207, 4, 36, "Input"],
Cell[199878, 4851, 339, 6, 49, "MathCaption"],
Cell[200220, 4859, 329, 6, 36, "Input"],
Cell[200552, 4867, 241, 6, 36, "Input"],
Cell[200796, 4875, 349, 6, 49, "MathCaption"],
Cell[201148, 4883, 400, 7, 36, "Input"],
Cell[201551, 4892, 285, 5, 49, "MathCaption"],
Cell[201839, 4899, 429, 9, 36, "Input"],
Cell[202271, 4910, 18, 0, 23, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[202338, 4916, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[202427, 4921, 56, 0, 71, "Section"],
Cell[202486, 4923, 495, 13, 36, "Text"],
Cell[202984, 4938, 185, 4, 35, "Text"],
Cell[203172, 4944, 196, 4, 49, "MathCaption"],
Cell[203371, 4950, 351, 7, 36, "Input"],
Cell[203725, 4959, 223, 4, 49, "MathCaption"],
Cell[203951, 4965, 146, 2, 36, "Input"],
Cell[204100, 4969, 18, 0, 23, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[204167, 4975, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[204256, 4980, 69, 0, 71, "Section"],
Cell[204328, 4982, 426, 7, 59, "Text"],
Cell[204757, 4991, 295, 6, 35, "Text"],
Cell[205055, 4999, 281, 5, 49, "MathCaption"],
Cell[205339, 5006, 1166, 32, 120, "Input"],
Cell[206508, 5040, 18, 0, 23, "Spacer"],
Cell[206529, 5042, 282, 7, 59, "Text"],
Cell[206814, 5051, 220, 4, 49, "MathCaption"],
Cell[207037, 5057, 325, 7, 36, "Input"],
Cell[207365, 5066, 18, 0, 23, "Spacer"],
Cell[207386, 5068, 216, 4, 35, "Text"],
Cell[207605, 5074, 307, 5, 49, "MathCaption"],
Cell[207915, 5081, 278, 6, 36, "Input"],
Cell[208196, 5089, 312, 5, 49, "MathCaption"],
Cell[208511, 5096, 324, 7, 36, "Input"],
Cell[208838, 5105, 18, 0, 23, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[208905, 5111, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[208994, 5116, 72, 0, 71, "Section"],
Cell[209069, 5118, 425, 9, 59, "Text"],
Cell[209497, 5129, 247, 5, 49, "MathCaption"],
Cell[209747, 5136, 395, 8, 36, "Input"],
Cell[210145, 5146, 264, 5, 49, "MathCaption"],
Cell[210412, 5153, 221, 5, 36, "Input"],
Cell[210636, 5160, 404, 9, 49, "MathCaption"],
Cell[211043, 5171, 189, 4, 36, "Input"],
Cell[211235, 5177, 18, 0, 23, "Spacer"],
Cell[211256, 5179, 487, 8, 83, "Text"],
Cell[211746, 5189, 18, 0, 23, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[211813, 5195, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[211902, 5200, 45, 0, 71, "Section"],
Cell[211950, 5202, 395, 8, 83, "Text"],
Cell[212348, 5212, 18, 0, 23, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[212415, 5218, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[212504, 5223, 64, 0, 71, "Section"],
Cell[212571, 5225, 67, 0, 35, "Text"],
Cell[212641, 5227, 226, 6, 36, "Input"],
Cell[212870, 5235, 288, 8, 50, "MathCaption"],
Cell[213161, 5245, 451, 11, 36, "Input"],
Cell[213615, 5258, 126, 2, 36, "Input"],
Cell[213744, 5262, 18, 0, 23, "Spacer"],
Cell[213765, 5264, 404, 12, 36, "Text"],
Cell[214172, 5278, 275, 10, 49, "MathCaption"],
Cell[214450, 5290, 156, 3, 36, "Input"],
Cell[214609, 5295, 141, 4, 50, "MathCaption"],
Cell[214753, 5301, 142, 2, 36, "Input"],
Cell[214898, 5305, 18, 0, 23, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[214965, 5311, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[215054, 5316, 76, 0, 99, "Section"],
Cell[215133, 5318, 172, 4, 48, "Text"],
Cell[215308, 5324, 117, 3, 67, "MathCaption"],
Cell[215428, 5329, 306, 8, 40, "Input"],
Cell[215737, 5339, 354, 6, 98, "MathCaption"],
Cell[216094, 5347, 715, 15, 68, "Input"],
Cell[216812, 5364, 224, 4, 67, "MathCaption"],
Cell[217039, 5370, 1098, 31, 95, "Input"],
Cell[218140, 5403, 18, 0, 23, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[218207, 5409, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[218296, 5414, 78, 0, 99, "Section"],
Cell[218377, 5416, 257, 3, 48, "Text"],
Cell[218637, 5421, 845, 30, 51, "Text"],
Cell[219485, 5453, 889, 31, 52, "Text"],
Cell[220377, 5486, 285, 3, 48, "Text"],
Cell[220665, 5491, 1043, 36, 51, "Text"],
Cell[221711, 5529, 940, 28, 144, "Text"],
Cell[222654, 5559, 89, 2, 48, "Text"],
Cell[222746, 5563, 1421, 34, 63, "OverviewSection"],
Cell[224170, 5599, 1267, 31, 63, "OverviewSection"],
Cell[225440, 5632, 1267, 31, 63, "OverviewSection"],
Cell[226710, 5665, 1350, 32, 63, "OverviewSection"],
Cell[228063, 5699, 99, 2, 48, "Text"],
Cell[228165, 5703, 18, 0, 23, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[228232, 5709, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[228321, 5714, 92, 2, 99, "Section"],
Cell[228416, 5718, 754, 17, 115, "Text"],
Cell[229173, 5737, 187, 4, 67, "MathCaption"],
Cell[229363, 5743, 612, 21, 67, "Input"],
Cell[229978, 5766, 286, 3, 67, "MathCaption"],
Cell[230267, 5771, 278, 5, 40, "Input"],
Cell[230548, 5778, 258, 5, 67, "MathCaption"],
Cell[230809, 5785, 286, 7, 40, "Input"],
Cell[231098, 5794, 18, 0, 23, "Spacer"],
Cell[231119, 5796, 414, 12, 89, "Text"],
Cell[231536, 5810, 130, 1, 67, "MathCaption"],
Cell[231669, 5813, 205, 4, 40, "Input"],
Cell[231877, 5819, 18, 0, 23, "Spacer"],
Cell[231898, 5821, 359, 9, 84, "Text"],
Cell[232260, 5832, 201, 3, 67, "MathCaption"],
Cell[232464, 5837, 388, 8, 40, "Input"],
Cell[232855, 5847, 18, 0, 23, "Spacer"],
Cell[232876, 5849, 366, 10, 84, "Text"],
Cell[233245, 5861, 242, 3, 67, "MathCaption"],
Cell[233490, 5866, 368, 7, 40, "Input"],
Cell[233861, 5875, 18, 0, 23, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[233928, 5881, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[234017, 5886, 89, 2, 99, "Section"],
Cell[234109, 5890, 638, 18, 120, "Text"],
Cell[234750, 5910, 302, 5, 79, "Text"],
Cell[235055, 5917, 245, 3, 67, "MathCaption"],
Cell[235303, 5922, 1071, 29, 95, "Input"],
Cell[236377, 5953, 18, 0, 23, "Spacer"],
Cell[236398, 5955, 369, 9, 53, "Text"],
Cell[236770, 5966, 269, 3, 67, "MathCaption"],
Cell[237042, 5971, 404, 9, 68, "Input"],
Cell[237449, 5982, 18, 0, 23, "Spacer"],
Cell[237470, 5984, 591, 15, 89, "Text"],
Cell[238064, 6001, 327, 10, 67, "MathCaption"],
Cell[238394, 6013, 276, 7, 40, "Input"],
Cell[238673, 6022, 18, 0, 23, "Spacer"],
Cell[238694, 6024, 186, 4, 48, "Text"],
Cell[238883, 6030, 133, 1, 67, "MathCaption"],
Cell[239019, 6033, 542, 12, 68, "Input"],
Cell[239564, 6047, 184, 4, 67, "MathCaption"],
Cell[239751, 6053, 1038, 28, 68, "Input"],
Cell[240792, 6083, 18, 0, 23, "Spacer"],
Cell[240813, 6085, 536, 13, 84, "Text"],
Cell[241352, 6100, 18, 0, 23, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[241419, 6106, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[241508, 6111, 67, 0, 99, "Section"],
Cell[241578, 6113, 465, 11, 84, "Text"],
Cell[242046, 6126, 166, 3, 67, "MathCaption"],
Cell[242215, 6131, 824, 17, 40, "Input"],
Cell[243042, 6150, 18, 0, 23, "Spacer"],
Cell[243063, 6152, 256, 6, 79, "Text"],
Cell[243322, 6160, 78, 0, 67, "MathCaption"],
Cell[243403, 6162, 252, 4, 40, "Input"],
Cell[243658, 6168, 18, 0, 23, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[243725, 6174, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[243814, 6179, 119, 3, 148, "Section"],
Cell[243936, 6184, 216, 4, 79, "Text"],
Cell[244155, 6190, 249, 7, 70, "MathCaption"],
Cell[244407, 6199, 439, 12, 40, "Input"],
Cell[244849, 6213, 14, 0, 23, "MR"],
Cell[244866, 6215, 382, 9, 110, "Text"],
Cell[245251, 6226, 258, 6, 67, "MathCaption"],
Cell[245512, 6234, 658, 19, 40, "Input"],
Cell[246173, 6255, 137, 1, 67, "MathCaption"],
Cell[246313, 6258, 177, 4, 40, "Input"],
Cell[246493, 6264, 18, 0, 23, "Spacer"],
Cell[246514, 6266, 153, 3, 48, "Text"],
Cell[246670, 6271, 108, 4, 67, "MathCaption"],
Cell[246781, 6277, 783, 20, 68, "Input"],
Cell[247567, 6299, 14, 0, 23, "MR"],
Cell[247584, 6301, 482, 8, 110, "Text"],
Cell[248069, 6311, 184, 4, 67, "MathCaption"],
Cell[248256, 6317, 162, 2, 40, "Input"],
Cell[248421, 6321, 18, 0, 23, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[248488, 6327, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[248577, 6332, 52, 0, 99, "Section"],
Cell[248632, 6334, 824, 22, 84, "Text"],
Cell[249459, 6358, 65, 0, 67, "MathCaption"],
Cell[249527, 6360, 146, 3, 40, "Input"],
Cell[249676, 6365, 312, 11, 72, "MathCaption"],
Cell[249991, 6378, 139, 2, 40, "Input"],
Cell[250133, 6382, 94, 2, 67, "MathCaption"],
Cell[250230, 6386, 197, 6, 40, "Input"],
Cell[250430, 6394, 14, 0, 23, "MR"],
Cell[250447, 6396, 98, 2, 48, "Text"],
Cell[250548, 6400, 174, 3, 98, "MathCaption"],
Cell[250725, 6405, 361, 10, 40, "Input"],
Cell[251089, 6417, 290, 8, 72, "MathCaption"],
Cell[251382, 6427, 368, 9, 40, "Input"],
Cell[251753, 6438, 77, 1, 40, "Input"],
Cell[251833, 6441, 18, 0, 23, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[251900, 6447, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[251989, 6452, 36, 0, 99, "Section"],
Cell[CellGroupData[{
Cell[252050, 6456, 40, 0, 59, "MoreExamplesSection"],
Cell[CellGroupData[{
Cell[252115, 6460, 141, 3, 48, "Item",
 CellID->900583006],
Cell[252259, 6465, 157, 3, 48, "Item",
 CellID->633837786],
Cell[252419, 6470, 154, 3, 48, "Item",
 CellID->1392780182],
Cell[252576, 6475, 153, 3, 48, "Item",
 CellID->884766574],
Cell[252732, 6480, 167, 3, 48, "Item",
 CellID->1095037390],
Cell[252902, 6485, 135, 3, 48, "Item",
 CellID->358558940],
Cell[253040, 6490, 163, 3, 48, "Item",
 CellID->460991098],
Cell[253206, 6495, 150, 3, 48, "Item",
 CellID->1903869357],
Cell[253359, 6500, 156, 3, 48, "Item",
 CellID->825942799],
Cell[253518, 6505, 171, 3, 48, "Item",
 CellID->286328585]
}, Open  ]],
Cell[253704, 6511, 18, 0, 20, "Spacer"]
}, Closed]],
Cell[CellGroupData[{
Cell[253759, 6516, 75, 0, 51, "MoreExamplesSection"],
Cell[CellGroupData[{
Cell[253859, 6520, 606, 15, 47, "Item"],
Cell[254468, 6537, 545, 15, 46, "Item"],
Cell[255016, 6554, 758, 20, 46, "Item"],
Cell[255777, 6576, 384, 10, 46, "Item"],
Cell[256164, 6588, 381, 10, 46, "Item"]
}, Open  ]],
Cell[256560, 6601, 18, 0, 20, "Spacer"]
}, Closed]],
Cell[CellGroupData[{
Cell[256615, 6606, 51, 0, 51, "MoreExamplesSection"],
Cell[CellGroupData[{
Cell[256691, 6610, 436, 11, 47, "Item"],
Cell[257130, 6623, 200, 6, 46, "Item"],
Cell[257333, 6631, 179, 6, 46, "Item"],
Cell[257515, 6639, 209, 6, 46, "Item"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[257797, 6653, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[257886, 6658, 61, 1, 99, "Section",
 InitializationGroup->True],
Cell[CellGroupData[{
Cell[257972, 6663, 41, 0, 59, "MoreExamplesSection"],
Cell[258016, 6665, 428, 11, 63, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[258481, 6681, 114, 1, 51, "MoreExamplesSection"],
Cell[258598, 6684, 207, 6, 39, "Input"],
Cell[258808, 6692, 3800, 87, 361, "Input"],
Cell[262611, 6781, 2358, 77, 337, "Input"],
Cell[264972, 6860, 2633, 62, 564, "Input"],
Cell[267608, 6924, 976, 23, 222, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[268621, 6952, 45, 0, 51, "MoreExamplesSection"],
Cell[268669, 6954, 1598, 47, 108, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[270304, 7006, 47, 0, 51, "MoreExamplesSection"],
Cell[270354, 7008, 308, 9, 37, "Input"],
Cell[270665, 7019, 207, 5, 37, "Input"],
Cell[270875, 7026, 204, 5, 37, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[271116, 7036, 44, 0, 51, "MoreExamplesSection"],
Cell[271163, 7038, 88, 1, 37, "Input"],
Cell[271254, 7041, 71, 1, 37, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[271362, 7047, 52, 0, 51, "MoreExamplesSection"],
Cell[271417, 7049, 210, 6, 36, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[271664, 7060, 37, 0, 51, "MoreExamplesSection"],
Cell[271704, 7062, 71, 2, 37, "Input"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
